--[[
-- 国家成员列表
-- @author lph
-- Creation  2016-4-6
]]



local CountryMemberListLayer = class("CountryMemberListLayer", function ()
    local layer = cc.Sprite:create()
    layer:setContentSize( 565, 464 )
    layer:setAnchorPoint(cc.p(0,0))
    return layer
end)

function CountryMemberListLayer:create( params )
    return CountryMemberListLayer.new( params )
end

function CountryMemberListLayer:ctor( params )
    self:initData(params)
    self:initUI()
end

function CountryMemberListLayer:initData(params)
    self._memberData = params
    self:memberListSort()

    local CountryMain = zc.getScene("Country")
    if CountryMain then
        local _countryData = CountryMain._countryData or {}
        if _countryData and _countryData.memberNum and _countryData.memberLimit then
            _countryData.memberNum = table.nums(self._memberData)
            if CountryMain._member_label then
                local _str = zc.lang("country_member") .. ":" .. _countryData.memberNum .. "/" .. _countryData.memberLimit
                CountryMain._member_label:setString(_str)
            end
        end
        self._countryData = _countryData
    end
end

function CountryMemberListLayer:memberListSort()
    for i=1, #self._memberData do
        local v = self._memberData[i]
        if tonumber(GAMEUID) == tonumber(v.userId) then
            self._my_positionId = v.countryPositionId
            self._contribution = tonumber(v.contribution) or 0
            self._nowTableIndex = i
            break
        end
    end
    
    local function comp(a,b)
        return tonumber(a.countryPositionId) < tonumber(b.countryPositionId)
    end
    table.sort(self._memberData,comp)
    self:freshMyPositionLab()
end

function CountryMemberListLayer:refreshMemberList()
    zc.sendHttp({
        apiName = "Country_memberList",
        params = {id=self._countryData.id},
        successCallback = function (data)
            self._memberData = data
            self:memberListSort()

            self._memberTable:reloadDataAndScrollToCurrentCell()
        end,
    })
end
function CountryMemberListLayer:initUI()
    self:initMemberList()

    --下方信息
    local attr_bg = ccui.Scale9Sprite:create( cc.rect( 589/2, 0, 1, 66 ), "res/Main/role/trinket/sellDi.png" )
    attr_bg:setContentSize( cc.size(565, 66) )
    attr_bg:setAnchorPoint(cc.p(0.5, 0))
    attr_bg:setPosition(cc.p(self:getContentSize().width/2, 0))
    self:addChild(attr_bg,1)
    
    local _touchHide = ZCSprite:create()
    _touchHide:setContentSize(attr_bg:getContentSize())
    _touchHide:setAnchorPoint(0.5, 0)
    _touchHide:setPosition(attr_bg:getPosition())
    attr_bg:addChild( _touchHide )
    _touchHide:setTouchEndedCallback(function() end)

    local _tipBg = zc.getScaleNode("res/Main/role/common/shadow_bg.png", cc.size(260, 43))
    _tipBg:setAnchorPoint(cc.p(0,0.5))
    _tipBg:setPosition( 20, attr_bg:getContentSize().height/2 )
    attr_bg:addChild( _tipBg )


    cc.SpriteFrameCache:getInstance():addSpriteFrames("res/Main/home/homeUI.plist", "res/Main/home/homeUI.pvr.ccz")
    local _tipSp = zc.getSprite({
        src = "home_icon_info.png",
        plist = true,
        pos = cc.p( 15, 43/2 ),
        scale = 0.5,
    })
    _tipBg:addChild( _tipSp )

    local _tipLabel = zc.createLabel({
        outLine = true,
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(25, 43/2),
        color = cc.c3b(203,183,123)
    })
    _tipBg:addChild( _tipLabel )
    self._myPositionLab = _tipLabel

    --叛国按钮
    self._quitCountryButton = zc.createCommomBtn({
        tag = 3,
        scale = 0.6,
        touchScale = 0.9,
        touchSize =  cc.size(140, 70),
        pos = cc.p( 355, attr_bg:getContentSize().height/2 ), 
        text = zc.lang("country_quit"),
        fontSize = 30,
        listener = function () 
            local function doQuit()
                --退出国家
                zc.sendHttp({
                    apiName = "Country_quit",
                    successCallback = function(data)
                        PlayerData:setBaseInfoByTag("countryId",0)
                        PlayerData:setBaseInfoByTag("countryName","")
                        LayerManager.removeLayout()
                    end,
                })
            end
            local comfirm = ZCConfirmDialog:createWithParams({
                title = zc.lang("prompt"),
                msg = zc.lang("tips_is_out_country"),
                showDi = true,
                rightCallback = function()
                    doQuit()
                end
            })
            local CountryMain = zc.getScene("Country")
            CountryMain:addChild(comfirm, 11)
        end,
    })
    attr_bg:addChild(self._quitCountryButton, 14)


    self._shengguanBtn = zc.createCommomBtn({
        tag = 5,
        scale = 0.6,
        touchScale = 0.9,
        pos = cc.p( 480, attr_bg:getContentSize().height/2 ), 
        text = zc.lang("promotion"),
        fontSize = 30,
        endCallback = function()
            local _chiefInfo = self:findChief(self._my_positionId)
            if _chiefInfo then
                local _chiefContribution = tonumber(_chiefInfo.contribution) or 0
                if self._contribution <= _chiefContribution then
                    zc.tipInfo(zc.lang("not_conform_to_promotion_candition2"))
                    return
                end
            end
            local _formationData = PlayerData:getNowFormationsInfo()
            self._formationData = _formationData
            local function doShengguan()
                zc.sendHttp({
                    apiName = "Country_upPosition",
                    params = {enableFormationId=self._formationData.formationId,formationInfo=self:getFormationString() },
                    successCallback = function (data)
                        --
                        self:resetAllData(data.countryUserList)
                        self:memberListSort()
                        self._memberTable:reloadData()
                        if self._nowTableIndex then
                            self._memberTable:scrollToCell(self._nowTableIndex-1,false)
                        end
                        if data.warModel and next(data.warModel) then
                            ----
                            local _data = {}
                            _data.data = data
                            _data.canShare = true
                            local battle = zc.createBattle({data = _data})
                            battle:play()
                        end
                    end,
                    errorCallback = function( errorCode , errorMsg)
                        zc.tipInfo(errorMsg)
                        if errorMsg == zc.lang("not_conform_to_promotion_candition") then
                            self:refreshMemberList()            
                        end
                    end,
                })
            end
            local _tipMsg = zc.lang("direct_promotion")
            if _chiefInfo and _chiefInfo.countryPositionId then
                local chiefStatic = gameData.getDataFromCacheWithPrimaryKey("country_position", self._my_positionId)
                local _guanName = chiefStatic.name or ""
                _tipMsg = zc.lang("promotio_need_fight") .. " ".._guanName.."【".._chiefInfo.userName .."】" .. zc.lang("is_to_fight") .. "？"
            end
            local comfirm = ZCConfirmDialog:createWithParams({
                title = zc.lang("prompt"),
                msg = _tipMsg,
                showDi = true,
                rightCallback = function()
                    doShengguan()
                end
            })
            local CountryMain = zc.getScene("Country")
            CountryMain:addChild(comfirm, 11)
        end,
    })
    attr_bg:addChild(self._shengguanBtn, 14)

    self:freshMyPositionLab()
-----------------------------------
end

function CountryMemberListLayer:freshShenguanBtn()
    if not self._shengguanBtn then
        return
    end
    if tonumber(self._my_positionId) == 1 then
        self._shengguanBtn:setEnable(false)
        return
    end
    self._shengguanBtn:setEnable(true)
end

function CountryMemberListLayer:freshMyPositionLab()
    if not self._myPositionLab then
        return
    end
    local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", self._my_positionId)
    self._myPositionLab:setString(zc.lang("my_promotion") .. ":" .. (_data.name or ""))
    self:freshShenguanBtn()
end
-- 获取当前阵法的字符串数据
function CountryMemberListLayer:getFormationString()
    local formationString = tostring( self._formationData.formationId )..":"..self._formationData["location1"]
    for i = 2, 9 do
        formationString = formationString.."_"..self._formationData["location"..i]
    end
    return formationString
end
function CountryMemberListLayer:initMemberList()
    local _tableSize = cc.size(565, 464 - 66)
    local _tableView = zc.ZCTableView:create(_tableSize)
    _tableView:setPosition(0, 66)
    _tableView:setInertia(true)
    _tableView:setBounceable(true)
    _tableView:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) 
    -- _tableView:setDirection(zctech.SCROLLVIEW_DIRECTION_BOTH) 
    _tableView:setDelegate()
    _tableView:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    self:addChild(_tableView)
    self._memberTable = _tableView

    local _cellSize = cc.size(565, 125)

    local function numberOfCellsInTableView( table )
        return #self._memberData
    end
    local function cellSizeForTable( table, index )
        return _cellSize.height , _cellSize.width
    end
    local function tableCellAtIndex( table, index )
        local cell = table:dequeueCell()
        if cell then
            cell:removeAllChildren()
        else
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(_cellSize)
        end

        local _di = zc.createImageView({
            src = "res/Main/country/main/country_item_bg.png",
            ap = cc.p(0.5,0.5),
            pos = cc.p(_cellSize.width/2, 55),
        })

        cell:addChild(_di)
        self:createOneCell(_di, index)
        return cell
    end
    _tableView:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW )
    _tableView:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX )
    _tableView:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX )
    _tableView:reloadData()
end

--查找上级
function CountryMemberListLayer:findChief(_posId)
    for i = 1, #self._memberData do
        local v = self._memberData[i]
        if v and v.countryPositionId then
            if tonumber(v.countryPositionId) == (tonumber(_posId) - 1) then
                return v
            end
        end
    end
    return nil
end
function CountryMemberListLayer:resetAllData( data )
    local _data = data or {}
    local uidToInfo = {}
    for k,v in pairs(_data) do
        if v and v.userId then
            uidToInfo[tonumber(v.userId)] = v
        end
    end
    --
    for i = 1, #self._memberData do
        local v = self._memberData[i]
        if v and v.userId then
            local _useInfo = uidToInfo[tonumber(v.userId)] or {}
            if _useInfo and _useInfo.positionId then
                v["countryPositionId"] = _useInfo.positionId
            end
        end
    end
end
function CountryMemberListLayer:createOneCell( cell, index )
    local _member_data = self._memberData[index+1]
    -- dump(_member_data, "_member_data ================== ")
    if _member_data then
        if tonumber(GAMEUID) == tonumber(_member_data.userId) then 
            cell:loadTexture("res/Main/country/main/country_item2_bg.png")

            -- local _selfPositionId = tonumber(_member_data.countryPositionId)
            -- if _selfPositionId == 1 then
            -- else
            --     local chiefInfo = self:findChief(_member_data.countryPositionId)
            --     local _canLevelUp = false --能否升官
            --     if chiefInfo and chiefInfo.contribution then
            --         if tonumber(_member_data.contribution) > tonumber(chiefInfo.contribution) then
            --             _canLevelUp = true
            --         end
            --     else
            --         _canLevelUp = true
            --     end
            --     if _canLevelUp then
            --         -- 自己 升官
            --         local shengguan = zc.createCommomBtn({
            --             tag = 5,
            --             scale = 0.6,
            --             touchScale = 0.9,
            --             pos = cc.p( 475, cell:getContentSize().height/2 ), 
            --             text = zc.lang("promotion"),
            --             fontSize = 30,
            --             listener = function () 
            --                 local _formationData = PlayerData:getNowFormationsInfo()
            --                 self._formationData = _formationData
            --                 local function doShengguan()
            --                     zc.sendHttp({
            --                         apiName = "Country_upPosition",
            --                         params = {enableFormationId=self._formationData.formationId,formationInfo=self:getFormationString() },
            --                         successCallback = function (data)
            --                             --
            --                             self:resetAllData(data.countryUserList)
            --                             self:memberListSort()
            --                             self._memberTable:reloadData()
            --                             if self._nowTableIndex then
            --                                 self._memberTable:scrollToCell(self._nowTableIndex-1,false)
            --                             end
            --                             if data.warModel and next(data.warModel) then
            --                                 ----
            --                                 local _data = {}
            --                                 _data.data = data
            --                                 _data.canShare = true
            --                                 _data.isFirstFight = true
            --                                 local battle = zc.createBattle({data = _data})
            --                                 battle:play()
            --                             end
            --                         end,
            --                         errorCallback = function( errorCode , errorMsg)
            --                             zc.tipInfo(errorMsg)
            --                             if errorMsg == zc.lang("not_conform_to_promotion_candition") then
            --                                 self:refreshMemberList()            
            --                             end
            --                         end,
            --                     })
            --                 end
            --                 local _tipMsg = zc.lang("direct_promotion")
            --                 if chiefInfo and chiefInfo.countryPositionId then
            --                     local chiefStatic = gameData.getDataFromCacheWithPrimaryKey("country_position", chiefInfo.countryPositionId)
            --                     local _guanName = chiefStatic["name"]
            --                     _tipMsg = zc.lang("promotio_need_fight") .. " ".._guanName.."【"..chiefInfo.userName .."】" .. zc.lang("is_to_fight") .. "？"
            --                 end
            --                 local comfirm = ZCConfirmDialog:createWithParams({
            --                     title = zc.lang("prompt"),
            --                     msg = _tipMsg,
            --                     showDi = true,
            --                     rightCallback = function()
            --                         doShengguan()
            --                     end
            --                 })
            --                 local CountryMain = zc.getScene("Country")
            --                 CountryMain:addChild(comfirm, 11)
            --             end,
            --         })
            --         cell:addChild(shengguan, 14)
            --     end
            -- end
        end
        -- 头像
        local _heroIcon = zc.createIconByData({
            data = {
                mainType = zc.mainTypeSoldier,
                type = 1, 
                id = tonumber(_member_data.seigniorId)+100,
                quality = 1,
                level = zc.getLevelTipShow().._member_data.level,
            },
            showLevel = true,
            mainRoleIcon = _member_data.iconId,
            pos = cc.p( 70, 50 ),
            listener = function()
                zc.createOtherPlayerSelect(_member_data.userId)
            end,
        })
        _heroIcon:setScale(0.65)
        cell:addChild(_heroIcon)
        --成员职位
        local _position_bg = zc.createImageView({
            src = "res/Main/country/main/country_member_name_bg.png",
            ap = cc.p(0,0.5),
            pos = cc.p(-2, 109)
        })
        cell:addChild(_position_bg)
        local _position_name = ""
        local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", _member_data.countryPositionId)
        if next(_data) ~= nil then
            _position_name = _data.name
        end
        local _country_position_label = zc.createLabel({
            text = _position_name,
            fontSize = 20,
            ap = cc.p(0,0.5),
            outLine = true,
            pos = cc.p(5, 12),
            color = cc.c3b(244,180,41),
        })
        _position_bg:addChild(_country_position_label)
        local _member_name_bg = zc.createSprite("res/Main/country/main/member_name_bg.png")
        _member_name_bg:setAnchorPoint(0, 0.5)
        _member_name_bg:setPosition(108, 70)
        cell:addChild(_member_name_bg)
        --成员名称
        local _member_name_label = zc.createLabel({
            text = _member_data.userName,
            fontSize = 20,
            ap = cc.p(0,0.5),
            outLine = true,
            -- pos = cc.p(120, 70),
            pos = cc.p(10, _member_name_bg:getContentSize().height/2),
        })
        _member_name_bg:addChild(_member_name_label)
        --贡献
        local _contribution_bg_s =  zc.createScale9Sprite({
            size = cc.size(140, 40),
            file = "res/Main/country/main/country_notice_bg_s.png",
            pos = cc.p(110, 10),
        })
        _contribution_bg_s:setAnchorPoint(cc.p(0,0))
        cell:addChild(_contribution_bg_s)
        local _contribution_label = zc.createLabel({
            text = zc.lang("country_contribution") ..  _member_data.contribution,
            fontSize = 18,
            ap = cc.p(0,0.5),
            outLine = true,
            pos = cc.p(5, 20),
            color = cc.c3b(254,243,205),
        })
        _contribution_bg_s:addChild(_contribution_label)
        --今日贡献
        local _today_contribution_bg_s =  zc.createScale9Sprite({
            size = cc.size(140, 40),
            file = "res/Main/country/main/country_notice_bg_s.png",
            pos = cc.p(260, 10),
        })
        _today_contribution_bg_s:setAnchorPoint(cc.p(0,0))
        cell:addChild(_today_contribution_bg_s)
        local _today_contribution_label = zc.createLabel({
            text = zc.lang("country_today_contribution") ..  _member_data.todayContribution,
            fontSize = 18,
            ap = cc.p(0,0.5),
            outLine = true,
            pos = cc.p(5, 20),
            color = cc.c3b(254,243,205),
        })
        _today_contribution_bg_s:addChild(_today_contribution_label)

        --在线
        local _text = zc.lang("on_line")
        if tonumber(_member_data.online) == 0 then
            local time = tonumber(PlayerData:getTime())-tonumber(_member_data.lastLoginTime)
            local D = math.floor(time/(24*3600))
            local H = math.floor(time/3600-D*24)
            local M = math.floor(time/60 - H*60)
            local S = math.floor(time%60) == 0 and 1 or math.floor(time%60)
            local timeStr = ""
            if D > 0 then
                timeStr = D..zc.lang("date_day") .. zc.lang("front")    --"天前"
            elseif H > 0 then
                timeStr = H..zc.lang("date_hours") .. zc.lang("front")  --"小时前"
            elseif M > 0 then
                timeStr = M..zc.lang("date_minute") .. zc.lang("front") --"分钟前"
            elseif S > 0 then
                timeStr = S..zc.lang("date_seconds") .. zc.lang("front") --"秒前"
            end
            _text = timeStr
        end
        local _online_label = zc.createLabel({
            text = _text,
            fontSize = 18,
            ap = cc.p(0.5,0.5),
            outLine = true,
            pos = cc.p(320, 70),
            color = cc.c3b(5,252,101),
        })
        cell:addChild(_online_label)

        --踢人
        local _flag = self:isCanTiren(_member_data.countryPositionId)
        if _flag then
            local _tr_button = zc.createCommomBtn({
                tag = 3,
                needSwallow = false,
                touchScale = 0.9,
                scale = 0.6,
                text = zc.lang("country_tichu"),
                fontSize = 30,
                endCallback = function()
                    local function dotiren()
                        zc.sendHttp({
                            apiName = "Country_kickout",
                            params = {uid=_member_data.userId},
                            successCallback = function (data)
                               zc.tipInfo(zc.lang("tips_kick_out_success"))
                               self:removeMemberByUserId(_member_data.userId)
                               self._memberTable:reloadDataAndScrollToCurrentCell()
                                local CountryMain = zc.getScene("Country")
                                if CountryMain then
                                    local _countryData = CountryMain._countryData or {}
                                    if _countryData and _countryData.memberNum and _countryData.memberLimit then
                                        local _memberNum = tonumber(_countryData.memberNum) - 1
                                        _countryData.memberNum = _memberNum
                                        if CountryMain._member_label then
                                            local _str = zc.lang("country_member") .. ":" .. _memberNum .. "/" .. _countryData.memberLimit
                                            CountryMain._member_label:setString(_str)
                                        end
                                    end
                                end
                            end,
                            errorCallback = function( errorCode , errorMsg)
                                zc.tipInfo(errorMsg)
                                if errorMsg == zc.lang("country_permission_unenough") then
                                    self:refreshMemberList()            
                                end
                            end,
                        })
                    end
                    local comfirm = ZCConfirmDialog:createWithParams({
                        title = zc.lang("prompt"),
                        msg = zc.lang("tips_is_to_kick_out"),
                        showDi = true,
                        rightCallback = function()
                            dotiren()
                        end
                    })
                    local CountryMainLayer = zc.getScene("Country")
                    CountryMainLayer:addChild(comfirm, 11)
                end,
                pos = cc.p( 475, 55 ),
            })
            cell:addChild(_tr_button)
            cell._tr_button = _tr_button
            if tonumber(self._my_positionId) == 1 then
                _tr_button:setPositionY(85)
            end
        end

        -- --禅让
        if tonumber(self._my_positionId) == 1 and tonumber(_member_data.countryPositionId) ~= 1 then
            local _sr_button = zc.createCommomBtn({
                tag = 3,
                needSwallow = false,
                touchScale = 0.9,
                scale = 0.6,
                btnText = zc.lang("country_shanrang"),
                fontSize = 30,
                endCallback = function()
                    local function doShanrang()
                        zc.sendHttp({
                            apiName = "Country_demise",
                            params = {uid=_member_data.userId},
                            successCallback = function (net_data)
                                zc.tipInfo(zc.lang("tips_demise_success"))
                                for k,v in pairs(self._memberData) do
                                    if v and v.countryPositionId and tonumber(v.countryPositionId) == 1 then
                                        v.countryPositionId = tostring(_member_data.countryPositionId)
                                        self._my_positionId = tonumber(_member_data.countryPositionId)
                                        break
                                    end
                                end
                                _member_data.countryPositionId = "1"
                                table.sort(self._memberData,function(a, b)
                                    return tonumber(a.countryPositionId) < tonumber(b.countryPositionId)
                                end)
                                self._memberTable:reloadDataAndScrollToCurrentCell()

                                local CountryMain = zc.getScene("Country")
                                if CountryMain then
                                    --禅让后国家数据修改
                                    local _countryData = CountryMain._countryData or {}
                                    local monarchInfo = _countryData.monarchInfo or {}
                                    monarchInfo.userName = _member_data.userName
                                    monarchInfo.userId = _member_data.userId
                                    monarchInfo.iconId = _member_data.iconId
                                    _countryData.countryPositionId = self._my_positionId
                                    _countryData.monarchName = _member_data.userName
                                    --判断权限
                                    local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", self._my_positionId) or {}
                                    local _privileges = _data.privileges or ""
                                    local _priData = string.split(_privileges,",")
                                    local _hasSettingPrivilege = false --是否有设置权限
                                    for i = 1, #_priData do
                                        if _priData[i] and (tonumber(_priData[i]) == 1 or tonumber(_priData[i]) == 2) then
                                            _hasSettingPrivilege = true
                                            break
                                        end
                                    end
                                    if not _hasSettingPrivilege then
                                        local _tabButtonList = CountryMain._tabButtonList
                                        if _tabButtonList and _tabButtonList[#_tabButtonList] then
                                            _tabButtonList[#_tabButtonList]:setVisible(false) 
                                        end
                                    end
                                end
                                self:freshShenguanBtn()
                            end,
                            errorCallback = function( errorCode , errorMsg)
                                zc.tipInfo(errorMsg)
                                if errorMsg == zc.lang("country_permission_unenough") then
                                    self:refreshMemberList()            
                                end
                            end,
                        })
                    end
    
                    local comfirm = ZCConfirmDialog:createWithParams({
                        title = zc.lang("prompt"),
                        msg = string.format(zc.lang("tips_is_to_demise_to"), tostring(_member_data.userName)),
                        showDi = true,
                        rightCallback = function()
                            doShanrang()
                        end
                    })
                    local CountryMainLayer = zc.getScene("Country")
                    CountryMainLayer:addChild(comfirm, 11)
                end,
                pos = cc.p( 475, 30 ),
            })
            cell._sr_button = _sr_button
            cell:addChild(_sr_button)
        end

    end
end

--国家职位权限
function CountryMemberListLayer:getCountryPrivileges(_positionId)
    local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", _positionId)
    local _privileges = ""
    if next(_data) ~= nil then
        _privileges = _data.privileges
    end
    local _data = {}
    if tonumber(_str) ~= 0 then 
        _data = string.split(_privileges,",")
    else
        _data = nil
    end
    return _data
end
--是否可以踢人
function CountryMemberListLayer:isCanTiren(_positionId)
    local _data = self:getCountryPrivileges(self._my_positionId)
    local _flag = false
    if _data then
        for k,v in pairs(_data) do
            if tonumber(v) == 5 and tonumber(self._my_positionId) < tonumber(_positionId) then  --可以踢人
                _flag = true
            end
        end
    end
    return _flag
end
--根据userid移除国家成员
function CountryMemberListLayer:removeMemberByUserId(_userId)
    for k,v in pairs(self._memberData) do
        if tonumber(v.userId) ==  tonumber(_userId) then
            table.remove(self._memberData,k)
            break
        end
    end
end

return CountryMemberListLayer