--[[
    FileName: FriendPop.lua
    Author: andong
    Date: 2016-03-21
    Purpose: 好友弹窗
]]
local FriendPop = class( "FriendPop", function ()
    return zc.createNormalDialog({
        closeCallBack = function()
            LayerManager.removeLayout(nil, nil, false)
        end
    })
end)
function FriendPop:create(params)
    return FriendPop.new(params)
end
function FriendPop:ctor(params)
    self:initData(params)
    self:initUI()
end
function FriendPop:initData(params)
    self._friendData = params.friends
    self._applyData = params.pendings
    self._blackData = params.blacklists

    --数据处理
    self._friendNum = 0 --好友数量
    self._friendNumLimit = 80
    self._onlineFriendNum = 0 --在线好友数量
    for i = 1, #self._friendData do
        self._friendNum=self._friendNum+1
        if self._friendData[i].online and tonumber(self._friendData[i].online) == 1 then --1 在线 0 不在线
            self._onlineFriendNum=self._onlineFriendNum+1
        end
    end
    self._applyMap = {} --对好友申请列表做一个映射,在一键处理的时候提高效率
    self._applyNum = #self._applyData --申请数量
    for i = 1, #self._applyData do
        self._applyMap[tonumber(self._applyData[i].id)] = i
    end
    self._energyNum = PlayerData:getFriendSendEnergyNum()

    if params.tag then --如果外界有传递tag
        self._tag = tonumber(params.tag) 
    else
        self._tag = 1 --起始tab标签为好友 2为申请 3为黑名单
    end

    zc.addEventListener({
        name = CUSTOM_EVENT.EVENT_REFRESH_FRIENDINFO ,
        callback = function()
            self:resetData()
        end
    })
end
function FriendPop:resetData()
    self._friendData = {}
    self._applyData = {}
    self._blackData = {}

    local friendInfo = table.copy(PlayerData:getFriendInfo())
    -- dump(friendInfo, "friendInfo resetData ============== ")
    self._friendData = friendInfo["friends"] or {}
    self._applyData = friendInfo["pendings"] or {}
    self._blackData = friendInfo["blacklists"] or {}

    local newApplyData = {} --重新整理好友申请数据
    self._applyMap = {} --重新调整映射
    for k,v in pairs(self._applyData) do
        local nowId = #newApplyData+1
        newApplyData[nowId]=v
        self._applyMap[tonumber(v.id)] = nowId
    end
    self._applyData = newApplyData

    self._friendNum = table.nums(self._friendData) or 0
    self._friendNumLab:setString(self._friendNum.."/"..self._friendNumLimit)

    self:showNoFriendAndReload()
end
function FriendPop:initUI()
    local popBg = zc.createNormalPop({
        tag = 2,
        src = "res/Main/common/popBg/bgWhite.png",
        bianZOrder = 1,
        height = 550,
    })
    popBg:setPosition(zc.width*0.5, zc.height*0.5 - 20)
    self:addChild(popBg)
    popSize = popBg:getContentSize()

    local head = zc.createImageView({
        src = "res/Main/friend/title.png",
        ap = cc.p(0, 0),
        pos = cc.p(-42, popSize.height-64),
    })
    popBg:addChild(head, 10)

    local friendNumBg = zc.createImageView({
        src = "res/Main/copy/leftTimesBg.png",
        ap = cc.p(1, 1),
        pos = cc.p(popSize.width - 71, popSize.height-9),
    })
    popBg:addChild(friendNumBg, 10)
    
    local friendNumLab = zc.createLabel({
        text = zc.lang("friends_num") .. ":",
        stroke = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(30, friendNumBg:getContentSize().height/2),
        color = display.COLOR_WHITE,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    friendNumBg:addChild(friendNumLab)
    local friendNumLab = zc.createLabel({
        text = self._friendNum.."/"..self._friendNumLimit,
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(friendNumLab:getPositionX()+friendNumLab:getContentSize().width, friendNumBg:getContentSize().height/2-1),
        color = display.COLOR_GREEN,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    friendNumBg:addChild(friendNumLab)
    self._friendNumLab = friendNumLab
    
    -- local leftTabBg = ccui.Scale9Sprite:create(cc.rect(25,25,1,1), "res/Main/setting/scale9_1.png")
    local leftTabBg = cc.Sprite:create()
    leftTabBg:setContentSize(cc.size(147, 446))
    leftTabBg:setAnchorPoint(cc.p(0, 0))
    leftTabBg:setPosition(cc.p(12, 17))
    popBg:addChild(leftTabBg, 1)

    local rightInfoBg = ccui.Scale9Sprite:create(cc.rect(25,25,1,1), "res/Main/setting/scale9_1.png")
    -- local rightInfoBg = cc.Sprite:create()
    rightInfoBg:setContentSize(cc.size(703, 448))
    rightInfoBg:setAnchorPoint(cc.p(1, 0))
    rightInfoBg:setPosition(cc.p(popSize.width - 8, 17))
    popBg:addChild(rightInfoBg)
    self._rightInfoBg = rightInfoBg

    --tab
    local nameTab = {[1]=zc.lang("friend"),[2]=zc.lang("apply_for"),[3]=zc.lang("black_list")}
    for i = 1, #nameTab do
        local tabBtn = zc.createTypeBtn({
            btnText = nameTab[i],
            pos = cc.p(leftTabBg:getContentSize().width/2, 390-(i-1)*73),
            endCallback = function() end,
        })
        tabBtn:setTag(i)
        leftTabBg:addChild(tabBtn)
        tabBtn:setTouchEndedCall(function()
            self:changeTab(tabBtn)
        end)
        if (i == 1 and self._energyNum > 0) or (i == 2 and self._applyNum > 0) then
            local redDot = cc.Sprite:create("res/Main/friend/redDot.png")
            redDot:setAnchorPoint(0.5, 0.5)
            redDot:setPosition(tabBtn:getContentSize().width-5, tabBtn:getContentSize().height-5)
            tabBtn:addChild(redDot, 10)
            local redDotLab = zc.createLabel({
                outLine = true,
                fontSize = 18,
                pos = cc.p(redDot:getContentSize().width/2, redDot:getContentSize().height/2),
                color = display.COLOR_WHITE,
                color2 = display.COLOR_BLACK,
                align = kCCTextAlignmentCenter,
                pixel = 1.3
            })
            redDot:addChild(redDotLab)
            if i == 1 then
                self._energyRedDot = redDot
                if self._energyNum > 0 then
                    redDotLab:setString(self._energyNum)
                end
                self._energyRedDotLab = redDotLab
            else
                redDotLab:setString(self._applyNum)
                self._applyRedDot = redDot
                self._applyRedDotLab = redDotLab
            end
        end
        if i == self._tag then
            self:changeTab(tabBtn)
        end
    end
end

--tab切换
function FriendPop:changeTab(_node)

    if not self._selectedBtn or self._selectedBtn ~= _node then
        local _tag = _node:getTag()
        if not self._selectedBtn then
            self._selectedBtn = _node
            self._selectedBtn:setSelected(true)
        else
            self._selectedBtn:setSelected(false)
            self._selectedBtn = _node
            self._selectedBtn:setSelected(true)
        end
        self._tag = _tag
        if _tag == 1 then --好友
            self:initRightInfo(self._friendData)
            local _getNum = PlayerData:getFriendSendEnergyNum()
            if _getNum > 0 then

            end
        elseif _tag == 2 then --申请
            if self._applyRedDot then
                local dotParent = self._applyRedDot:getParent()
                self._applyRedDot:setPosition(dotParent:getContentSize().width-10, dotParent:getContentSize().height-10)
            end
            self:initRightInfo(self._applyData)
        elseif _tag == 3 then --黑名单
            self:initRightInfo(self._blackData)
        end
    end
end

function FriendPop:initRightInfo(data)
    self._rightInfoBg:removeAllChildren()
    self._myTable = nil

    if self._tag ~= 3 then
        self:createBottomInfo()
    end
    local no_friend = zc.createImageView({
        src = "res/Main/friend/no_friend.png",
        pos = cc.p(self._rightInfoBg:getContentSize().width/2, self._rightInfoBg:getContentSize().height/2 + 20),
    })
    self._rightInfoBg:addChild(no_friend)
    self._no_friend = no_friend

    if not data or not next(data) then --没有好友
        self._no_friend:setVisible(true)
    else
        self._no_friend:setVisible(false)
        local tableSize = cc.size(self._rightInfoBg:getContentSize().width, self._rightInfoBg:getContentSize().height-2)
        if self._tag ~= 3 then
            tableSize = cc.size(tableSize.width, tableSize.height-72)
        end
        local tableNode = self._rightInfoBg
        
        -- local myTableBg = ccui.Scale9Sprite:create(cc.rect(25,25,1,1), "res/Main/setting/scale9_1.png")
        local myTableBg = cc.Sprite:create()
        myTableBg:setContentSize(tableSize)
        myTableBg:setAnchorPoint(cc.p(0.5, 1))
        myTableBg:setPosition(cc.p(tableNode:getContentSize().width/2, tableNode:getContentSize().height))
        tableNode:addChild(myTableBg)
        
        local myTable = zc.ZCTableView:create(cc.size(myTableBg:getContentSize().width-4,myTableBg:getContentSize().height-8))
        myTable:setPosition(2,4)
        myTable:setInertia(true) --设置惯性
        myTable:setBounceable(true)
        myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) --设置横向纵向
        myTable:setDelegate()
        myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
        
        myTableBg:addChild(myTable)

        self._myTable = myTable
        
        local function cellSizeForTable(table,idx)
            return 95, tableSize.width-4
        end
        local function numberOfCellsInTableView(table)
            -- return 10
            if self._tag == 1 then
                return #self._friendData
            elseif self._tag == 2 then
                return #self._applyData
            elseif self._tag == 3 then
                return #self._blackData
            end
        end
        local function tableCellAtIndex(table,idx)
            local nowIdx = idx + 1
            local cell = table:dequeueCell()
            if cell == nil then
                cell = zc.ZCTableViewCell:new()
                cell:setContentSize(cc.size(tableSize.width-4, 95))
            else
                cell:removeAllChildren()
            end
            
            return self:updateCell(cell, nowIdx)
        end
        myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
        myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
        myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
        
        self:showNoFriendAndReload()
    end
end

function FriendPop:updateCell(cell, nowIdx)

    local cellSize = cell:getContentSize()
    local cellData
    if self._tag == 1 then
        cellData = self._friendData[nowIdx]
    elseif self._tag == 2 then
        cellData = self._applyData[nowIdx]
    elseif self._tag == 3 then
        cellData = self._blackData[nowIdx]
    end
    -- dump(cellData ,"cellData----")
    local cell_img = zc.createImageView({
        src = "res/Main/friend/cell_img.png",
        ap = cc.p(0.5, 0.5),
        pos = cc.p(cell:getContentSize().width/2, cell:getContentSize().height/2),
    })
    cell:addChild(cell_img)

    local head =  zc.createPlayerHead({
        iconId = tonumber(cellData.iconId),
        callback = function() 
            zc.sendHttp({
                apiName = "User_otherPlayer",
                params = {targetUserId=cellData.userId},
                successCallback = function (data)
                    zc.createPop("otherPlayerSelect", data)
                end,
            })
        end,
        scale = 0.86,
        level = cellData.level,
        needSwallow = false,
        needEnableWhenMoving = true,
    })
    head:setPosition(46, cell_img:getContentSize().height/2)
    cell_img:addChild(head)

    local shadow = zc.getScaleNode("res/Main/role/common/shadow_bg.png", cc.size(65, 20))
    shadow:setAnchorPoint(cc.p(0.5, 1))
    shadow:setPosition(cc.p(head:getContentSize().width/2, head:getContentSize().height-9))
    head:addChild(shadow)
    if cellData.online and tonumber(cellData.online) == 1 then
        local onlineLab = zc.createLabel({
            text = zc.lang("on_line"),
            fontSize = 16,
            pos = cc.p(shadow:getContentSize().width/2, shadow:getContentSize().height/2),
            color = display.COLOR_GREEN,
        })
        shadow:addChild(onlineLab)
    elseif cellData.lastLoginTime then
        local timeStr = ""
        if tonumber(cellData.lastLoginTime) > 0 then
            local time = tonumber(PlayerData:getTime())-tonumber(cellData.lastLoginTime)
            local D = math.floor(time/(24*3600))
            local H = math.floor(time/3600-D*24)
            local M = math.floor(time/60 - H*60)
            local S = math.floor(time%60) == 0 and 1 or math.floor(time%60)
            if D > 0 then
                timeStr = D .. zc.lang("date_day") .. zc.lang("front")
            elseif H > 0 then
                timeStr = H .. zc.lang("date_hours") .. zc.lang("front")
            elseif M > 0 then
                timeStr = M .. zc.lang("date_minute") .. zc.lang("front")
            elseif S > 0 then
                timeStr = S .. zc.lang("date_seconds") .. zc.lang("front")
            end
        end
        local timeStrLab = zc.createLabel({
            text = timeStr,
            stroke = false,
            fontSize = 16,
            pos = cc.p(shadow:getContentSize().width/2, shadow:getContentSize().height/2),
            color = cc.c3b(227, 206, 169),
        })
        shadow:addChild(timeStrLab)
    end
    
    local nameBg = cc.Sprite:create("res/Main/wushenTower/name_bg_1.png")
    nameBg:setAnchorPoint(0, 0.5)
    nameBg:setPosition(115, cell_img:getContentSize().height/2-3)
    cell_img:addChild(nameBg)

    local weapon = cc.Sprite:create("res/Main/hero/hero_type1.png")
    weapon:setAnchorPoint(0, 0.5)
    weapon:setPosition(-11, nameBg:getContentSize().height/2-8)
    nameBg:addChild(weapon)
    weapon:setScale(0.9)

    local name = zc.createLabel({
        text = ""..cellData.userName,
        outLine = true,
        fontSize = 20,
        ap = cc.p(0, 0),
        pos = cc.p(25, 3),
    })
    nameBg:addChild(name)

    local countryNamStr = (not cellData.countryName or cellData.countryName == "") and "" or "<"..cellData.countryName..">"
    -- countryNamStr = "<五个字的国家>"
    local countryName = zc.createLabel({
        text = countryNamStr,
        -- stroke = true,
        fontSize = 18,
        ap = cc.p(0, 0.5),
        pos = cc.p(15, nameBg:getContentSize().height),
        color = cc.c3b(73, 48, 45),
    })
    nameBg:addChild(countryName)

    --button部分的创建
    local function createBtn(_pos, _type, _text, _callback)
        local _tag = 2
        if _type == "orange" then
            _tag = 1
        end
        local touchBtn = zc.createCommomBtn({
            tag = _tag,
            btnText = _text,
            needSwallow = false,
            endCallback = _callback,
            anchor = cc.p(0.5, 0),
            pos = _pos
        })
        cell_img:addChild(touchBtn)
    end
    if self._tag == 1 then
        local chat_Btn = zc.createPushButton({
            normalFile = "res/Main/friend/chat.png",
            needSwallow = false,
            touchScale = 0.9,
            pos = cc.p(cellSize.width-160,cellSize.height/2),
            endCallback = function()
                local uId = cellData.userId
                local uName = cellData.userName
                local uGodName = cellData.godName
                -- local otherChatPanel = zc.getPop("otherChatPanel")
                local otherChatPanel = zc.getPop("ChatPanel")
                if otherChatPanel then
                    LayerManager.removeLayout(true)
                end
                -- zc.createSourceScene("otherChatPanel", "src/layer/chat/ChatPanelPop.lua",{toUserId = uId, toGodName = uGodName, toUserName = uName, channel = 3, isClose = true})
                zc.createSourceScene("ChatPanel", "src/layer/chat/ChatPanelPop.lua",{toUserId = uId, toGodName = uGodName, toUserName = uName, channel = 3, isClose = true})
            end,
        })
        cell_img:addChild(chat_Btn)

        local _energyPath = "res/Main/friend/energy_no.png"
        local _sendState = 1
        if cellData.getEnergyStatus and tonumber(cellData.getEnergyStatus) == 1 then --有体力可领取
            _energyPath = "res/Main/friend/energy_get.png"
            _sendState = 2
        elseif cellData.sendEnergyStatus and tonumber(cellData.sendEnergyStatus) == 0 then --今日可赠送
            _energyPath = "res/Main/friend/energy_send.png"
            _sendState = 3
        end
        
        local energy_Btn = zc.createPushButton({
            normalFile = _energyPath,
            needSwallow = false,
            touchScale = 0.9,
            pos = cc.p(cellSize.width-66,cellSize.height/2),
            endCallback = function()
                if _sendState == 1 then
                    zc.tipInfo(zc.lang("tips_today_have_send"))
                elseif _sendState == 2 then
                    zc.sendHttp({
                        apiName = "Friend_get_energy",
                        params = {id=cellData.id},
                        successCallback = function (net_data)
                            PlayerData:updataData( net_data )
                            cellData.getEnergyStatus = 2
                            self:showNoFriendAndReload()
                            PlayerData:updateFriendInfoByType(cellData, "friends")
                            PlayerData:addFriendSendEnergyNum(-1)
                            self:deleteEnergyRedDot()
                        end
                    })
                elseif _sendState == 3 then
                    zc.sendHttp({
                        apiName = "Friend_send_other_energy",
                        params = {targetUserId=cellData.userId},
                        successCallback = function (net_data)
                            zc.tipInfo(zc.lang("tips_tili_send_success"))
                            cellData.sendEnergyStatus = 1
                            self:showNoFriendAndReload()
                            PlayerData:updateFriendInfoByType(cellData, "friends")
                        end
                    })
                end
            end,
        })
        cell_img:addChild(energy_Btn) 

        local _titleName = {
            [1]={name=zc.lang("renqi"),num=cellData.allgroup or 0},
            [2]={name=zc.lang("youqing"),num=cellData.group or 0},
        }
        for i = 1, 2 do
            local renqiSize = cc.size(157, 30)
            local renqiBg = zc.getScaleNode("res/Main/common/popBg/di_properties.png", renqiSize)
            renqiBg:setAnchorPoint(0, 0.5)
            renqiBg:setPosition(cc.p(309,cellSize.height/2 + (3-2*i)*18 ))
            cell_img:addChild(renqiBg)
            local titleName = zc.createLabel({
                text = _titleName[i].name.."：",
                stroke = false,
                fontSize = 18,
                ap = cc.p(0, 0.5),
                pos = cc.p(8, renqiSize.height/2),
                color = cc.c3b(227,206,169),
            })
            renqiBg:addChild(titleName)
            
            local titleNumber = zc.createLabel({
                text = zc.getWan(_titleName[i].num),
                stroke = false,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(72, renqiSize.height/2),
            })
            renqiBg:addChild(titleNumber)
        end
    elseif self._tag == 2 then
        createBtn(cc.p(428, 8), "blue", zc.lang("jujue_2"), function()
            self:applications(cellData.id, "refuse")
        end)
        createBtn(cc.p(595, 8), "orange", zc.lang("tongyi_2"), function()
            self:applications(cellData.id, "agree")
        end)
    elseif self._tag == 3 then
        createBtn(cc.p(595, 8), "blue", zc.lang("yichu_2"), function()
            self:friendDelete(cellData.userId, nowIdx, cellData.userName,"fromBlackList")
        end)
    end

    return cell
end
--刷新好友信息
function FriendPop:updateInfo(_data)
    if _data and _data.userId then
        local friendInfo = PlayerData:getFriendInfo()
        local friends = friendInfo["friends"] or {}
        for i = 1, #friends do
            local v = friends[i]
            if tonumber(v.userId) == tonumber(_data.userId) then
                for m,n in pairs(_data) do
                    v[m] = _data[m]
                end
                break
            end
        end
    end
end
--删除好友
function FriendPop:friendDelete(_id, _index,_name, _type)
    if _id then
        local function doDelete()
            if _type == "fromFriend" then --从好友列表删除
                zc.sendHttp({
                    apiName = "Friend_remove",
                    params = {id=_id},
                    successCallback = function (net_data)
                        if net_data and net_data.result and tonumber(net_data.result)==1 then
                            --好友数量减1
                            self._friendNum = self._friendNum-1  
                            if self._friendData[_index] and self._friendData[_index].online and tonumber(self._friendData[_index].online) == 1 then
                                self._onlineFriendNum = self._onlineFriendNum  -1
                            end
                            self._friendNumLab:setText(self._friendNum.."/"..self._friendNumLimit)
                            table.remove(self._friendData, _index)
                            PlayerData:setFriendInfo(self._friendData, "friends")
                            self:showNoFriendAndReload()
                        end
                    end,
                    errorCallback = function(_errorCode,_msg)
                        print("-----------log--------ad-------------_msg ", _msg)
                        zc.tipInfo(_msg)
                        if _errorCode and tonumber(_errorCode) == 300 then
                            --好友数量减1
                            self._friendNum = self._friendNum-1  
                            if self._friendData[_index] and self._friendData[_index].online and tonumber(self._friendData[_index].online) == 1 then
                                self._onlineFriendNum = self._onlineFriendNum  -1
                            end
                            self._friendNumLab:setText(self._friendNum.."/"..self._friendNumLimit)
                            table.remove(self._friendData, _index)
                            PlayerData:setFriendInfo(self._friendData, "friends")
                            self:showNoFriendAndReload()
                        end
                    end,
                })
            elseif _type == "fromBlackList" then --从黑名单中移除
                zc.removePlayerFromBlacklist(_id, function()
                    table.remove(self._blackData, _index)
                    PlayerData:setFriendInfo(self._blackData, "blacklists")
                    self:showNoFriendAndReload()
                end)
            end
        end
        local msgStr = zc.lang("tips_sure_to_delete_friend")
        if _type == "fromBlackList" then
            msgStr = zc.lang("tips_sure_to_remove_player_black_list")
        end
        local comfirm = ZCConfirmDialog:createWithParams({
            title = zc.lang("prompt"),
            msg = msgStr,
            showDi = true,
            rightCallback = function()
                doDelete()
            end
        })  
        self:addChild(comfirm, 11)
    end
end
--发送邮件
function FriendPop:sendEmail(_name)
    zc.createEmailPop({tag=3, name=_name, needSend=true})
end
--处理好友申请 包括是否一键处理
function FriendPop:applications(_id, _type, _isOneKey)
    local function refuseUrl(_ids) --拒绝添加
        zc.sendHttp({
            apiName = "Friend_refuse",
            params = {ids=_ids},
            successCallback = function(net_data)
                for i = 1, #net_data do
                    if tonumber(net_data[i].flag) == 1 then
                        local mapId = self._applyMap[tonumber(net_data[i].id)]
                        if mapId and self._applyData[mapId] then
                            self._applyData[mapId] = nil
                        end
                        self._applyNum = self._applyNum - 1
                    end  
                end
                local newApplyData = {}
                 self._applyMap = {} --重新调整映射
                for k,v in pairs(self._applyData) do
                    local nowId = #newApplyData+1
                    newApplyData[nowId]=v
                    self._applyMap[tonumber(v.id)] = nowId
                end
                self._applyData = newApplyData
                PlayerData:setFriendInfo(self._applyData, "pendings")
                self:showNoFriendAndReload()
                self:deleteRedDot()
            end,
        })
    end
    local function agreeUrl(_ids) --同意添加
        zc.sendHttp({
            apiName = "Friend_agree",
            params = {ids=_ids},
            successCallback = function (net_data)
                local addFriend = 0
                local onlineFriend = 0
                for i = 1, #net_data do
                    --flag:1, // 1. 添加失败, 对方好友数量已达上限 2. 添加失败, 在对方的黑名单中 3 添加成功 , 其他的未返回的id表示未处理
                    if tonumber(net_data[i].flag) == 3 then
                        local mapId = self._applyMap[tonumber(net_data[i].id)]
                        if mapId and self._applyData[mapId] then
                            --增加的好友
                            self._friendData[#self._friendData+1] = table.copy(self._applyData[mapId])
                            if self._applyData[mapId].online and tonumber(self._applyData[mapId].online) == 1 then
                                onlineFriend=onlineFriend+1
                            end
                            self._applyData[mapId] = nil
                        end
                        addFriend = addFriend + 1
                        self._applyNum = self._applyNum - 1
                    elseif tonumber(net_data[i].flag) == 2 then
                        zc.tipInfo(zc.lang("tips_add_friend_fail_in_black_list"))
                    elseif tonumber(net_data[i].flag) == 1 then
                        zc.tipInfo(zc.lang("tips_add_friend_fail_in_list_full"))
                    end
                end
                self._friendNum = self._friendNum+addFriend
                self._onlineFriendNum = self._onlineFriendNum +onlineFriend
                self._friendNumLab:setText(self._friendNum.."/"..self._friendNumLimit)
                self:deleteRedDot()
                
                local newApplyData = {} --重新整理好友申请数据
                self._applyMap = {} --重新调整映射
                for k,v in pairs(self._applyData) do
                    local nowId = #newApplyData+1
                    newApplyData[nowId]=v
                    self._applyMap[tonumber(v.id)] = nowId
                end
                self._applyData = newApplyData
                PlayerData:setFriendInfo(self._applyData, "pendings")
                PlayerData:setFriendInfo(self._friendData, "friends")
                self:showNoFriendAndReload()
            end,
        })
    end
    if _id then --单个处理
        if _type == "refuse" then
            refuseUrl(_id)
        elseif _type == "agree" then
            agreeUrl(_id)
        end
    elseif _isOneKey and _isOneKey == "onkey" then --一键处理
        if self._applyData and next(self._applyData) then
            if _type == "refuse" then
                local onkeyIds = ""..self._applyData[1].id
                for i = 2, #self._applyData do
                    onkeyIds = onkeyIds.."|"..self._applyData[i].id
                end
                refuseUrl(onkeyIds)
            elseif _type == "agree" then
                --可以添加的好友数量
                local _canAddNum = tonumber(self._friendNumLimit) - tonumber(self._friendNum)
                if not _canAddNum or _canAddNum < 0 then
                    _canAddNum = 0
                end
                local onkeyIds = ""
                local _haveIndex = 0
                for i = 1, _canAddNum do
                    if self._applyData[i] and self._applyData[i].id then
                        _haveIndex = _haveIndex + 1
                        if _haveIndex == 1 then
                            onkeyIds = ""..self._applyData[1].id
                        else
                            onkeyIds = onkeyIds.."|"..self._applyData[i].id
                        end
                    end
                end
                if onkeyIds == "" then
                    zc.tipInfo(zc.lang("tips_friend_num_limit"))
                    return
                end
                agreeUrl(onkeyIds)
            end
        else
            zc.tipInfo(zc.lang("tips_friend_now_have_no_response"))
        end
    end
end

--创建底框信息
function FriendPop:createBottomInfo()
    --底框
    local bottom_bg = zc.createPushButton({
        normalFile = "res/Main/friend/bottom_bg.png",
        needSwallow = true,
        -- endCallback = function()
        -- end,
        anchor = cc.p(0.5, 0),
        pos = cc.p(self._rightInfoBg:getContentSize().width/2, 0)
    })
    self._rightInfoBg:addChild(bottom_bg, 10)
    local arrImg = zc.createImageView({
        src = "res/Main/vip/vip_arrow.png",
        ap = cc.p(0, 0.5),
        pos = cc.p(20, bottom_bg:getContentSize().height/2 - 5),
    })
    bottom_bg:addChild(arrImg)
    local tipBg = ccui.Scale9Sprite:create(cc.rect(16,15,1,1), "res/Main/friend/tip_bg.png")
    tipBg:setContentSize(cc.size(299,31))
    tipBg:setAnchorPoint(cc.p(0, 0.5))
    tipBg:setPosition(cc.p(52, arrImg:getPositionY()))
    bottom_bg:addChild(tipBg)
    local _str = zc.lang("tips_friend_tips1")
    if self._tag == 2 then
        _str = zc.lang("tips_friend_tips2")
    end
    local tipLab = zc.createLabel({
        text = _str,
        fontSize = 19,
        pos = cc.p(tipBg:getContentSize().width/2, tipBg:getContentSize().height/2-2),
        color = cc.c3b(73, 48, 45),
    })
    tipBg:addChild(tipLab)
    
    --
    local function createBtnBg(_node, _pos, _text, _color, _callback)
        local myScale9 = zc.getScaleNode("res/Main/role/common/shadow_bg.png", cc.size(126, 31))
        local btnBg = zc.createPushButton({
            normalNode = myScale9,
            needSwallow = true,
            endCallback = _callback,
            pos = _pos
        })
        _node:addChild(btnBg)
        local btnLab = zc.createLabel({
            text = _text,
            outLine = true,
            fontSize = 22,
            pos = cc.p(btnBg:getContentSize().width/2, btnBg:getContentSize().height/2),
            color = _color,
            color2 = display.COLOR_BLACK,
            pixel = 1.3
        })
        btnBg:addChild(btnLab)
    end
    local _btnPos
    if self._tag == 1 then --添加好友
        _btnPos = cc.p(bottom_bg:getContentSize().width-91,tipBg:getPositionY())
        createBtnBg(bottom_bg, _btnPos, zc.lang("add_friend"), display.COLOR_GOLD,function()
            zc.createSourcePop("Friend", "src/layer/friend/FriendAddPop.lua")
        end)
    elseif self._tag == 2 then --申请列表
        _btnPos = cc.p(bottom_bg:getContentSize().width-91,tipBg:getPositionY())
        createBtnBg(bottom_bg, _btnPos, zc.lang("all_tongyi"), display.COLOR_GOLD,function()
            self:applications(nil, "agree", "onkey")
        end)
        _btnPos = cc.p(bottom_bg:getContentSize().width-240,tipBg:getPositionY())
        createBtnBg(bottom_bg, _btnPos, zc.lang("one_key_jujue"), display.COLOR_GREEN,function()
            self:applications(nil, "refuse", "onkey")
        end)
    end
end
--reloadTable
function FriendPop:showNoFriendAndReload()
    local _data
    if self._tag == 1 then
        _data = self._friendData
        table.sort(_data,function(a,b)
            local _aWeight = 0
            local _bWeight = 0
            if tonumber(a.getEnergyStatus) == 1 then
                _aWeight = 1000000
            elseif tonumber(a.sendEnergyStatus) == 0 then
                _aWeight = 100000
            end
            if tonumber(b.getEnergyStatus) == 1 then
                _bWeight = 1000000
            elseif tonumber(b.sendEnergyStatus) == 0 then
                _bWeight = 100000
            end
            if _aWeight ~= _bWeight then
                return _aWeight > _bWeight
            else
                local _aAllGroup = tonumber(a.allgroup) or 0
                local _bAllGroup = tonumber(b.allgroup) or 0
                if _aAllGroup ~= _bAllGroup then
                    return _aAllGroup > _bAllGroup
                else
                    local _aGroup = tonumber(a.group) or 0
                    local _bGroup = tonumber(b.group) or 0
                    return _aGroup > _bGroup
                end
            end
        end)
    elseif self._tag == 2 then
        _data = self._applyData
    elseif self._tag == 3 then
        _data = self._blackData
    end
    if self._myTable then
        self._myTable:reloadDataAndScrollToCurrentCell()
    end
    if not next(_data) or not _data then
        if self._no_friend then
            self._no_friend:setVisible(true)
        end
    end
end
--删除好友申请红点
function FriendPop:deleteRedDot()
    if self._applyNum <= 0 then
        if self._applyRedDot then
            self._applyRedDot:setVisible(false)
        end
    else
        if self._applyRedDotLab then
            self._applyRedDotLab:setText(self._applyNum)
        end
    end
end
--删除体力红点
function FriendPop:deleteEnergyRedDot()
    local _energyNum = PlayerData:getFriendSendEnergyNum()
    if _energyNum <= 0 then
        if self._energyRedDot then
            self._energyRedDot:setVisible(false)
        end
    else
        if self._energyRedDotLab then
            self._energyRedDotLab:setString(_energyNum)
        end
    end
end

function FriendPop:onCleanup()
    zc.removeEventListener(CUSTOM_EVENT.EVENT_REFRESH_FRIENDINFO)
    zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_REDORBUBBLE_CHANGE, data = {tag = "friend"}})
end

return FriendPop