--[[
    FileName: CardExtractLayer.lua
    Author: andong
    Date: 2016-04-21
    Purpose: 酒馆界面
]]
local CardExtractLayer = class( "CardExtractLayer", function()
    return zc.createNormalDialog({
        src = "res/Main/pub/cardExtract/bg.jpg",
        showFlower = false,
        closeCallBack = function()
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_12809 then
                zc.setGuideFuncNextStep(_currentGID)
            elseif _currentGID == GuideKey.KEY_14509 then
                getGuideManager():setFuncGuideOver()
            end
            LayerManager.removeLayout()
        end
    })
end)

function CardExtractLayer:create(parmas)
    return CardExtractLayer.new(parmas)
end

function CardExtractLayer:ctor(parmas)
    self._dizuoY = 70
    self._tesxiaoY = (640 - zc.height)*0.5
    self._costPopId = zc.cardExtractPopId
    self._showIdx = tonumber(parmas.id) or 0
    self._luckDrawtimes = parmas.luckDrawtimes
    self._firstDrawHero = parmas.firstDrawHero
    self._nextDrawHeroFreeTime = parmas.nextDrawHeroFreeTime
    PlayerData:freshCardExtrData(self._nextDrawHeroFreeTime)

    local _dizuo = cc.Node:create()
    self:addChild(_dizuo)
    _dizuo:setPosition(zc.width*0.5, self._dizuoY)
    local _spine1 = zc.createSpine({
        fileName = "choukabeijing_2",
        needInit = false,
        loop = false,
    })
    _dizuo:addChild(_spine1, 1)
    self._spine1 = _spine1
    _spine1:setVisible(false)

    local _spine2 = zc.createSpine({
        fileName = "choukabeijing_2",
        needInit = false,
        loop = false,
    })
    _dizuo:addChild(_spine2)
    self._spine2 = _spine2
    _spine2:setVisible(false)

    --标题
    local _title = zc.createSprite("res/Main/pub/cardExtract/title.png")
    _title:setAnchorPoint(0, 1)
    _title:setPosition(10, zc.height - 10)
    self:addChild(_title, 1)
    --图鉴入口
    local _scale1 = 0.5
    local _scale2 = 0.6
    local _btn = zc.getSprite({
        src = "bottomDi.png",
        plist = true,
        pos = cc.p(zc.width - 50, zc.height - 140), 
        scale = 0.9,
    })
    local _di = zc.getSprite({
        src = "btnNameDi.png",
        plist = true,
        pos = cc.p(_btn:getContentSize().width*0.5, 10),
    })
    _btn:addChild(_di)

    local _label = zc.createLabel({
        text = zc.lang("preview"),
        fontSize = 22,
        stroke = true,
        pixel = 2,
        pos = cc.p(_di:getContentSize().width*0.5, _di:getContentSize().height*0.5),
    })
    _di:addChild(_label)
    self:addChild(_btn, 1)

    local _icon = zc.createPushButton({
        normalFile = "res/Main/common/common_icon_yulan.png",
        touchScale = _scale2/_scale1,
        scale = _scale1,
        touchSize = cc.size(95, 95),
        needEnableWhenMoving = true,
        pos = cc.p(_btn:getContentSize().width*0.5, _btn:getContentSize().height*0.5 + 10),
        endCallback = function()
            --前往图鉴
            zc.createGeneralPreviewLayer()
        end,
        noScaleAction = true,
    })
    _btn:addChild(_icon)

    --整理卡包数据
    local _houseInfo = PlayerData:getHouseInfoByHouseId(9) or {}
    local _houseLevel = tonumber(_houseInfo.level) or 1
    local _playerLevel = tonumber(PlayerData.info.level) or 1
    local _dbs = gameData.getAllDataWithNoClone("hero_handbook_card")
    local _pokedexCardDb = {}
    for k,v in pairs(_dbs) do
        if tonumber(v.id) ~= 5 then
            local _data = {db = v}
            local _hLv = tonumber(v.level) or 1
            local _pLv = tonumber(v.plevel) or 1
            if _houseLevel >= _hLv and _playerLevel >= _pLv then
                _data.openFlag = true
            end
            table.insert(_pokedexCardDb, _data)
        end
    end
    table.sort(_pokedexCardDb, function( a, b )
        return a.db.id < b.db.id
    end)

    if zc.getFunctionStatus(45, false) then --武神榜是否开启
        table.insert(_pokedexCardDb, 1, {
            db = gameData.getDataFromCacheWithPrimaryKey("hero_handbook_card", 5),
            openFlag = true,
        })
    end
    
    local _flag = false
    for i=1,#_pokedexCardDb do
        if not _pokedexCardDb[i].openFlag then
            if _flag then
                _pokedexCardDb[i] = nil
            else
                _flag = true
            end
        end
    end

    --承载node
    local _cardExtractBagNode = ZCSprite:create()
    _cardExtractBagNode:setAnchorPoint(0, 0)
    _cardExtractBagNode:setContentSize(zc.width, zc.height)
    _cardExtractBagNode:setTouchEndedCallback(function() 
        -- 收起点开的卡包
        self:closePoked()
    end)
    self:addChild(_cardExtractBagNode)

    self._partWidth = 160
    self._startY = 100
    self._pokedexCardScale = 0.8
    self._startX = zc.width*0.5 - (#_pokedexCardDb - 1)*self._partWidth*0.5
    self._pokedBtns = {}
    for i=1, #_pokedexCardDb do
        local _data = _pokedexCardDb[i]
        local _file = _data.openFlag and "res/Main/pub/cardExtract/card_u_" .. _data.db.id .. ".png" or "res/Main/pub/cardExtract/card_c_" .. _data.db.id .. ".png"
        local _btn = ZCSprite:create(_file)
        _btn:setScale(self._pokedexCardScale)
        _btn:setPosition(self._startX + (i - 1)*self._partWidth, self._startY)
        _btn:setTouchEndedCallback(function()
            -- if not _data.openFlag then
            --     zc.tipInfo("当前卡包尚未开启")
            --     return
            -- end
            if self._openOne then
                self:closePoked()
                return
            end 
            self:openPoket(i)
        end)
        _btn.openFlag = _data.openFlag
        _btn.db = _data.db
        _cardExtractBagNode:addChild(_btn)
        self._pokedBtns[i] = _btn

        local _shadow = zc.createSprite("res/Main/pub/cardExtract/itemDi2.png")
        if i == 2 or i == 3 then
            _shadow:setPositionX(_btn:getContentSize().width*0.5 + 10)
        else
            _shadow:setPositionX(_btn:getContentSize().width*0.5)
        end
        if not _data.openFlag then
            _shadow:setPositionY(15)
        end
        _btn.shadow = _shadow
        _btn:addChild(_shadow, -2)
    end
    
    self:doDizuo(1, false)
end

function CardExtractLayer:onCleanup()
    helper.collectMemory(true)
end

function CardExtractLayer:onEnter()
    zc.getSpine("choujiang01")
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_14508 then
        local _flag = false
        for i=1, #self._pokedBtns do
            local _id = tonumber(self._pokedBtns[i].db.id)
            if self._showIdx == _id then
                self._pokedBtns[i]:setVisible(false)
                _flag = true
                self._showIdx = nil
                getGuideManager():addMaskLayer()
                local _sprite = cc.Sprite:create()
                _sprite:setScale(2.0)
                _sprite:setPosition(self._pokedBtns[i]:getPosition())
                self._pokedBtns[i]:getParent():addChild(_sprite, 10)
                local _action = zc.getAnimationBySpriteFrame({
                    path = "res/Main/pub/cardExtract/wushentexiao",
                    preFix = "bao_",
                    startIndex = 0,
                    endIndex = 12,
                    perUnit = 1/30,
                })
                _sprite:runAction(cc.Sequence:create(_action, cc.CallFunc:create(function()
                    _sprite:removeFromParent()
                    self._pokedBtns[i]:setVisible(true)
                    self:openPoket(i)
                end)))
                break
            end
        end
        if not _flag then
            getGuideManager():setFuncGuideOver()
        end
    else
        for i=1, #self._pokedBtns do
            local _id = tonumber(self._pokedBtns[i].db.id)
            if self._showIdx == _id then
                self:openPoket(i)
                self._showIdx = nil
                break
            end
        end
        self:addGuide()
    end
end

function CardExtractLayer:doDizuo( idx, haveAct )
    local _idx = tonumber(idx) or 0
    if self._diIdx == _idx then
        return
    end 
    self._diIdx = _idx
    local _haveAct = haveAct == nil and true or haveAct

    local _first, _sec
    if self._spine2:getLocalZOrder() == 1 then
        _first = self._spine1
        _sec = self._spine2
    else
        _first = self._spine2
        _sec = self._spine1
    end

    _first:setVisible(true)
    _first.idx = idx
    _first:setLocalZOrder(1)
    _sec:setLocalZOrder(0)
    if not _haveAct then
        _first:playAction("idle0" .. _first.idx)
        _sec:setVisible(false)
        return
    end

    _first:playAction("start0" .. _first.idx)
    _first:registerSpineEventHandler( function ( event )
        if event.animation == "start0" .. _first.idx then
            _first:playAction("idle0" .. _first.idx, true)
        end
    end, sp.EventType.ANIMATION_COMPLETE)

    if _sec:isVisible() and _sec.idx then
        _sec:playAction("end0" .. _sec.idx)
        _sec:registerSpineEventHandler( function ( event )
            if event.animation == "end0" .. _sec.idx then
                _sec:setVisible(false)
            end
        end, sp.EventType.ANIMATION_COMPLETE)
    end
end

function CardExtractLayer:openPoket( idx )
    if self._isMoveing then
        return
    end
    if self._openOne then
        return
    end
    self._openOne = self._pokedBtns[idx]
    self:doDizuo(self._openOne.db.id)
    -- self._dizuo:playAction("idle0" .. idx)
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12806 then  --对话
        zc.setGuideFuncNextStep(_currentGID, false)
    end
    if self._openOne.openFlag then
        self._openOne:setTexture("res/Main/pub/cardExtract/card_d_" .. self._openOne.db.id .. ".png")
    end
    self._isMoveing = true
    local _pWidth = 450
    local _pointX = zc.width*0.5 - 160
    local _time = 0.3
    for i=1, #self._pokedBtns do
        local _btn = self._pokedBtns[i]
        
        local _flag = i == idx
        local _targetX = 0
        if _flag then
            _targetX = _pointX
        elseif i < idx then
            _targetX = _pointX - (idx - i)*self._partWidth
        else
            _targetX = _pointX + _pWidth + (i - idx - 1)*self._partWidth
        end
        local _actArray = {}
        _actArray[#_actArray + 1] = cc.Spawn:create(
            cc.ScaleTo:create(_time, _flag and self._pokedexCardScale or 0.8*self._pokedexCardScale),
            cc.FadeTo:create(_time, _flag and 255 or 255*0.5),
            cc.MoveTo:create(_time, cc.p(_targetX, self._startY))
        )
        if _flag then
            _actArray[#_actArray + 1] = cc.CallFunc:create(function()
                self._isMoveing = false
                local _currentGID = getGuideManager():getCurrentGID()
                if _currentGID == GuideKey.KEY_14508 then
                    getGuideManager():removeMaskLayer()
                    if tolua.isnull(self._guideBtn) then
                        getGuideManager():setFuncGuideOver()
                    else
                        getGuideManager():setObjTarget(self._guideBtn)
                        getGuideManager():startGuide()
                    end
                end
            end)
            self:showBar(_btn)
        end
        _btn:runAction(cc.Sequence:create(_actArray))
        _btn.shadow:runAction(cc.Spawn:create(
            cc.ScaleTo:create(_time, _flag and self._pokedexCardScale or 0.8*self._pokedexCardScale),
            cc.FadeTo:create(_time, _flag and 255 or 255*0.5)
        ))
    end
end

function CardExtractLayer:closePoked()
    if self._isMoveing then
        return
    end
    if not self._openOne then
        return
    end
    local _time = 0.3
    self._isMoveing = true
    local _idx = 0
    for i=1, #self._pokedBtns do
        local _btn = self._pokedBtns[i]
        local _actArray = {}
        _actArray[#_actArray + 1] = cc.Spawn:create(    
            cc.ScaleTo:create(_time, self._pokedexCardScale),
            cc.FadeTo:create(_time, 255),
            cc.MoveTo:create(_time, cc.p(self._startX + (i - 1)*self._partWidth, self._startY))
        )
        if self._openOne == _btn then
            _idx = i
            _actArray[#_actArray + 1] = cc.CallFunc:create(function()
                self._isMoveing = false
            end)
        end
        _btn:runAction(cc.Sequence:create(_actArray))
        _btn.shadow:runAction(cc.Spawn:create(
            cc.ScaleTo:create(_time, self._pokedexCardScale),
            cc.FadeTo:create(_time, 255)
        ))
    end

    if self._openOne.openFlag then
        self._openOne:setTexture("res/Main/pub/cardExtract/card_u_" .. self._openOne.db.id .. ".png")
    end
    if self._openOne.openInfo then
        self._openOne.openInfo:removeFromParent()
        self._openOne.openInfo = nil
    end
    self._openOne = nil
end

function CardExtractLayer:showBar( btn )
    local _flag = self._openOne.openInfo and true or false
    if btn.openInfo then
        btn.openInfo:removeFromParent()
        btn.openInfo = nil
    end 
    local _payType = btn.db.payType
    local _id = btn.db.id
    local _necessaryFlag = false
    if btn.db.necessary ~= 0 and string.len(btn.db.necessary) > 0 then
        _necessaryFlag = true
    end
    local _di = zc.createSprite("res/Main/pub/cardExtract/infoDi.png")
    _di:setAnchorPoint(0, 0.5)
    _di:setPosition(btn:getContentSize().width*0.5 + 20, btn:getContentSize().height*0.5 - 20)
    btn:addChild(_di, -1)
    btn.openInfo = _di
    local _size = _di:getContentSize()
    local function _showInfo()
        if tonumber(btn.db.id) == 5 then
            local _num = 1
            local _stuff = string.split(btn.db.stuff or "", "|")
            local _btn1 = zc.createCommomBtn({
                tag = 3,
                text = zc.lang("single_chou_2"),
                fontSize = 28,
                scale = 0.8,
                pos = cc.p(_size.width*0.35, _size.height*0.4),
                endCallback = function()
                    self:doExtractCard(_id, 1, _stuff)
                end
            })
            _di:addChild(_btn1)
            self._guideBtn = _btn1

            local _leftTipSize = cc.size(140, 30)
            local _leftTipDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _leftTipSize)
            _leftTipDi:setPosition(_btn1:getPositionX(), _btn1:getPositionY() + _btn1:getContentSize().height*0.5 + 15)
            _di:addChild(_leftTipDi)

            local _img1 = zc.createSprite(zc.getImgByType(tonumber(_stuff[2]) or 1))
            _img1:setAnchorPoint(1, 0.5)
            _img1:setPosition(_leftTipSize.width*0.5 - 5, _leftTipSize.height*0.5)
            _leftTipDi:addChild(_img1)

            local __num = tonumber(_stuff[3]) or 0
            local _lab1 = zc.createLabel({
                text = __num,
                ap = cc.p(0, 0.5),
                fontSize = 24,
                pos = cc.p(_leftTipSize.width*0.5 - 5, _leftTipSize.height*0.5),
                outLine = true,
            })
            _leftTipDi:addChild(_lab1)

            local _btn2 = zc.createCommomBtn({
                tag = 3,
                text = zc.lang("shilian_2"),
                fontSize = 28,
                scale = 0.8,
                pos = cc.p(_size.width*0.75, _size.height*0.4),
                endCallback = function()
                    self:doExtractCard(_id, 10, _stuff)
                end
            })
            _di:addChild(_btn2)

            local _rightTipDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _leftTipSize)
            _rightTipDi:setPosition(_btn2:getPositionX(), _btn2:getPositionY() + _btn2:getContentSize().height*0.5 + 15)
            _di:addChild(_rightTipDi)

            local _img1 = zc.createSprite(zc.getImgByType(tonumber(_stuff[2]) or 1))
            _img1:setAnchorPoint(1, 0.5)
            _img1:setPosition(_leftTipSize.width*0.5 - 5, _leftTipSize.height*0.5)
            _rightTipDi:addChild(_img1)

            local _lab1 = zc.createLabel({
                text = __num*10,
                ap = cc.p(0, 0.5),
                fontSize = 24,
                pos = cc.p(_leftTipSize.width*0.5 - 5, _leftTipSize.height*0.5),
                outLine = true,
            })
            _rightTipDi:addChild(_lab1)

            return
        end
        if not btn.openFlag then
            local _leftTipSize = cc.size(360, 80)
            local _leftTipDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _leftTipSize)
            _leftTipDi:setPosition(_size.width*0.55, _size.height*0.5)
            _di:addChild(_leftTipDi)

            local tipLab1 = zc.createLabel({
                text = zc.lang("mainhero_achieve_space_level"),
                fontSize = 22,
                outLine = true,
                ap = cc.p(0.5, 0.5),
                pos = cc.p(_leftTipSize.width/2, 60),
            })
            _leftTipDi:addChild(tipLab1)
            local levelLab1 = zc.createLabel({
                text = btn.db.plevel,
                fontSize = 22,
                outLine = true,
                ap = cc.p(0.5, 0.5),
                pos = cc.p(148, tipLab1:getContentSize().height/2),
                color = display.COLOR_RED,
            })
            tipLab1:addChild(levelLab1)
            local tipLab1 = zc.createLabel({
                text = zc.lang("and_house_level_achieve_space_level_open") .. "！",
                fontSize = 22,
                outLine = true,
                ap = cc.p(0.5, 0.5),
                pos = cc.p(_leftTipSize.width/2, 25),
            })
            _leftTipDi:addChild(tipLab1)
            local levelLab1 = zc.createLabel({
                text = btn.db.level,
                fontSize = 22,
                outLine = true,
                ap = cc.p(0.5, 0.5),
                pos = cc.p(171, tipLab1:getContentSize().height/2),
                color = display.COLOR_RED,
            })
            tipLab1:addChild(levelLab1)
            return
        end
        local _num = 1
        local _btn1 = zc.createCommomBtn({
            tag = 3,
            text = zc.lang("single_chou_2"),
            fontSize = 28,
            scale = 0.8,
            pos = cc.p(_size.width*0.35, _size.height*0.4),
            endCallback = function()
                self:doExtractCard(_id, 1, _necessaryFlag)
            end
        })
        _di:addChild(_btn1)

        local _currentGID = getGuideManager():getCurrentGID()
        if _currentGID == GuideKey.KEY_12807 then  --抽将
            getGuideManager():setObjTarget(_btn1, 0.8)
            getGuideManager():startGuide()
        end
        
        local _nextFreeTime = tonumber(self._nextDrawHeroFreeTime[tostring(_id)]) or 0
        local _time = _nextFreeTime - PlayerData:getTime()
        _time = _time ~= 0 and _time + 2 or _time
        -- if _time <= 0 or (_necessaryFlag and tonumber(self._firstDrawHero[tostring(_id)]) == 0) then
        if _time <= 0 then
            _btn1:setText(zc.lang("free_2"))
        else
            xpcall(function()
                local _node = _btn1:getStateNormal()
                _node:getChildByName("normalLab"):setPositionX(_node:getContentSize().width*0.65)
                _node = _btn1:getStateSelected()
                _node:getChildByName("selectedLab"):setPositionX(_node:getContentSize().width*0.65)
            end, function() end)
            local _img1 = zc.createSprite(zc.cardExtractPopSmallImg)
            _img1:setPosition(30, _btn1:getContentSize().height*0.5)
            _btn1:addChild(_img1)

            local _lab1 = zc.createLabel({
                text = "x" .. _num,
                ap = cc.p(0, 0.5),
                fontSize = 24,
                pos = cc.p(_img1:getPositionX() + 5, _img1:getPositionY() - 5),
                outLine = true,
            })
            _btn1:addChild(_lab1)

            local _leftTipSize = cc.size(140, 30)
            local _leftTipDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _leftTipSize)
            _leftTipDi:setPosition(_btn1:getPositionX(), _btn1:getPositionY() + _btn1:getContentSize().height*0.5 + 15)
            _di:addChild(_leftTipDi)
            local _leftTipLab1 = zc.createRichLabel({
                text = "[color=ffff0000]" .. zc.getTimeHMS(_time) .. "[/color]" .. zc.lang("after_free"),
                fontSize = 20,
                anchor = cc.p(0, 0.5),
                pos = cc.p(5, _leftTipSize.height*0.5),
                color = cc.c3b(152, 144, 111),
                outLine = true,
            })
            _leftTipDi:addChild(_leftTipLab1)
            schedule(_leftTipLab1, function()
                _time = _nextFreeTime - PlayerData:getTime() + 2
                _leftTipLab1:setString("[color=ffff0000]" .. zc.getTimeHMS(_time) .. "[/color]" ..  zc.lang("after_free"))
                if _time <= 0 then
                    self:showBar(btn)
                end
            end, 1)
        end

        local _btn2 = zc.createCommomBtn({
            tag = 3,
            text = zc.lang("shilian_2"),
            scale = 0.8,
            fontSize = 28,
            pos = cc.p(_size.width*0.75, _btn1:getPositionY()),
            endCallback = function()
                self:doExtractCard(_id, 10)
            end
        })
        _di:addChild(_btn2)
        do 
            xpcall(function()
                local _node = _btn2:getStateNormal()
                _node:getChildByName("normalLab"):setPositionX(_node:getContentSize().width*0.65)
                _node = _btn2:getStateSelected()
                _node:getChildByName("selectedLab"):setPositionX(_node:getContentSize().width*0.65)
            end, function() end)
            local _img1 = zc.createSprite(zc.cardExtractPopSmallImg)
            _img1:setPosition(30, _btn2:getContentSize().height*0.5)
            _btn2:addChild(_img1)

            local _lab1 = zc.createLabel({
                text = "x" .. _num*10,
                ap = cc.p(0, 0.5),
                fontSize = 24,
                pos = cc.p(_img1:getPositionX() + 5, _img1:getPositionY() - 5),
                outLine = true,
            })
            _btn2:addChild(_lab1)

            local _leftTipSize = cc.size(140, 30)
            local _leftTipDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _leftTipSize)
            _leftTipDi:setPosition(_btn2:getPositionX(), _btn2:getPositionY() + _btn2:getContentSize().height*0.5 + 15)
            _di:addChild(_leftTipDi)
            local _leftTipLab1 = zc.createRichLabel({
                text = zc.lang("shilian") .. "[color=ffff0000]" .. zc.lang("must_get") .. "[/color]" .. zc.lang("general"),
                fontSize = 20,
                anchor = cc.p(0, 0.5),
                pos = cc.p(5, _leftTipSize.height*0.5),
                color = cc.c3b(152, 144, 111),
                outLine = true,
            })
            _leftTipDi:addChild(_leftTipLab1)
        end
    end
    if _flag then
        _showInfo()
    else
        _di:setScaleX(0)
        _di:runAction(cc.Sequence:create(
            cc.ScaleTo:create(0.3, 1.0, 1.0),
            cc.CallFunc:create(_showInfo)
        ))
    end
end

function CardExtractLayer:doExtractCard( id, num, necessaryFlag )
    local _flag = false
    if id == 5 then
        local _have = zc.getNumByTypeId(necessaryFlag[1] or 1, necessaryFlag[2] or 1)
        local _cost = tonumber(necessaryFlag[3]) or 0
        _cost = _cost*num
        if _have < _cost then
            zc.tipInfo(zc.getNameById(necessaryFlag[2] or 1) .. zc.lang("un_enough"))
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_14508 then
                getGuideManager():setFuncGuideOver()
            end
            return
        end
    else
        local _nextFreeTime = tonumber(self._nextDrawHeroFreeTime[tostring(id)]) or 0
        local _time = _nextFreeTime - PlayerData:getTime()
        _time = _time ~= 0 and _time + 2 or _time
        local _haveNum = zc.getNumByTypeId(zc.mainTypeProp, self._costPopId)
        if _haveNum < num  then
            if num == 1 then
                if _time > 0 then
                    _flag = true
                end
            else
                _flag = true
            end
        end
    end

    if _flag then
        zc.createSourcePop("CardExtractBuyPop", "src/layer/pub/CardExtractBuyPop.lua", {
            id = self._costPopId,
            idx = id,
            cost = self._openOne.db.price,
        })
        local _currentGID = getGuideManager():getCurrentGID()
        if _currentGID == GuideKey.KEY_12807 then  --抽将
            getGuideManager():setFuncGuideOver()
        end
        return
    end

    PlayerData:setCardExtracting(true)
    zc.sendHttp({
        apiName = "Hero_tenLuckDraw",
        params = {id = id, num = num},
        successCallback = function(net_data)
            net_data.noAnimation = true
            self._luckDrawtimes = net_data.luckDrawtimes
            self._firstDrawHero = net_data.firstDrawHero
            self._nextDrawHeroFreeTime = net_data.nextDrawHeroFreeTime
            PlayerData:freshCardExtrData(self._nextDrawHeroFreeTime)
            PlayerData:updataData(net_data)
            self:showBar(self._openOne)
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_12807 then  --抽将
                zc.setGuideFuncNextStep(_currentGID, true)
            elseif _currentGID == GuideKey.KEY_14508 then
                zc.setGuideFuncNextStep(_currentGID, false)
            end
            local _id = id
            if num == 10 then
                self:playAnimationTen(net_data, _id)
            else
                self:playAnimationOne(net_data, _id)
            end
        end,
        failCallback = function()
            PlayerData:setCardExtracting(false)
        end,
        errorCallback = function( errorCode, errorMsg )
            zc.tipInfo(LANGUAGE_GETERRORTIP(errorMsg))
            PlayerData:setCardExtracting(false)
        end
    })
end


function CardExtractLayer:createOneWeapon( showGet, lay, pos )

end

function CardExtractLayer:createItemIcon( showGet, lay, pos, isSigle )
    local _scale = 0.9
    local _shadow = zc.createSprite("res/Main/pub/cardExtract/itemDi.png")
    _shadow:setAnchorPoint(0.5, 0.5)
    _shadow:setScale(_scale)
    _shadow:setPosition(pos.x, pos.y)
    lay:addChild(_shadow)

    local _icon, _nameText, _nameColor
    if showGet.itemType == zc.mainTypeWeapon then
        local _db = gameData.getDataFromCacheWithPrimaryKey("weapon", showGet.itemId)
        _icon = zc.createSprite("res/Main/weapon/weaponImage/" .. (_db.iconId or 1 ) .. ".png")
        zc.showWeaponEffect(_icon, _db.id)
        local __scale = 1.0
        local __rotation = 0
        local _px = 0
        local _py = isSigle and 10 or -30
        local __type = tonumber(_db.type) or 0
        if __type == 6 then
            __scale = 1.2
        elseif __type == 5 and isSigle then
            __scale = 1.2
        elseif __type == 1 then
            __scale = isSigle and 1.0 or 0.8
        elseif __type == 3 then
            __rotation = -90
            _py = _icon:getContentSize().width*_scale*0.5
            _px = _icon:getContentSize().height*_scale*0.5
        end
        _icon:setScale(__scale*_scale)
        _icon:setRotation(__rotation)
        _icon:setPosition(pos.x + _px, pos.y + _py)
        _nameText = _db.name
        _nameColor = zc.getColorByQuality(zc.getQualityByQualifications(_db.quality))
    elseif showGet.itemType == zc.mainTypeSoldierFragment then
        _icon = zc.createIconByData({
            data = {
                mainType = showGet.itemType,
                type = showGet.itemId,
                id = showGet.itemId,
            }
        })
        _icon:setScale(_scale)
        _icon:setPosition(pos)
    else
        local _iconInfo = zc._getIconInfo({
            data = {
                mainType = showGet.itemType,
                type = showGet.itemId,
                id = showGet.itemId,
            },
        })
        local _img = tonumber(showGet.itemType) == zc.mainTypeResource and _iconInfo.bigImg or _iconInfo.img
        _icon = zc.createSprite(_img)
        _icon:setScale(1.2)

        _icon:setPosition(pos.x, pos.y - 20)
    end
    _icon:setAnchorPoint(0.5, 0)
    lay:addChild(_icon)

    local _w, _h = 120, 33
    local _numBg = zc.getScaleNode("res/Main/role/common/name_bg.png", cc.size(_w, _h))
    _numBg:setAnchorPoint(0.5, 1)
    _numBg:setPosition(pos.x, pos.y - 20)
    lay:addChild(_numBg)
    local _numLab = zc.createLabel({
        fontSize = 20,
        outLine = true,
        text = _nameText or showGet.changeNum,
        pos = cc.p(_w*0.5, _h*0.5),
        color = _nameColor
    })
    _numBg:addChild(_numLab)

    _icon:runAction(cc.RepeatForever:create(cc.Sequence:create(
        cc.MoveBy:create(1.0, cc.p(0, 20)),
        cc.MoveBy:create(1.0, cc.p(0, -20))
    )))
    _shadow:runAction(cc.RepeatForever:create(cc.Sequence:create(
        cc.ScaleTo:create(1.0, 0.8*_scale),
        cc.ScaleTo:create(1.0, 1.0*_scale)
    )))
    zc.doFuncForAllChild(_icon, function( child )
        child:setOpacity(0)
        child:runAction(cc.FadeIn:create(0.5))
    end)
    return _icon, _numBg
end

function CardExtractLayer:playAnimationOne( data, id )
    local _tmpTb = PlayerData:getShowIconDatas(data)
    local showGet = {}
    for k,v in pairs(_tmpTb) do
        local _changeNum = tonumber(v.changeNum) or 0
        if _changeNum > 0 then
            showGet = v
            break
        end
    end
    local _type = tonumber(showGet.itemType) or 0
    local _quality = 1
    local _heroDb = nil
    local _transFlag = false
    if _type == zc.mainTypeSoldier or 
      (_type == zc.mainTypeSoldierFragment and tonumber(showGet.trans) == 1) then
        _heroDb = gameData.getDataFromCacheWithPrimaryKey("hero", showGet.itemId)
        if _type == zc.mainTypeSoldier then 
            _quality = zc.getQualityByQualifications(_heroDb.qualifications)
        else
            _quality = zc.getQualityByQualificationsSoldierFrag(_heroDb.qualifications)
        end
        if tonumber(showGet.trans) == 1 then
            _transFlag = true
        end
    elseif _type == zc.mainTypeSoldierFragment then
        local _db = gameData.getDataFromCacheWithPrimaryKey("hero", showGet.itemId)
        _quality = zc.getQualityByQualificationsSoldierFrag(_heroDb.qualifications)
    end

    local lay = ZCDialog:create()
    LayerManager.addNode(lay, {isPop = true})

    local _bg2 = zc.createSpine({
        fileName = "choujiang02",
        needInit = false,
        actName = "beijing0",
    })
    lay:addChild(_bg2)
    _bg2:setPosition(zc.width*0.5, zc.height*0.5)
    
    local _bg = zc.createSpine({
        fileName = "choujiang02",
        needInit = false,
        loop = false,
        actName = "p1_bj"
    })
    lay:addChild(_bg)
    _bg:setPosition(zc.width*0.5, zc.height*0.5)

    local _daiji = zc.createSpine({
        fileName = "choukabeijing_2",
        needInit = false,
        loop = false,
        actName = "taizi0" .. id
    })
    lay:addChild(_daiji)
    _daiji:setPosition(zc.width*0.5, self._dizuoY)


    local _front2 = zc.createSpine({
        fileName = "choujiang01",
        needInit = false,
        loop = false,
        autoRemove = true,
    })
    lay:addChild(_front2)
    _front2:setPosition(zc.width*0.5, zc.height*0.5 + self._tesxiaoY)
    _front2:setVisible(false)
    local _front1 = zc.createSpine({
        fileName = "choujiang01",
        needInit = false,
        loop = false,
        actName = "p1",
        loop = false,
        autoRemove = true,
    })
    lay:addChild(_front1)
    _front1:setPosition(zc.width*0.5, zc.height*0.5 + self._tesxiaoY)


    local function _showEnd()
        PlayerData:setCardExtracting(false)
        lay:setTouchEndedCallback(function() 
            LayerManager.removeLayout(true)
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_12808 then
                getGuideManager():setHeroFuncCallBack(function()
                    getGuideManager():setObjTarget(self._closeBtn, 0.8)
                    getGuideManager():startGuide()
                end)
                getGuideManager():startGuide()
            elseif _currentGID == GuideKey.KEY_14509 then
                getGuideManager():setObjTarget(self._closeBtn, 0.8)
                getGuideManager():startGuide()
            end
        end)
        local closeLabel = zc.createLabel({
            text = zc.lang("tips_click_empty_continue"),
            outLine = true,
            fontSize = 22,
            ap = cc.p(0.5, 0),
            pos = cc.p(zc.width*0.5 - 15, 25),
        })
        lay:addChild(closeLabel, 2)
        closeLabel:runAction(cc.RepeatForever:create(cc.Sequence:create(cc.FadeIn:create(1),cc.FadeOut:create(1)))) 
    end


    local _pos = cc.p(zc.width*0.5 - 15, zc.height*0.5 - 170 + self._tesxiaoY)
    local _baoZ = zc.createSpine({
        fileName = "choujiang04",
        loop = false,
        needInit = false,
        autoRemove = true,
        removeCallback = function()
            _bg2:setVisible(false)
            if _heroDb then
                if _transFlag then
                    if lay._armature then
                        lay._armature:removeFromParent()
                        lay._armature = nil
                    end
                    local _spine = zc.createSpine({
                        fileName = "zhuanhuan0",
                        needInit = false,
                        loop = false,
                        autoRemove = true,
                        actName = "animation",    
                    })
                    _spine:setPosition(_pos.x, _pos.y + 60)
                    lay:addChild(_spine)
                    local _icon = self:createItemIcon(showGet, lay, _pos, true)
                else
                    zc.createPubShowGetHero({id = showGet.itemId})
                end
                performWithDelay(lay, _showEnd, 2)
            end
        end
    })
    _baoZ:setVisible(false)
    _baoZ:setPosition(zc.width*0.5, zc.height*0.5 + self._tesxiaoY)
    lay:addChild(_baoZ, 1)

    local function _playEnd()
        _bg:setVisible(true)
        _bg:playAction("p5_bj")
        _daiji:setVisible(true)
        _daiji:playAction("daiji0" .. id)

        if _heroDb then
            performWithDelay(lay, function()
                local _armature = zc.createArmature({
                    fileName = _heroDb.modelId, 
                    async = true, 
                    asyncCallback = function( _armature )
                        if tolua.isnull(_armature) then
                            return
                        end
                        _armature:setScaleX(-1)
                        _armature:setOpacity(0)
                        _armature:runAction(cc.FadeIn:create(1.0))
                        _armature:getAnimation():play("idle", -1, 1) 
                    end
                })  
                _armature:setPosition(_pos)
                lay:addChild(_armature)
                lay._armature = _armature
                if _transFlag then
                    performWithDelay(_armature, function()
                        _armature:removeFromParent()
                        lay._armature = nil
                    end, 3)
                end
            end, 0.5)
        else
            performWithDelay(lay, function()
                self:createItemIcon(showGet, lay, _pos, true)
                performWithDelay(lay, function()
                    _showEnd()
                end, 1.0)
            end, 1.0)
        end
        _baoZ:setVisible(true)
        _baoZ:playAction(_quality > 3 and "bz_nb" or "bz_pt")
        performWithDelay(lay, function()
            local runningScene  = cc.Director:getInstance():getRunningScene()
            runningScene:runAction(CCShake:create(1.2, 30))
        end, 0.3)
    end

   
    local function _eventComplete( event )
        local name = event.animation
        if name == "p1_bj" then
            _bg:setVisible(false)
        elseif name == "taizi0" .. id then
            _daiji:setVisible(false)
        end
    end

    _bg:registerSpineEventHandler(_eventComplete, sp.EventType.ANIMATION_COMPLETE)
    _daiji:registerSpineEventHandler(_eventComplete, sp.EventType.ANIMATION_COMPLETE)
    
    local _pertime = 0.35
    performWithDelay(lay, function()
         _front2:setVisible(true)
        if _quality == 2 then
            _front2:playAction("bailv")
            performWithDelay(lay, _playEnd, 1.6666 - _pertime)
        elseif _quality == 3 then
            _front2:playAction("bailvlan")
            performWithDelay(lay, _playEnd, 2.3333 - _pertime)
        elseif _quality == 4 then
            _front2:playAction("bailvlanzi")
            performWithDelay(lay, _playEnd, 3.0 - _pertime)
        elseif _quality == 5 then
            _front2:playAction("bailvlanzijin")
            performWithDelay(lay, _playEnd, 3.6666 - _pertime)
        else
            _front2:playAction("baise")
            performWithDelay(lay, _playEnd, 1.3333 - _pertime)
        end
    end, 2.6 - 0.4)
end

function CardExtractLayer:playAnimationTen( data, id )
    local _tmpTb = PlayerData:getShowIconDatas(data)
    local _haveHero = false
    for k,v in pairs(_tmpTb) do
        local _type = tonumber(v.itemType) or 0
        if _type == zc.mainTypeSoldier or 
          (_type == zc.mainTypeSoldierFragment and tonumber(v.trans) == 1) then
            v.heroDb = gameData.getDataFromCacheWithPrimaryKey("hero", v.itemId)
            v.quality = zc.getQualityByQualificationsSoldierFrag(v.heroDb.qualifications)
            _haveHero = true
        elseif _type == zc.mainTypeSoldierFragment then
            local _db = gameData.getDataFromCacheWithPrimaryKey("hero", v.itemId)
            v.quality = zc.getQualityByQualificationsSoldierFrag(v.heroDb.qualifications)
        else
            v.quality = 1
        end
    end
    table.sort(_tmpTb, function( a, b )
        local _flagA = a.heroDb and true or false
        local _flagB = b.heroDb and true or false
        if _flagA ~= _flagB then
            return _flagA
        end
        local _aQua = tonumber(a.quality) or 0
        local _bQua = tonumber(b.quality) or 0
        if _aQua ~= _bQua then
            return _aQua > _bQua
        end
        if _flagA then
            local _transA = tonumber(a.trans) or 0 
            local _transB = tonumber(b.trans) or 0 
            if _transA ~= _transB then
                return _transA ~= 1
            end
        end
        return false
    end)

    local lay = ZCDialog:create()
    LayerManager.addNode(lay, {isPop = true})

    local _bg2 = zc.createSpine({
        fileName = "choujiang02",
        needInit = false,
        actName = "beijing0",
    })
    lay:addChild(_bg2)
    _bg2:setPosition(zc.width*0.5, zc.height*0.5)
    
    local _bg = zc.createSpine({
        fileName = "choujiang02",
        needInit = false,
        loop = false,
        actName = "p1_bj"
    })
    lay:addChild(_bg)
    _bg:setPosition(zc.width*0.5, zc.height*0.5)

    local _daiji = zc.createSpine({
        fileName = "choukabeijing_2",
        needInit = false,
        loop = false,
        actName = "taizi0" .. id
    })
    lay:addChild(_daiji)
    _daiji:setPosition(zc.width*0.5, self._dizuoY)

    local _front2Node = cc.Node:create()
    _front2Node:setScale(1.55)
    _front2Node:setPosition(zc.width*0.5, zc.height*0.5)
    lay:addChild(_front2Node)
    _front2Node:setVisible(false)
    for i=1,#_tmpTb do
        local _front2 = zc.createSpine({
            fileName = "choujiang01",
            needInit = false,
            loop = false,
            autoRemove = true,
        })
        _front2Node:addChild(_front2)
        _front2Node["front" .. i] = _front2
    end

    local _front1 = zc.createSpine({
        fileName = "choujiang01",
        needInit = false,
        loop = false,
        actName = "p2",
        loop = false,
        autoRemove = true,
    })
    lay:addChild(_front1)
    _front1:setPosition(zc.width*0.5, zc.height*0.5)

  

    local function _showEnd()
        PlayerData:setCardExtracting(false)
        lay:setTouchEndedCallback(function() 
            LayerManager.removeLayout(true)
        end)
        local closeLabel = zc.createLabel({
            text = zc.lang("tips_click_empty_continue"),
            outLine = true,
            fontSize = 22,
            ap = cc.p(0.5, 0),
            pos = cc.p(zc.width*0.5, 25),
        })
        lay:addChild(closeLabel, 2)
        closeLabel:runAction(cc.RepeatForever:create(cc.Sequence:create(cc.FadeIn:create(1),cc.FadeOut:create(1)))) 
    end

    local _endPosGroups = {
        {1.0, cc.p(0, -210), 1.2},
        {0.65, cc.p(-180, -100), 0.9},
        {0.65, cc.p(180, -100), 0.9},
        {0.65, cc.p(-335, -30), 0.9},
        {0.65, cc.p(335, -30), 0.9},
        {0.42, cc.p(-400, 110), 0.8},
        {0.42, cc.p(-200, 110), 0.8},
        {0.42, cc.p(0, 110), 0.8},
        {0.42, cc.p(200, 110), 0.8},
        {0.42, cc.p(400, 110), 0.8},
    }

    local _showHeroId = {}
    local _showHeroInFunc
    _showHeroInFunc = function()
        if #_showHeroId > 0 then
            performWithDelay(lay, function()
                local _back = table.remove(_showHeroId)
                zc.createPubShowGetHero({
                    id = _back,
                    callback = _showHeroInFunc
                })
            end, 0.1)
        else
            _showEnd()
        end
    end

    local function _showItems()
        local _node = cc.Node:create()
        _node:setPosition(zc.width*0.5, zc.height*0.5)
        lay:addChild(_node, 1)
        for i=#_tmpTb, 1, -1 do
            local _v = _tmpTb[i]
            local _file, _bzActName = "", "baoz_pt"
            if _v.heroDb then
                _file = _v.quality > 3 and "res/Main/pub/cardExtract/zhenDi3.png" or "res/Main/pub/cardExtract/zhenDi2.png"
                _bzActName = _v.quality > 3 and "baoz_nb" or _bzActName
            else
                _file = "res/Main/pub/cardExtract/zhenDi1.png"
            end
            dump(_tmpTb[i], "wm---test : " .. _bzActName)
            local _diSp = zc.createSprite(_file)
            _node:addChild(_diSp)
            _diSp:setScale(_endPosGroups[i][1])
            _diSp:setPosition(_endPosGroups[i][2])
            local _pos = cc.p(_diSp:getContentSize().width*0.5, 70)
            if _v.heroDb then
                local _transFlag = false
                 if tonumber(_v.trans) == 1 then
                    _transFlag = true
                end
                local _armature = zc.createArmature({
                    fileName = _v.heroDb.modelId, 
                    async = true, 
                    asyncCallback = function( _armature )
                        if tolua.isnull(_armature) then
                            return
                        end
                        _armature:setScaleX(-1)
                        _armature:setOpacity(0)
                        _armature:runAction(cc.FadeIn:create(1.0))
                        _armature:getAnimation():play("idle", -1, 1) 
                    end
                })  
                _armature:setPosition(_pos)
                _diSp:addChild(_armature)
                local _bzSp = zc.createSpine({
                    fileName = "choujiang04",
                    needInit = false,
                    loop = false,
                    autoRemove = true,
                    actName = _bzActName,    
                })
                _bzSp:setScale(0.7)
                _bzSp:setPosition(_pos.x, _pos.y + 120)
                _diSp:addChild(_bzSp, 1)
                if _transFlag then
                    performWithDelay(_armature, function()
                        local _spine = zc.createSpine({
                            fileName = "zhuanhuan0",
                            needInit = false,
                            loop = false,
                            autoRemove = true,
                            actName = "animation",    
                        })
                        _spine:setPosition(_pos.x, _pos.y + 60)
                        _diSp:addChild(_spine)
                        _armature:removeFromParent()
                        local _icon, _numDi = self:createItemIcon(_v, _diSp, _pos)
                        _numDi:setScale(_numDi:getScale()/_endPosGroups[i][1])
                        if _v.itemType == zc.mainTypeWeapon then
                            local _scale = _icon:getScale()/_endPosGroups[i][1]
                            _icon:setScale(_scale)
                            local _db = gameData.getDataFromCacheWithPrimaryKey("weapon", _v.itemId)
                            if tonumber(_db.type) == 3 then
                                _py = _icon:getContentSize().width*_scale*0.5
                                _px = _icon:getContentSize().height*_scale*0.5
                                _icon:setPosition(_pos.x + _px, _pos.y + _py)
                            end
                        end
                    end, 2)
                else
                    table.insert(_showHeroId, _v.heroDb.id)
                end
            else
                local _icon, _numDi = self:createItemIcon(_v, _diSp, _pos)
                _numDi:setScale(_numDi:getScale()/_endPosGroups[i][1])
                if _v.itemType == zc.mainTypeWeapon then
                    local _scale = _icon:getScale()/_endPosGroups[i][1]
                    _icon:setScale(_scale)
                    local _db = gameData.getDataFromCacheWithPrimaryKey("weapon", _v.itemId)
                    if tonumber(_db.type) == 3 then
                        _py = _icon:getContentSize().width*_scale*0.5
                        _px = _icon:getContentSize().height*_scale*0.5
                        _icon:setPosition(_pos.x + _px, _pos.y + _py)
                    end
                end
            end
        end
        if _haveHero then
            performWithDelay(lay, function()
                local runningScene  = cc.Director:getInstance():getRunningScene()
                runningScene:runAction(CCShake:create(1.2, 30))
            end, 0.3)
        end
        performWithDelay(lay, _showHeroInFunc, 3)
    end

    local _baoZ = zc.createSpine({
        fileName = "choujiang04",
        loop = false,
        needInit = false,
        autoRemove = true,
        removeCallback = function()
            _bg2:removeFromParent()
            _bg:removeFromParent()
            _daiji:removeFromParent()
            _showItems()
        end
    })
    _baoZ:setPosition(zc.width*0.5, zc.height*0.5)
    lay:addChild(_baoZ, 1)
    _baoZ:setVisible(false)

    local _bgImg = zc.createSprite("res/Main/pub/cardExtract/bg2.jpg")
    _bgImg:setPosition(zc.width*0.5, zc.height*0.5)
    lay:addChild(_bgImg, 1)
    _bgImg:setVisible(false)

    local function _playEnd()
        _bg:setVisible(true)
        _bg:playAction("p5_bj")
        _daiji:setVisible(true)
        _daiji:playAction("daiji0" .. id)

        _baoZ:setVisible(true)
        _baoZ:playAction("bz_shilian")
        _bgImg:setVisible(true)
        _bgImg:setOpacity(0)
        performWithDelay(lay, function()
            _bgImg:runAction(cc.FadeTo:create(0.25, 255))
        end, 0.8333)
    end

   
    local function _eventComplete( event )
        local name = event.animation
        if name == "p1_bj" then
            _bg:setVisible(false)
        elseif name == "taizi0" .. id then
            _daiji:setVisible(false)
        elseif name == "daiji0" .. id then
            _daiji:playAction("idle0" .. id, true)
        end
    end

    _bg:registerSpineEventHandler(_eventComplete, sp.EventType.ANIMATION_COMPLETE)
    _daiji:registerSpineEventHandler(_eventComplete, sp.EventType.ANIMATION_COMPLETE)
    
    local _infos = {
        {0.6, 1.0, cc.p(0, 0)},
        {0.4, 1.0, cc.p(92, 53)},
        {0.35, 1.0, cc.p(-109, 33)},
        {0.35, 1.0, cc.p(-203, 66)},
        {0.25, 0.75, cc.p(181, 89)},
        {0.32, 1.0, cc.p(225, -21)},
        {0.27, 0.85, cc.p(-268, -21)},
        {0.22, 0.75, cc.p(281, 63)},
        {0.22, 0.75, cc.p(-331, 21)},
        {0.22, 0.6, cc.p(348, 14)},
    }
    local _actNames = {
        {"baise_sl", 1.3333}, 
        {"bailv_sl", 2.0}, 
        {"bailvlan_sl", 2.8333}, 
        {"bailvlanzi_sl", 3.3333}, 
        {"bailvlanzijin_sl", 4.0}
    }
    performWithDelay(lay, function()
        local _removeCount = 0
        local _pertime = 0.5
        local _pertime2 = 0.5
        local _flag1, _flag2
        _front2Node:setVisible(true)
        for i=1, #_tmpTb do
            local _front2 = _front2Node["front" .. i]
            local _actName = _actNames[_tmpTb[i].quality][1]
            _front2:playAction(_actName)
            _front2:setScale(_infos[i][1])
            _front2:setOpacity(_infos[i][2]*255)
            _front2:setPosition(_infos[i][3])
            performWithDelay(_front2, function()
                _removeCount = _removeCount + 1
                if _removeCount > 3 and not _flag1 then
                    _flag1 = true
                    _front2Node:runAction(cc.Sequence:create(
                        cc.ScaleTo:create(0.3, 2.1)))
                elseif _removeCount > 6 and not _flag2 then
                    _flag2 = true
                    _flag1 = true
                    _front2Node:stopAllActions()
                    _front2Node:runAction(cc.Sequence:create(
                        cc.ScaleTo:create(0.3, 2.5)))
                end
            end, _actNames[_tmpTb[i].quality][2] - _pertime2)
            if i == 1 then
                performWithDelay(lay, _playEnd, _actNames[_tmpTb[i].quality][2] - _pertime)
            end
        end
    end, 2.6 - 0.4)
end

function CardExtractLayer:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12805 then  --对话
        getGuideManager():setHeroFuncCallBack(function()
            getGuideManager():setObjTarget(self._pokedBtns[1], 0.8)
            getGuideManager():startGuide()
        end)
        getGuideManager():startGuide()
    end
end


return CardExtractLayer