--[[
    FileName: BingFaLevelUpPop.lua
    Author: andong
    Date: 2016-04-14
    Purpose: 兵法升级界面
]]
local BingFaLevelUpPop = class( "BingFaLevelUpPop", function ()
    return ZCPopLayer:create()
end)

function BingFaLevelUpPop:create(params)
    return self.new(params)
end

function BingFaLevelUpPop:ctor(params)
    self:initData(params)
    self:refreshUI()
    self:show()
end

function BingFaLevelUpPop:initData(params)
    self._callback = params.callback
    self.EffectNum = 2
    params = params.info
    self._mainId = params.bookId
    
    local staticValue = gameData.getDataFromCache("book_level", {["bookId"]=params.bookId})
    local bookInfo = gameData.getDataFromCacheWithPrimaryKey("book", params.bookId)
    self._staticValue = staticValue
    self._bookInfo = bookInfo

    self._curLevel = tonumber(params.level)

    self:refreshData()
end

function BingFaLevelUpPop:refreshData()
    local staticValue = self._staticValue
    local bookInfo = self._bookInfo

    if self._curLevel == #staticValue then --是否是最大等级
        self._isMaxLevel = true
    end

    local curValue = staticValue[self._curLevel]
    self.nextValue = {}
    if not self._isMaxLevel then
        self.nextValue = staticValue[self._curLevel+1]
    end
    local priceString = tostring(self.nextValue.spendNum)
    local priceTa = string.split(priceString, "|")
    self._consumeType = priceTa[2] --升级消耗(武魂)
    --固定作用类型
    local baseInfo = {}
    self.info = {
        ["curr"] = {baseInfo={},openInfo={}},
        ["next"] = {baseInfo={},openInfo={}}
    }
    for j = 1, 2 do
        local valueInfo = j == 1 and curValue or self.nextValue
        if not next(valueInfo) then
            return
        end
        local taName = j == 1 and "curr" or "next"
        for i = 1, self.EffectNum do
            if bookInfo["effectId"..i] and tonumber(bookInfo["effectId"..i]) > 0 then
                if valueInfo["effectValue"..i] and tonumber(valueInfo["effectValue"..i]) ~=0 then
                    local idx = #self.info[taName]["baseInfo"] + 1
                    self.info[taName]["baseInfo"][idx] = {}
                    self.info[taName]["baseInfo"][idx].effectId = bookInfo["effectId"..i]
                    self.info[taName]["baseInfo"][idx].value = valueInfo["effectValue"..i]
                end
            else
                break
            end
        end
        --开启作用类型
        for i = 1, self.EffectNum do
            if bookInfo["openEffectId"..i] and tonumber(bookInfo["openEffectId"..i]) > 0 then
                if valueInfo["openEffectValue"..i] and tonumber(valueInfo["openEffectValue"..i]) ~= 0 then
                    local idx = #self.info[taName]["openInfo"] + 1
                    self.info[taName]["openInfo"][idx] = {}
                    self.info[taName]["openInfo"][idx].effectId = bookInfo["openEffectId"..i]
                    self.info[taName]["openInfo"][idx].value = valueInfo["openEffectValue"..i]
                end
            else
                break
            end
        end
    end 
end

function BingFaLevelUpPop:popBgAddChild(_node)
    self._popBg:addChild(_node)
    self._itemList[#self._itemList+1] = _node
end

function BingFaLevelUpPop:refreshUI()
    if not self._popBg then
        local popBg = zc.createNormalPop({
            tag = 1,
            titleTag = 1,
            showSide = false,
            height = 530+31,
            width = 377,
            bianZOrder = 0
        })
        popBg:setPosition(zc.width*0.5, zc.height*0.5)
        self:addContent(popBg)
        local popSize = cc.size(377, 530)
        self._popBg = popBg
        self._popSize = popSize       
    else
        for i = 1, #self._itemList do
            local v = self._itemList[i]
            if not tolua.isnull(v) then
                v:removeFromParent()
            end
        end
    end

    local popSize = self._popSize
    local popBg = self._popBg

    self._itemList = {}

    --升级等级
    for i = 1, 2 do
        local levelNumImgId = self._curLevel + (i-1)
        local posX = i==1 and 80 or popSize.width/2+80
        local levelNum = zc.createFntLabel({
            fnt = "res/Main/research/bingfa/num/nums.fnt",
            text = levelNumImgId,
            ap = cc.p(0.5, 0.5),
            pos = cc.p(posX, popSize.height - 70),
            addwidth = -15,
        })
        self:popBgAddChild( levelNum )
        local ji = zc.createSprite("res/Main/research/bingfa/num/ji.png")
        ji:setAnchorPoint(0, 0.5)
        ji:setPosition(levelNum:getPositionX()+levelNum:getContentSize().width/2, levelNum:getPositionY()+3)
        self:popBgAddChild( ji )
        ji:setPositionX(levelNum:getPositionX()+levelNum:getContentSize().width/2-5)
        if self._isMaxLevel then
            levelNum:setPositionX(popSize.width/2-ji:getContentSize().width/2)
            ji:setPositionX(levelNum:getPositionX()+levelNum:getContentSize().width/2)
            break
        end
    end
    if not self._isMaxLevel then
        local arrow_green = zc.createSprite("res/Main/common/arrow_green.png")
        arrow_green:setPosition(popSize.width/2+10, popSize.height - 70)
        self:popBgAddChild( arrow_green )
    end
        
    local _middleBg = zc.createGeneralPopScale({
        tag = 3,
        width = 350,
        height = 321,
    })
    _middleBg:setAnchorPoint(cc.p(0.5, 1))
    _middleBg:setPosition(cc.p(popSize.width/2-2, popSize.height-85))
    self:popBgAddChild( _middleBg )
    self._middleBg = _middleBg

    --info
    local infoBg = zc.createGeneralPopScale({
        tag = 2,
        width = 330,
        height = 300,
    })
    infoBg:setPosition(cc.p(self._middleBg:getContentSize().width/2, self._middleBg:getContentSize().height/2))
    self._middleBg:addChild(infoBg)
    self._infoBg = infoBg

    local infoBgSize = cc.size(330, 300)
    --附加属性
    local fujia = zc.createSprite("res/Main/role/equip/addAttr.png")
    fujia:setAnchorPoint(0.5, 0.5)
    fujia:setPosition(infoBgSize.width/2, infoBgSize.height-20)
    infoBg:addChild(fujia)
    local lace_left = zc.createSprite("res/Main/common/lace.png")
    lace_left:setAnchorPoint(1, 0.5)
    lace_left:setPosition(0, fujia:getContentSize().height/2 )
    fujia:addChild(lace_left)

    local lace_right = zc.createSprite("res/Main/common/lace.png")
    lace_right:setAnchorPoint(0, 0.5)
    lace_right:setPosition(fujia:getContentSize().width, lace_left:getPositionY() )
    lace_right:setFlipX(true)
    fujia:addChild(lace_right)

    local curBase = self.info["curr"]["baseInfo"] or {}
    local nextBase = self.info["next"]["baseInfo"] or {}

    for i = 1, #curBase do
        local posX = 10
        local posY = infoBgSize.height-61-30*(i-1)
        local myLab = zc.createLabel({
            text = LANGUAGE_getAttributeTextById(curBase[i].effectId).."：",
            outLine = true,
            fontSize = 18,
            ap = cc.p(0, 0.5),
            pos = cc.p(posX, posY),
            color = cc.c3b(219,212,167),
        })
        infoBg:addChild(myLab)       
        local num = zc.createLabel({
            text = zc.getAttributeNumById(curBase[i].effectId, curBase[i].value),
            outLine = true,
            fontSize = 18,
            ap = cc.p(0, 0.5),
            pos = cc.p(myLab:getPositionX()+myLab:getContentSize().width, myLab:getPositionY()),
        })
        infoBg:addChild(num)    

        if self._isMaxLevel then --如果是最大等级
            myLab:setPositionX(infoBgSize.width/2-num:getContentSize().width/2-myLab:getContentSize().width/2)
            num:setPositionX(myLab:getPositionX()+myLab:getContentSize().width)
        else
            local arrow_green = zc.createSprite("res/Main/common/arrow_green.png")
            arrow_green:setPosition(infoBgSize.width/2+10,  posY)
            infoBg:addChild(arrow_green)

            local addValue = zc.createLabel({
                text = "+"..zc.getAttributeNumById(nextBase[i].effectId, nextBase[i].value),
                outLine = true,
                fontSize = 18,
                ap = cc.p(0, 0.5),
                pos = cc.p(205, posY),
                color = display.COLOR_GREEN,
            })
            infoBg:addChild(addValue)
        end    
    end
    --启用特性 
    local qiyong = zc.createSprite("res/Main/research/bingfa/attr_open.png")
    qiyong:setAnchorPoint(0.5, 0.5)
    qiyong:setPosition(infoBgSize.width/2, 87)
    infoBg:addChild(qiyong)
    local lace_left = zc.createSprite("res/Main/common/lace.png")
    lace_left:setAnchorPoint(1, 0.5)
    lace_left:setPosition(0, qiyong:getContentSize().height/2 )
    qiyong:addChild(lace_left)

    local lace_right = zc.createSprite("res/Main/common/lace.png")
    lace_right:setAnchorPoint(0, 0.5)
    lace_right:setPosition(qiyong:getContentSize().width, lace_left:getPositionY() )
    lace_right:setFlipX(true)
    qiyong:addChild(lace_right)

    local curOpen = self.info["curr"]["openInfo"] or {}
    local nextOpen = self.info["next"]["openInfo"] or {}

    for i = 1, #curOpen do
        local posX = 10
        local posY = 52-30*(i-1)
        local myLab = zc.createLabel({
            text = LANGUAGE_getAttributeTextById(curOpen[i].effectId).."：",
            outLine = true,
            fontSize = 18,
            ap = cc.p(0, 0.5),
            pos = cc.p(posX, posY),
            color = cc.c3b(219,212,167),
        })
        infoBg:addChild(myLab)
        local addOrSub = tonumber(curOpen[i].value) < 0 and "" or "+" 
        local numColor = tonumber(curOpen[i].value) < 0 and display.COLOR_RED or display.COLOR_GREEN
        local num = zc.createLabel({
            text = addOrSub..zc.getAttributeNumById(curOpen[i].effectId, curOpen[i].value),
            outLine = true,
            fontSize = 18,
            ap = cc.p(0, 0.5),
            pos = cc.p(myLab:getPositionX()+myLab:getContentSize().width, myLab:getPositionY()),
            color = numColor,
        })
        infoBg:addChild(num)    

        if self._isMaxLevel then --如果是最大等级
            myLab:setPositionX(infoBgSize.width/2-num:getContentSize().width/2-myLab:getContentSize().width/2)
            num:setPositionX(myLab:getPositionX()+myLab:getContentSize().width)
        else
            local arrow_green = zc.createSprite("res/Main/common/arrow_green.png")
            arrow_green:setPosition(infoBgSize.width/2+10,  posY)
            infoBg:addChild(arrow_green)
            local addOrSub2 = tonumber(nextOpen[i].value) < 0 and "" or "+" 
            local numColor2 = tonumber(nextOpen[i].value) < 0 and display.COLOR_RED or display.COLOR_GREEN
            local addValue = zc.createLabel({
                text = addOrSub2..zc.getAttributeNumById(nextOpen[i].effectId, nextOpen[i].value),
                outLine = true,
                fontSize = 18,
                ap = cc.p(0, 0.5),
                pos = cc.p(205, posY),
                color = numColor2,
            })
            infoBg:addChild(addValue)
        end    
    end

    local priceString = tostring(self.nextValue.spendNum)
    local priceTa = string.split(priceString, "|")
    local priceStr = tonumber(priceTa[3])
    local playerOwnNum = tonumber(PlayerData:getResourcesInfo()[zc.getTypeByType(priceTa[2])])

    local levelUpBtn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("shengjie_2"),
        needSwallow = false,
        endCallback = function()
            if priceStr <= playerOwnNum then
                self:levelUp()
            else
                zc.tipInfo(zc.lang("right_now") .. LANGUAGE_getReousrceNameById(priceTa[2]) .. zc.lang("num_unenough") .."!")
            end
        end,
        pos = cc.p(popSize.width/2, 50)
    })
    self:popBgAddChild( levelUpBtn )
       
    if not self._isMaxLevel then
        local gold = zc.createSprite(zc.getImgByType(self._consumeType))
        gold:setAnchorPoint(0.5, 0.5)
        gold:setPosition(levelUpBtn:getPositionX(), levelUpBtn:getPositionY()+levelUpBtn:getContentSize().height/2+17)
        self:popBgAddChild( gold )
        
        local priceColor = priceStr<= playerOwnNum and display.COLOR_WHITE or display.COLOR_RED
        local price = zc.createLabel({
            text = zc.getWan(priceStr),
            outLine = true,
            fontSize = 22,
            ap = cc.p(0, 0.5),
            pos = cc.p(gold:getContentSize().width, gold:getContentSize().height/2),
            color = priceColor,
        })
        gold:addChild(price)
        gold:setPositionX(levelUpBtn:getPositionX() - price:getContentSize().width/2)
    else
        local tipLab = zc.createLabel({
            text = zc.lang("tips_bingfa_max_level"),
            outLine = true,
            fontSize = 22,
            pos = cc.p(levelUpBtn:getPositionX(), levelUpBtn:getPositionY()+levelUpBtn:getContentSize().height/2+17),
            pixel = 1.3
        })
        self:popBgAddChild( tipLab )
        levelUpBtn:setEnable(false)
    end
end

function BingFaLevelUpPop:levelUp() --出售卡片
    if not self._isMaxLevel then
        local function doLevelUp()
            zc.sendHttp({
                apiName = "Captain_upgrade",
                params = {id = self._mainId},
                successCallback = function (net_data)
                    zc.tipInfo(zc.lang("advanced_success") .. "！")
                    PlayerData:updataData(net_data)
                    if self._callback and type(self._callback) == "function" then
                        self._callback(net_data)
                    end

                    --更新等级
                    self._curLevel = tonumber(self._curLevel) + 1
                    self:refreshData()
                    self:refreshUI()

                end,
            })
        end
        doLevelUp()
    else
        zc.tipInfo(zc.lang("tips_bingfa_max_level"))
    end
end

return BingFaLevelUpPop