--[[
    FileName: QunXiongMainLayer.lua
    Author: andong
    Date: 2016-04-07
    Purpose: 研究院界面
]]
local QunXiongMainLayer = class( "QunXiongMainLayer", function ()
    return zc.createNormalDialog()
end)
function QunXiongMainLayer:create(parmas)
    return QunXiongMainLayer.new(parmas)
end
function QunXiongMainLayer:ctor(parmas)
    self._record = {}
    self:initData(parmas)
    self:initUI()
end

function QunXiongMainLayer:initData(parmas)
    if parmas and parmas.callback then
        self._callback = parmas.callback
    end
    self._parmas = parmas
    self._tag =  1--1总览 2图鉴 3兑换
    self._subTag = parmas.tag --1
    self._mainId = parmas.captains[self._subTag].id --挑战的主键id
    self._openState = parmas.openState --开启的名将册信息
    --组合激活状态 
    self._totalAct = parmas.totalAct
    self._activitied = parmas.activitied
    --已经拥有的武将卡
    self._ownHeros = {} 
    for k,v in pairs(parmas.heroCards) do
        if tonumber(v.num) > 0 then 
            local idx = tonumber(v.heroCardId) --用静态id做key
            self._ownHeros[idx] = {}
            self._ownHeros[idx].mainId = v.id            --主键id
            self._ownHeros[idx].staticId = v.heroCardId  --卡牌静态id
            self._ownHeros[idx].num = v.num              --卡牌数量
        end
    end
    --所有名将册
    self.seatNum = tonumber(parmas.openNum)
    --激活的组合信息
    self:getGroupData(self._subTag)
    --图鉴、兑换静态信息
    self._exchangeData = gameData.getDataFromCache("heroCard", {["captainId"]=self._subTag}) 
    self:initLeftData(parmas)

end
--获取每个组合数据
function QunXiongMainLayer:getGroupData(_subTag)
    if not _subTag then
        return
    end
    self._curGroupData = gameData.getDataFromCache("captain_combine", {["captainId"]=_subTag}) --组合
    --排序规则（1可激活、10000已激活、有卡牌、无卡牌）
    for i = 1, #self._curGroupData do
        local flag = false
        self._curGroupData[i].flag = 10 --不能激活
        local id = self._curGroupData[i].id
        if self._activitied[tonumber(id)] then
            self._curGroupData[i].flag = 10000 --已激活
        else
            local _canActivity = true
            local _ownNum = 0
            for j = 1, 10 do
                if not self._curGroupData[i]["heroCardId"..j] then
                    break
                else
                    if tonumber(self._curGroupData[i]["heroCardId"..j]) > 0 then
                        local heroId = tonumber(self._curGroupData[i]["heroCardId"..j])
                        if self._ownHeros[heroId] and self._ownHeros[heroId].num and tonumber(self._ownHeros[heroId].num) > 0 then --拥有
                            _ownNum = _ownNum + 1
                        else --不拥有
                            _canActivity = false
                            self._curGroupData[i].flag = self._curGroupData[i].flag + 1
                        end
                    end
                end
            end
            if _ownNum == 0 then --一个都不拥有
                self._curGroupData[i].flag = 1000
            end
            if _canActivity then
                self._curGroupData[i].flag = 1 --可激活
            end
        end
    end
    table.sort(self._curGroupData, function(a, b)
        if tonumber(a.flag) ~= tonumber(b.flag) then
            return tonumber(a.flag) < tonumber(b.flag)
        else
            return tonumber(a.id) < tonumber(b.id)
        end
    end)
    -- dump(self._curGroupData, "222222")
end
function QunXiongMainLayer:initLeftData(parmas)
    self._challengeData = gameData.getDataFromCacheWithPrimaryKey("captain_npcGroup", parmas.captains[self._subTag].lastGroupId) --怪物组
    local nowCaptains = parmas["captains"][self._subTag]
    if nowCaptains["id"] then
        self._mainId = nowCaptains["id"]
    end
    self._dropData = {}
    local dropId = self._challengeData.drop
    if dropId then
        local dropidTa = string.split(dropId, ",")
        for i = 1, #dropidTa do
            local dropid = string.split(dropidTa[i], "|")
            local drop = gameData.getDataFromCacheWithPrimaryKey("drop_award", dropid[1])
            if drop and next(drop) then
                self._dropData[#self._dropData+1] = drop
            end
        end
    end
    for i = 1 ,#self._dropData do
        if tonumber(self._dropData[i].itemType) == zc.mainTypeSoldierCard then
            self._dropData[i].info = gameData.getDataFromCacheWithPrimaryKey("heroCard", self._dropData[i].itemId)
        end
    end
    table.sort(self._dropData, function(a, b)
        return tonumber(a.info.quality or 0) > tonumber(b.info.quality or 0)
    end)
end
function QunXiongMainLayer:initUI()
    --界面信息
    self:createInfo()
    --切换tab
    self:createTab()
    self:createSubTab(true)
end
function QunXiongMainLayer:createInfo()
    self._centerBgPosY = zc.height/2 --中心点坐标
end
function QunXiongMainLayer:createTab()
    --tab
    local initPosY = self._centerBgPosY + 160
    local nameInfo = LANGUAGE_get_qunxiong_tabs()
    self._mainTab = {}
    for i = 1, #nameInfo do
        local tabBtn = zc.createPushButton({
            normalNode      = zc.createSprite("res/Main/role/common/tab_u.png"),
            pos = cc.p(zc.width - 49, initPosY-(i-1)*115),
            anchor = cc.p(0, 0.5),
            endCallback = function() end,
        })
        tabBtn:setTag(i)
        self:addChild(tabBtn, 10)
        tabBtn:setTouchEndedCall(function()
            self:changeTab(tabBtn)
        end)
        local _normal_label = zc.createLabel({
            text = nameInfo[i],
            color = cc.c3b( 122, 42, 0 ),
            color2 = cc.c3b( 255, 232, 128 ),
            outLine = true,
            pixel = 0.5,
            fontSize = 24,
            width = 30,
            pos = cc.p( tabBtn:getContentSize().width/2 - 8, tabBtn:getContentSize().height/2 + 3 ),
        })
        tabBtn:addChild( _normal_label ,1)
        local _selected_label = zc.createLabel({
            text = nameInfo[i],
            color = display.COLOR_WHITE,
            color2 = cc.c3b( 72, 37, 0 ),
            outLine = true,
            pixel = 0.5,
            fontSize = 24,
            width = 30,
            pos = cc.p( tabBtn:getContentSize().width/2 - 8, tabBtn:getContentSize().height/2 + 3 ),
        })
        tabBtn:addChild( _selected_label ,1)
        _selected_label:setVisible(false)

        tabBtn._normal = _normal_label
        tabBtn._selected = _selected_label
        if i == 1 then
            self:changeTab(tabBtn)
        end
        self._mainTab[i] = tabBtn
    end

end
--总览界面、图鉴界面、兑换界面 之间的切换逻辑是显示一个隐藏另外两个
function QunXiongMainLayer:changeTab(_node)

    local nameTab = {[1]="zonglan",[2]="tujian",[3]="duihuan"}

    local function getNormal(_tag)
        return zc.createSprite("res/Main/role/common/tab_u.png")
    end
    local function getSelected(_tag)
        return zc.createSprite("res/Main/role/common/tab_d.png")
    end

    if not self._selectedBtn or self._selectedBtn ~= _node then
        local _tag = _node:getTag()
        if not self._selectedBtn then
            self._selectedBtn = _node
            self._selectedBtn:setStateNormal(getSelected(_tag))
            _node._normal:setVisible(false)
            _node._selected:setVisible(true)
        else
            self._selectedBtn:setStateNormal(getNormal(self._tag))
            self._selectedBtn._normal:setVisible(true)
            self._selectedBtn._selected:setVisible(false)
            self._selectedBtn = _node
            self._selectedBtn:setStateNormal(getSelected(_tag))
            _node._normal:setVisible(false)
            _node._selected:setVisible(true)
        end
        self._tag = _tag
        if self._zonglan then
            self._zonglan:setVisible(false)
        end
        if self._tujian then
            self._tujian:setVisible(false)
        end
        if self._duihuan then
            self._duihuan:setVisible(false)
        end
        if self._subTabBg then
            self._subTabBg:setVisible(false)
        end
        if _tag == 1 then 
            self:createZonglanInfo()
        elseif _tag == 2 then
            self:createTujianInfo(true)
        elseif _tag == 3 then
            self:createDuihuanInfo()
        end
    end
end
function QunXiongMainLayer:createSecondBg() 
    --背景
    local subbg = zc.createNormalPop({
        srcTag = 1,
        width = 970,
        height = 520+31,
    })
    subbg:setPosition(zc.width*0.5+34, self._zonglan:getPositionY() )
    self:addChild(subbg)

    local _titleImg = zc.getSprite({
        src = "res/Main/common/popBg/titleBg2.jpg",
        ap = cc.p(1, 1),
        name = "titleImg",
    })
    _titleImg:setPosition(cc.p(subbg:getContentSize().width-3, subbg:getContentSize().height-3))
    subbg:addChild(_titleImg,2)

    local titleLeft = zc.createSprite("res/Main/common/popBg/titleBg2.jpg")
    titleLeft:setAnchorPoint(0, 1)
    titleLeft:setPosition(3, _titleImg:getPositionY())
    subbg:addChild(titleLeft,1)

    --标题
    local subbg_title = zc.createImageView({
        src = "res/Main/research/qunxiong/qunxiong_title.png",
        pos = cc.p(0, subbg:getPositionY() + subbg:getContentSize().height/2),
        ap = cc.p(0,0.5)
    })
    self:addChild(subbg_title,10)

    local bgImg2 = zc.getScaleNode("res/Main/otherPlayer/otherPlayer_tag_bg.png", cc.size(154, 473))
    bgImg2:setAnchorPoint(cc.p(0, 0))
    bgImg2:setPosition(cc.p(1, 1))
    bgImg2:setName("bgImg2")
    subbg:addChild(bgImg2)
    local splitY = cc.Sprite:create( "res/Main/common/tab_split_y.png" )
    splitY:setPosition(154,473/2+16)
    bgImg2:addChild(splitY)

    return subbg
end

function QunXiongMainLayer:createSubTab(_isNotVisible) --二级tab
    if self._subTabBg then
        self._subTabBg:setVisible(true)
    else
        local subTabSize
        self._subTabBg = self:createSecondBg()

        if _isNotVisible then
            self._subTabBg:setVisible(false)
        end

        local subTab = self._subTabBg:getChildByName("bgImg2")
        local subTabSize = subTab:getContentSize()

        local itemHeight = 130
        local innerHeight = itemHeight * self.seatNum + 10
        if innerHeight < subTabSize.height-28 then
            innerHeight = subTabSize.height-28
        end
        local ifBunce = self.seatNum > 2 and true or false
        local myscrollview = zc.createScrollview({
            pos = cc.p(0, 0),
            size = cc.size(subTabSize.width,subTabSize.height-28),
            innerSize = cc.size(subTabSize.width, innerHeight),
            dir = ccui.ScrollViewDir.vertical,
            bounceEnable = false,
        })
        subTab:addChild(myscrollview, 1)

       --tab
        local initPosY = self._centerBgPosY + 70
        local function getNormal(_tag)
            local tabTag = _tag
            _tag = _tag - (math.floor((_tag-1)/3))*3
            local scaleSize = cc.size(136, 130)
            local _normal = zc.getScaleNode("res/Main/common/img_empty.png", scaleSize)
            local _normal2 = zc.createSprite("res/Main/research/qunxiong/tab_".._tag.."_u.png")
            _normal2:setPosition(cc.p(_normal:getContentSize().width/2, _normal:getContentSize().height/2+12))
            _normal:addChild(_normal2)
            if not self._openState[tonumber(tabTag)] then
                zc.setGray(_normal2)
            end
            return _normal
        end
        self._subNumLab = {}
        self._subTab = {}
        for i = 1, self.seatNum do
            local labColor = cc.c3b(247, 188, 12)
            if not self._openState[i] then
                labColor = display.COLOR_DEEPGRAY
            end
            local tabBtn = zc.createPushButton({
                normalNode = getNormal( i ),
                pos = cc.p(subTabSize.width/2, innerHeight-75-(i-1)*130),
                anchor = cc.p(0.5, 0.5),
                needEnableWhenMoving = true,
                needSwallow = false,
                endCallback = function() end,
            })
            tabBtn:setTag(i)
            myscrollview:addChild(tabBtn)
            local numStr = self._totalAct[i].activitied.."/"..self._totalAct[i].totalGroup
            local numLab = zc.createLabel({
                text = numStr,
                outLine = true,
                fontSize = 18,
                pos = cc.p(tabBtn:getContentSize().width/2, 25),
                color = labColor,
            })
            tabBtn:addChild(numLab, 1)
            self._subNumLab[i] = numLab
            tabBtn:setTouchEndedCall(function()
                self:changeSubTab(tabBtn)
            end)
            if i == self._subTag then
                self:changeSubTab(tabBtn)
            end
            self._subTab[i] = tabBtn
        end

        if tonumber(self._subTag) > 3 then
            myscrollview:scrollToBottom(0.3, true) 
        end
    end  
end
function QunXiongMainLayer:changeSubTab(_node) --切换二级tab
    local function getNormal(_tag)
        _tag = _tag - (math.floor((_tag-1)/3))*3
        -- print("tag --> ", _tag)
        local scaleSize = cc.size(136, 130)
        local _normal = zc.getScaleNode("res/Main/common/img_empty.png", scaleSize)
        local _normal2 = zc.createSprite("res/Main/research/qunxiong/tab_".._tag.."_u.png")
        _normal2:setPosition(cc.p(_normal:getContentSize().width/2, _normal:getContentSize().height/2+12))
        _normal:addChild(_normal2)
        return _normal
    end
    local function getSelected(_tag)
        _tag = _tag - (math.floor((_tag-1)/3))*3
        local se1 = zc.createSprite("res/Main/research/qunxiong/select_down.png")
        local se2 = zc.createSprite("res/Main/research/qunxiong/tab_".._tag.."_d.png")
        se2:setPosition(cc.p(se1:getContentSize().width/2, se1:getContentSize().height/2+12))
        se1:addChild(se2)
        return se1
    end
    local _tag = _node:getTag()
    if not self._openState[tonumber(_tag)] then
        zc.tipInfo(zc.lang("tips_qunxiong_unopen"))
        return
    end
    if not self._selectedSubBtn or self._selectedSubBtn ~= _node then
        if not self._selectedSubBtn then
            self._selectedSubBtn = _node
            self._selectedSubBtn:setStateNormal(getSelected(_tag))
            self._selectedSubBtn:setLocalZOrder(1)
        else
            self._selectedSubBtn:setStateNormal(getNormal(self._subTag))
            self._selectedSubBtn:setLocalZOrder(0)
            self._selectedSubBtn = _node
            self._selectedSubBtn:setStateNormal(getSelected(_tag))
            self._selectedSubBtn:setLocalZOrder(1)
        end
        self._subTag = _tag -- 1同符合约 2势如破竹 3三国无双

        --
        if self._notFirst then --第一次的数据是已经配置完成
            --更换数据
            self:getGroupData(self._subTag)
            self._exchangeData = gameData.getDataFromCache("heroCard", {["captainId"]=self._subTag}) 
            self._mainId = self._parmas.captains[self._subTag].id --挑战的主键id
            --刷新所有界面信息
            self:refreshInterFaceInfo()
        end
        self._notFirst = true
    end
end
function QunXiongMainLayer:refreshInterFaceInfo()
    --刷新总览信息
    if self._zonglan then
        if self._myTable then
            self._myTable:reloadData()
        end
        local titleStr = LANGUAGE_KEY_GETQUNXIONGNAME_BY_ID(self._subTag)
        local yijihuoStr = zc.lang("already_activated") .. "："..self._totalAct[self._subTag].activitied.."/"..self._totalAct[self._subTag].totalGroup
        self._zonglanTitleName:setText(titleStr)
        self._zonglanYijihuo:setText(yijihuoStr)
        self:initLeftData(self._parmas)
        self:createZLLeftInfo(self._leftBg)
    end
    --刷新图鉴信息
    if self._tujian then
        local _isVisible = self._tag == 2 and true or false
        self:createTujianInfo(_isVisible, true)
    end
    --刷新兑换信息
    if self._duihuan then
        if self._duihuanTable then
            self._duihuanTable:reloadData()
        end
    end
end

function QunXiongMainLayer:createZonglanInfo() 
    if self._zonglan then
        self._zonglan:setVisible(true)
    else
        local zlBg = zc.createSprite()
        zlBg:setContentSize( cc.size(zc.width-52, 520) )
        zlBg:setAnchorPoint(0, 0.5)
        zlBg:setPosition( cc.p(0, zc.height/2-21) )
        self:addChild(zlBg)
        self._zonglan = zlBg

        local zlSize = cc.size(zc.width-52, 520)

        local leftBg1 = zc.createNormalPop({
            srcTag = 3,
            width = 433,
            height = 520+31,
        })
        leftBg1:setAnchorPoint(0, 0.5)
        leftBg1:setPosition(35, zlSize.height/2)
        zlBg:addChild(leftBg1)

        local attrBg = zc.getScaleNode("res/Main/role/trinket/attrBg.png", cc.size(433, 136))
        attrBg:setAnchorPoint(cc.p(0.5, 0))
        attrBg:setPosition(cc.p(leftBg1:getContentSize().width/2, 3))
        leftBg1:addChild(attrBg)

        local leftBg = zc.createSprite()
        leftBg:setContentSize( cc.size(433, 520) )
        leftBg:setPosition(leftBg1:getContentSize().width/2, leftBg1:getContentSize().height/2)
        leftBg1:addChild(leftBg)
        self._leftBg = leftBg

        local rightBg = zc.createNormalPop({
            srcTag = 2,
            width = 571,
            height = 520+31,
        })
        rightBg:setAnchorPoint(cc.p(1, 0.5))
        rightBg:setPosition(cc.p(zlSize.width+3, leftBg1:getPositionY() ))
        rightBg:setName("rightBg")
        zlBg:addChild(rightBg)
                
        --
        self:createZLRightInfo(rightBg) --总览右界面
        self:createZLLeftInfo(leftBg) --总览左界面
    end
end
function QunXiongMainLayer:createZLRightInfo(rightBg) --总览右界面
    local rightBgSize = rightBg:getContentSize()

    -- 顶部
    local _topBg = cc.Sprite:create( "res/Main/role/common/top_bg.jpg" )
    _topBg:setAnchorPoint( 0.5, 1 )
    _topBg:setPosition( cc.p(rightBgSize.width/2,rightBgSize.height-5 ) )
    rightBg:addChild( _topBg )
    _topBg:setScaleX( 564/_topBg:getContentSize().width )
    local nameBg = zc.getScaleNode("res/Main/role/common/name_bg.png", cc.size(275,32) )
    nameBg:setPosition(cc.p(_topBg:getPositionX(), _topBg:getPositionY()- _topBg:getContentSize().height/2))
    rightBg:addChild(nameBg)

    local titleStr = LANGUAGE_KEY_GETQUNXIONGNAME_BY_ID(self._subTag)
    local titleName = zc.createLabel({
        text = titleStr,
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(25, nameBg:getContentSize().height/2),
        color = cc.c3b(219,212,167),
    })
    nameBg:addChild(titleName)
    
    local yijihuoStr = self._totalAct[self._subTag].activitied.."/"..self._totalAct[self._subTag].totalGroup
    local yijihuo = zc.createLabel({
        text = "(" .. zc.lang("already_activated") .. "："..yijihuoStr..")",
        outLine = true,
        fontSize = 18,
        ap = cc.p(0, 0.5),
        pos = cc.p(titleName:getPositionX()+titleName:getContentSize().width+5, titleName:getPositionY()),
    })
    nameBg:addChild(yijihuo) 
    self._zonglanTitleName = titleName
    self._zonglanYijihuo = yijihuo
    
    local tableSize = cc.size(rightBgSize.width-30, rightBgSize.height-57)
    local myTable = zc.ZCTableView:create(tableSize)
    myTable:setPosition(15,2)
    myTable:setInertia(true) --设置惯性
    myTable:setBounceable(true)
    myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) --设置横向纵向
    myTable:setDelegate()
    myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    
    rightBg:addChild(myTable)
    self._myTable = myTable
    
    local function cellSizeForTable(table,idx)
        return 143, tableSize.width
    end
    local function numberOfCellsInTableView(table)
        return #self._curGroupData
    end
    local function tableCellAtIndex(table,idx)
        local nowIdx = idx + 1
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(cc.size(tableSize.width, 143))
            self:createCell(cell, nowIdx)
        else
            self:updateCell(cell, nowIdx)
        end
        return cell
    end
    myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
    
    myTable:reloadData()
end

function QunXiongMainLayer:createCell(cell, idx)
    local cellSize = cell:getContentSize()
    local cellData = self._curGroupData[idx]
    local cell_img = zc.getScaleNode("res/Main/smithy/book/cellimg.png", cc.size(540, 135) )
    cell_img:setPosition(cellSize.width/2, cellSize.height/2)
    cell_img:setName("cell_img")
    cell:addChild(cell_img)
    local name = zc.createLabel({
        text = cellData.name,
        outLine = true,
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(21, 110),
    })
    name:setName("name")
    cell_img:addChild(name)

    local _attrSp = {} 
    local _attrWidth = 0
    for i = 1, 3 do
        if cellData["effectId"..i] and tonumber(cellData["effectId"..i]) > 0 then
            local _baseEffect = false
            if cellData["effectLayer"..i] and (tonumber(cellData["effectLayer"..i]) == 1 or tonumber(cellData["effectLayer"..i]) == 2) then
                _baseEffect = true
            end
            local attributeStr = LANGUAGE_getAttributeTextById(cellData["effectId"..i], _baseEffect)
            local _target = cellData["effectTarget"..i]
            if _target then
                attributeStr = LANGUAGE_getTargetTextById(_target)..attributeStr
            end
            local attribute = zc.createLabel({
                text = attributeStr,
                outLine = true,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(0, name:getPositionY()),
            })
            cell_img:addChild(attribute)
            local attributeNumStr = zc.getAttributeNumById(cellData["effectId"..i], cellData["effectValue"..i])
            local attributeNum = zc.createLabel({
                text = "+"..attributeNumStr,
                outLine = true,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(0, name:getPositionY()),
                color = display.COLOR_GREEN,
            })
            cell_img:addChild(attributeNum)

            attribute:setName("attribute"..i)
            attributeNum:setName("attributeNum"..i)

            _attrWidth = _attrWidth + attribute:getContentSize().width
            _attrWidth = _attrWidth + attributeNum:getContentSize().width

            _attrSp[#_attrSp+1] = attribute
            _attrSp[#_attrSp+1] = attributeNum
        end
    end
    local _posX = cellSize.width - _attrWidth - 15
    for i = 1, #_attrSp do
        if i == 1 then
            _attrSp[i]:setPositionX(_posX)
        else
            if i % 2 == 1 then
                _attrSp[i]:setPositionX(_attrSp[i-1]:getPositionX()+_attrSp[i-1]:getContentSize().width+3)
            else
                _attrSp[i]:setPositionX(_attrSp[i-1]:getPositionX()+_attrSp[i-1]:getContentSize().width)
            end
        end
    end

    --head
    local _idx = 1
    local _canActivity = true
    for i = 1, 6 do --heroCardId1
        if cellData["heroCardId"..i] and tonumber(cellData["heroCardId"..i]) > 0 then
            -- 头像
            local _showGray = true
            local _num = nil
            if self._ownHeros[tonumber(cellData["heroCardId"..i])] --如果拥有这个武将卡  
                and tonumber(self._ownHeros[tonumber(cellData["heroCardId"..i])].num) > 0 then 
                _showGray = false
                _num = self._ownHeros[tonumber(cellData["heroCardId"..i])].num
            else
                _canActivity = false
            end
            if self._activitied[tonumber(cellData.id)] then
                _showGray = false
            end

            local head = zc.createIconByData({
                data = {
                    mainType = zc.mainTypeSoldierCard,
                    type = 1, 
                    id = tonumber(cellData["heroCardId"..i]),
                }, 
                showGray = _showGray,
                showDetailPop = false,
                pos = cc.p(52+(_idx-1)*65, 50), 
                listener = function()
                    self:showHeroInfo(cellData["heroCardId"..i])
                end,
            })
            head:setScale(60/120)
            head:setName("head"..i)
            if not self._activitied[tonumber(cellData.id)] then
                self:createNumbg(head, _num)
            end
            cell_img:addChild(head)
            _idx = _idx+1
        end
    end

    local yijihuoimg = zc.createSprite("res/Main/research/qunxiong/yijihuo.png")
    yijihuoimg:setPosition(450, 38)
    yijihuoimg:setName("yijihuoimg")
    cell_img:addChild(yijihuoimg)

    --
    local _select = zc.createSprite("res/Main/common/button/common_btnSquare1_d.png")
    zc.setGray(_select)

    local activityBtn = zc.createCommomBtn({
        tag = 2,
        text = zc.lang("activated"),
        touchScale = 0.9,
        needSwallow = false,
        endCallback = function()
            if not _canActivity then
                zc.tipInfo(zc.lang("tips_hero_card_unenough"))
            else
                self:activityCard(cellData.id, cellData)
            end
        end,
        pos = cc.p(450, 48)
    })
    activityBtn:setName("activityBtn")
    cell_img:addChild(activityBtn)

    if idx == 1 and _canActivity then
        self._guide_activityBtn = activityBtn
    end

    if self._activitied[tonumber(cellData.id)] then
        yijihuoimg:setVisible(true)
        activityBtn:setVisible(false)
    else
        yijihuoimg:setVisible(false)
        activityBtn:setVisible(true)
        if _canActivity then
            activityBtn:setEnable(true)
        else
            activityBtn:setEnable(false)
        end
    end 
end

function QunXiongMainLayer:updateCell(cell, idx)
    local cellSize = cell:getContentSize()
    local cellData = self._curGroupData[idx]
    local cell_img = cell:getChildByName("cell_img")
    local name = cell_img:getChildByName("name")
    name:setText(cellData.name)

    local _attrSp = {} 
    local _attrWidth = 0
    for i = 1, 3 do
        local attribute = cell_img:getChildByName("attribute"..i)
        local attributeNum = cell_img:getChildByName("attributeNum"..i)
        if attribute then attribute:setVisible(false) end
        if attributeNum then attributeNum:setVisible(false) end

        if cellData["effectId"..i] and tonumber(cellData["effectId"..i]) > 0 then
            local _baseEffect = false
            if cellData["effectLayer"..i] and (tonumber(cellData["effectLayer"..i]) == 1 or tonumber(cellData["effectLayer"..i]) == 2) then
                _baseEffect = true
            end
            local attributeStr = LANGUAGE_getAttributeTextById(cellData["effectId"..i], _baseEffect)
            local _target = cellData["effectTarget"..i]
            if _target then
                attributeStr = LANGUAGE_getTargetTextById(_target)..attributeStr
            end
            local attributeNumStr = zc.getAttributeNumById(cellData["effectId"..i], cellData["effectValue"..i])

            if attribute then
                attribute:setVisible(true)
                attribute:setText(attributeStr)
                attributeNum:setVisible(true)
                attributeNum:setText("+"..attributeNumStr)
            else
                attribute = zc.createLabel({
                    text = attributeStr,
                    outLine = true,
                    fontSize = 20,
                    ap = cc.p(0, 0.5),
                    pos = cc.p(0, name:getPositionY()),
                    pixel = 1.3
                })
                cell_img:addChild(attribute)
                attributeNum = zc.createLabel({
                    text = "+"..attributeNumStr,
                    outLine = true,
                    fontSize = 20,
                    ap = cc.p(0, 0.5),
                    pos = cc.p(0, name:getPositionY()),
                    color = display.COLOR_GREEN,
                    pixel = 1.3
                })
                cell_img:addChild(attributeNum)
                attribute:setName("attribute"..i)
                attributeNum:setName("attributeNum"..i)
            end

            _attrWidth = _attrWidth + attribute:getContentSize().width
            _attrWidth = _attrWidth + attributeNum:getContentSize().width

            _attrSp[#_attrSp+1] = attribute
            _attrSp[#_attrSp+1] = attributeNum
        end
    end
    local _posX = cellSize.width - _attrWidth - 15
    for i = 1, #_attrSp do
        if i == 1 then
            _attrSp[i]:setPositionX(_posX)
        else
            if i % 2 == 1 then
                _attrSp[i]:setPositionX(_attrSp[i-1]:getPositionX()+_attrSp[i-1]:getContentSize().width+3)
            else
                _attrSp[i]:setPositionX(_attrSp[i-1]:getPositionX()+_attrSp[i-1]:getContentSize().width)
            end
        end
    end

    --head
    local _idx = 1
    local _canActivity = true
    for i = 1, 6 do --heroCardId1
        local head = cell_img:getChildByName("head"..i)
        if head then head:setVisible(false) end
        if cellData["heroCardId"..i] and tonumber(cellData["heroCardId"..i]) > 0 then
            -- 头像
            local _showGray = true
            local _num = nil
            if self._ownHeros[tonumber(cellData["heroCardId"..i])] --如果拥有这个武将卡  
                and tonumber(self._ownHeros[tonumber(cellData["heroCardId"..i])].num) > 0 then 
                _showGray = false
                _num = self._ownHeros[tonumber(cellData["heroCardId"..i])].num
            else
                _canActivity = false
            end
            if self._activitied[tonumber(cellData.id)] then
                _showGray = false
            end
            if head then
                head:setVisible(true)
                local newParmas = {
                    data = {
                        mainType = zc.mainTypeSoldierCard,
                        type = 1, 
                        id = tonumber(cellData["heroCardId"..i]),
                    }, 
                    showGray = _showGray,
                    listener = function()
                        self:showHeroInfo(cellData["heroCardId"..i])
                    end,
                }
                zc.updateIconByData(head,newParmas)
                if head:getChildByName("countBg") then
                    head:getChildByName("countBg"):removeFromParent()
                end
                if not self._activitied[tonumber(cellData.id)] then
                    self:createNumbg(head, _num)
                end
                _idx = _idx+1
            else
                local head = zc.createIconByData({
                    data = {
                        mainType = zc.mainTypeSoldierCard,
                        type = 1, 
                        id = tonumber(cellData["heroCardId"..i]),
                    }, 
                    showGray = _showGray,
                    pos = cc.p(52+(_idx-1)*65, 50), 
                    listener = function()
                        self:showHeroInfo(cellData["heroCardId"..i])
                    end,
                })
                head:setName("head"..i)
                head:setScale(60/120)
                if not self._activitied[tonumber(cellData.id)] then
                    self:createNumbg(head, _num)
                end
                cell_img:addChild(head)
                _idx = _idx+1
            end
        end
    end

    local yijihuoimg = cell_img:getChildByName("yijihuoimg")
    if yijihuoimg then yijihuoimg:setVisible(false) end
    local activityBtn = cell_img:getChildByName("activityBtn")
    if activityBtn then activityBtn:setVisible(false) end

    if self._activitied[tonumber(cellData.id)] then
        yijihuoimg:setVisible(true)
    else
        activityBtn:setVisible(true)
        if _canActivity then
            activityBtn:setEnable(true)
            activityBtn:setTouchEndedCall(function()
                if not _canActivity then
                    zc.tipInfo(zc.lang("tips_hero_card_unenough"))
                else
                    self:activityCard(cellData.id, cellData)
                end
            end)
        else
            activityBtn:setEnable(false)
        end
    end 
end  

function QunXiongMainLayer:createZLLeftInfo(leftBg) --总览左界面
    local zlBg = self._zonglan
    local leftSize = leftBg:getContentSize()
    leftBg:removeAllChildren()
    
    local roleBg = zc.getSpine( "jsxxyxg" )
    roleBg:setPosition( leftSize.width/2, 380 )
    roleBg:playAction( "animation", true )
    leftBg:addChild( roleBg , 10)
    
    -- 英雄
    -- dump(self._challengeData, "self._challengeData ==")
    local modName = self._challengeData["modelId"] or "hjxb"
    local armature = zc.battle.createHeroArmature({
        fileName = modName , 
        async = true, 
        asyncCallback = function ( _armature )
            if not tolua.isnull(roleBg)  then
                if _armature then
                    _armature:setOpacity(0)
                    _armature:runAction(cc.Sequence:create(cc.FadeIn:create(0.2),cc.CallFunc:create(function()
                        _armature:getAnimation():play("idle", -1, 1)
                    end)))
                end
            end
        end,
    })
    armature:setPosition( cc.p(roleBg:getContentSize().width/2, roleBg:getContentSize().height/2-70))
    armature:setScaleX( -1.0 )
    roleBg:addChild( armature , 1)
    self._record[modName] = true

    local weapon = cc.Sprite:create("res/Main/hero/hero_type1.png")
    weapon:setAnchorPoint(0.5, 1)
    weapon:setPosition(cc.p(370,459))
    leftBg:addChild(weapon,1)
    local nameBg = zc.createSprite("res/Main/smithy/clear/weaponNameBg.png")
    nameBg:setAnchorPoint(0.5, 1)
    nameBg:setPosition(cc.p(weapon:getPositionX(), weapon:getPositionY()-weapon:getContentSize().height+20))
    leftBg:addChild(nameBg)

    local name = zc.createLabel({
        text = self._challengeData.name,
        fontSize = 22,
        ap = cc.p(0.5, 1),
        pos = cc.p(nameBg:getContentSize().width/2-2, nameBg:getContentSize().height-20),
        width = 22,
    })
    nameBg:addChild(name)
    local myLab = zc.createLabel({
        text = "【       】",
        outLine = true,
        fontSize = 26,
        pos = cc.p(66, roleBg:getPositionY()+5),
        color = cc.c3b(246, 12, 217),
    })
    leftBg:addChild(myLab)
    myLab:setRotation(90)
    local _typeStr = zc.lang("easy")
    if tonumber(self._challengeData.type) == 2 then
        _typeStr = zc.lang("common")
    elseif tonumber(self._challengeData.type) == 3 then
        _typeStr = zc.lang("hard")
    end
    local _type = zc.createLabel({
        text = _typeStr,
        outLine = true,
        fontSize = 26,
        pos = cc.p(myLab:getPositionX()-2, roleBg:getPositionY()),
        color = cc.c3b(246, 12, 217),
        width = 26,
    })
    leftBg:addChild(_type)

    local dropBg = zc.getScaleNode("res/Main/role/common/shadow_bg.png", cc.size(405, 80) )
    dropBg:setAnchorPoint(0.5, 0)
    dropBg:setPosition(leftSize.width/2, 137)
    leftBg:addChild(dropBg)

    local _book_cur_attr_img = zc.createImageView({
        src = "res/Main/research/qunxiong/dropTitle.png",
        pos = cc.p(dropBg:getContentSize().width/2, dropBg:getContentSize().height+22),
    })
    dropBg:addChild(_book_cur_attr_img)
    local lace_left = zc.createSprite("res/Main/common/lace.png")
    lace_left:setAnchorPoint(1, 0.5)
    lace_left:setPosition(0, _book_cur_attr_img:getContentSize().height/2 )
    _book_cur_attr_img:addChild(lace_left)
    local lace_right = zc.createSprite("res/Main/common/lace.png")
    lace_right:setAnchorPoint(0, 0.5)
    lace_right:setPosition(_book_cur_attr_img:getContentSize().width, lace_left:getPositionY() )
    lace_right:setFlipX(true)
    _book_cur_attr_img:addChild(lace_right)

    local posDrop = zc.sortFromMiddle(cc.p(405/2, 77/2), #self._dropData, 70)
    for i = 1, #self._dropData do
        local dropItem = zc.createIconByData({
            data = {
                mainType = self._dropData[i].itemType,
                type = self._dropData[i].itemId, 
                id = tonumber(self._dropData[i].itemId),
            }, 
            showDetailPop = false,
            pos = posDrop[i], 
            listener = function()
                self:showHeroInfo(self._dropData[i].itemId)
            end,
        })
        dropItem:setScale(60/120)
        dropBg:addChild(dropItem)
        self:createNumbg(dropItem,  self._dropData[i].itemNum)
    end
    
    
    local posBtn = zc.sortFromMiddle(cc.p(leftSize.width/2, 65),2, 203)
    --刷新

    local refreshBtn = zc.createCommomBtn({
        tag =2,
        text = LANGUAGE_SHOP.refresh_space,
        needSwallow = false,
        endCallback = function()
            self:refreshChallenge()
        end,
        anchor = cc.p(0.5, 0.5),
        pos = posBtn[1]
    })
    leftBg:addChild(refreshBtn)
    local freeNum = tonumber(self._parmas.captainflushLimit) - tonumber(self._parmas.captainFlushNum)
    if freeNum > 0 then
        local freeNumLab = zc.createLabel({
            text = zc.lang("can_free_fresh") ..freeNum..zc.lang("ci"),
            outLine = true,
            fontSize = 18,
            pos = cc.p(refreshBtn:getPositionX() , refreshBtn:getPositionY()+refreshBtn:getContentSize().height/2+10),
            color = display.COLOR_GREEN,
        })
        leftBg:addChild(freeNumLab)
    else
        local priceId = tonumber(self._parmas.captainFlushNum) + 167
        if priceId > 217 then
            priceId = 217
        end
        local static = gameData.getDataFromCacheWithPrimaryKey("consume_price", priceId)
        local priceImg = zc.createSprite("res/Main/common/common_icon_gold.png")
        priceImg:setAnchorPoint(0.5, 0.5)
        priceImg:setPosition(refreshBtn:getPositionX()-25, refreshBtn:getPositionY()+refreshBtn:getContentSize().height/2+15)
        leftBg:addChild(priceImg)
        local price = zc.createLabel({
            text = static.price,
            outLine = true,
            fontSize = 22,
            ap = cc.p(0, 0.5),
            pos = cc.p(priceImg:getContentSize().width, priceImg:getContentSize().height/2),
        })
        priceImg:addChild(price)
    end
    
    --挑战
    local chaTimes = PlayerData:getResourcesInfo().captainEnergy
    local chaTimesLimit = PlayerData:getResourcesInfo().captainEnergyLimit


    local challengeBtn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("challenge_2"),
        needSwallow = false,
        endCallback = function()
            if chaTimes <=0 then
                zc.tipInfo(zc.lang("tips_challenge_times_over"))
            else
                --功能引导
                local _currentGID = getGuideManager():getCurrentGID()
                if _currentGID == GuideKey.KEY_12508 then
                    zc.setGuideFuncNextStep(_currentGID)
                end
                self:changellenge()
            end
        end,
        anchor = cc.p(0.5, 0.5),
        pos = posBtn[2]
    })
    leftBg:addChild(challengeBtn)

    local timesBg = zc.getScaleNode("res/Main/role/common/shadow_bg.png", cc.size(135, 28))
    timesBg:setAnchorPoint(cc.p(0.5, 0.5))
    timesBg:setPosition(cc.p(challengeBtn:getPositionX(), challengeBtn:getPositionY()+challengeBtn:getContentSize().height/2+15))
    leftBg:addChild(timesBg)
    local timesLab = zc.createLabel({
        text = zc.lang("cishu") .. "：",
        outLine = true,
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(18, 14),
    })
    timesBg:addChild(timesLab)
    
    local chaTimesLab = zc.createLabel({
        text = chaTimes.."/"..chaTimesLimit,
        outLine = true,
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(timesLab:getPositionX()+timesLab:getContentSize().width, timesLab:getPositionY()),
        color = display.COLOR_GREEN,
    })
    timesBg:addChild(chaTimesLab)
    self._fightLab = chaTimesLab

    local timesTip = zc.createLabel({
        text = zc.lang("tips_recover_every_hour"),
        outLine = true,
        fontSize = 18,
        pos = cc.p(timesBg:getPositionX(), challengeBtn:getPositionY()-challengeBtn:getContentSize().height/2-10),
        color = display.COLOR_GREEN,
    })
    leftBg:addChild(timesTip)
    if chaTimes > 0 then
        self._guide_challengeBtn = challengeBtn
    end
end

function QunXiongMainLayer:changellenge()
    local function getNpc(_id)
        return 
    end
    local _enemysData = self._challengeData or {}
    _enemysData["enemys"] = {}
    for i = 1, 9 do
        local enemyId = tonumber(_enemysData["location"..i])
        if enemyId ~= 0 then 
            _enemysData["enemys"][i] = gameData.getDataFromCacheWithPrimaryKey("captain_npc", enemyId)
        else
            _enemysData["enemys"][i] = {}
        end
    end

    local _dataInfo = {battleType = BattleType.QunXiong, mainId = self._mainId,enemys = _enemysData,topinfo = false}
    zc.createMatrixBattle( _dataInfo )

end
function QunXiongMainLayer:refreshChallenge()
    local subTag = self._subTag
    if not self._parmas.captains[subTag] then
        return
    end
    zc.sendHttp({
        apiName = "Captain_flush",
        params = {id=self._parmas.captains[subTag].id},
        successCallback = function (net_data)
            self._parmas.captains[subTag].lastGroupId = net_data.groupId
            self._parmas.captainFlushNum = net_data.captainFlushNum
            self:initLeftData(self._parmas)
            self:createZLLeftInfo(self._leftBg)
            PlayerData:updataData(net_data)
        end,
    })
end

function QunXiongMainLayer:createTujianInfo(_isVisible, _changeData)  --_changeData是否更新数据
    self:createSubTab()
    if self._tujian then
        self._tujian:setVisible(_isVisible)
        if not _changeData then
            return
        end
        local tjSize = self._tujian:getContentSize()
        local canLines =  math.floor((#self._exchangeData-1)/self._tujian._itemsOfLine)+1 --需要的行数
        local canBounce = canLines > 3 and true or false
        local scrollWidth = tjSize.width-62
        local scrollHeight = 455
        local innerHeight = canLines*136 > scrollHeight and canLines*136 or scrollHeight
        self._tujian._scrollview:setInnerContainerSize(cc.size(scrollWidth, innerHeight))
        
        local totalCardNum = #self._tujianCardList
        if #self._exchangeData > totalCardNum then
            totalCardNum = #self._exchangeData
        end
        self._tujianItems = {}
        for i = 1, totalCardNum do
            local _data = self._exchangeData[i]
            local cardInfo = self._tujianCardList[i]
            local modI = i <= self._tujian._itemsOfLine and (i-1) or ((i-1)%self._tujian._itemsOfLine)
            local posX = 45 + (modI)*self._tujian._distance
            local posY = innerHeight-45-139*( math.floor((i-1)/self._tujian._itemsOfLine) )
            if _data and _data.id then
                local heroData = gameData.getDataFromCacheWithPrimaryKey("heroCard", _data.id)
                if self._ownHeros[tonumber(heroData.id)] then
                    heroData.num = self._ownHeros[tonumber(heroData.id)].num
                else
                    heroData.num = 0
                end
                local countBg
                if cardInfo and cardInfo._cardBtn and cardInfo._cardName then
                    local cardBtn = cardInfo._cardBtn
                    local cardName = cardInfo._cardName
                    cardBtn:setVisible(true)
                    cardName:setVisible(true)
                    local params = {
                        data = {
                            mainType = zc.mainTypeSoldierCard,
                            type = 1, 
                            id = tonumber(heroData.id),
                        },
                        pos = cc.p(posX, posY),
                        listener = function()
                            self:showHeroInfo(heroData.id) 
                        end,
                        showDetailPop = true,
                    }
                    zc.updateIconByData(cardBtn, params)
                    cardName:setString(heroData.name or "")
                    cardName:setPosition(posX, posY-55)
                    countBg = cardBtn:getChildByName("countBg")
                else
                    local cardBtn = zc.createIconByData({
                        data = {
                            mainType = zc.mainTypeSoldierCard,
                            type = 1, 
                            id = tonumber(heroData.id),
                        },
                        anchor = cc.p(0.5, 0.5),
                        pos = cc.p(posX, posY),
                        listener = function()
                            self:showHeroInfo(heroData.id) 
                        end,
                        showName = false,
                    })
                    self._tujian._scrollview:addChild(cardBtn)
                    cardBtn:setScale(90/120)
                    countBg = self:createNumbg(cardBtn,  heroData.num > 0 and heroData.num or "")
                    local cardName = zc.createLabel({
                        text = heroData.name,
                        outLine = true,
                        fontSize = 16,
                        pos = cc.p(posX, posY-55),
                    })
                    self._tujian._scrollview:addChild(cardName)
                    local _index = #self._tujianCardList + 1
                    self._tujianCardList[_index] = {}
                    self._tujianCardList[_index]._cardBtn = cardBtn
                    self._tujianCardList[_index]._cardName = cardName
                end
                local numLabel = countBg:getChildByName("countLabel") 
                if tonumber(heroData.num) > 0 then
                    countBg:setVisible(true)
                    numLabel:setString(heroData.num)
                else
                    countBg:setVisible(false)
                end
                self._tujianItems[i] = {}
                self._tujianItems[i]["staticId"] = tonumber(heroData.id)
                self._tujianItems[i].numLabel = numLabel 
                self._tujianItems[i].countBg = countBg
            else
                if cardInfo and cardInfo._cardBtn and cardInfo._cardName then
                    cardInfo._cardBtn:setVisible(false)
                    cardInfo._cardName:setVisible(false)
                end
            end
        end
    else
        self._tujian = zc.createSprite()
        self._tujian:setContentSize( cc.size(813, 465) )
        self._tujian:setAnchorPoint(1, 0)
        self._tujian:setPosition(self._subTabBg:getContentSize().width-3, 3)
        self._subTabBg:addChild(self._tujian)

        self._tujian:setVisible(_isVisible)

        local tjBg = self._tujian
        local tjSize = tjBg:getContentSize()

        local itemsOfLine = math.floor((tjSize.width-62)/109) --一行的item个数(按至少109的间隔)
        local canLines =  math.floor((#self._exchangeData-1)/itemsOfLine)+1 --需要的行数
        local canBounce = canLines > 3 and true or false
        local scrollWidth = tjSize.width-62
        local scrollHeight = 455
        local innerHeight = canLines*136 > scrollHeight and canLines*136 or scrollHeight
        local myscrollview = zc.createScrollview({
            size = cc.size(scrollWidth, scrollHeight),
            innerSize = cc.size(scrollWidth, innerHeight),
            dir = ccui.ScrollViewDir.vertical,
            bounceEnable = canBounce,
        })
        myscrollview:ignoreAnchorPointForPosition(false) --是否忽略锚点，false不忽略
        myscrollview:setAnchorPoint(cc.p(0.5, 1))
        myscrollview:setPosition(cc.p(tjSize.width/2, tjSize.height-3))
        tjBg:addChild(myscrollview)
        local distance = (scrollWidth-90)/(itemsOfLine-1)
        self._tujianItems = {} --图鉴数量，用来更新数据
        self._tujianCardList = {} --记录

        self._tujian._scrollview = myscrollview
        self._tujian._itemsOfLine = itemsOfLine
        self._tujian._distance = distance

        for i = 1, #self._exchangeData do
            local heroData = gameData.getDataFromCacheWithPrimaryKey("heroCard", self._exchangeData[i].id)
            --记录个数 
            if self._ownHeros[tonumber(heroData.id)] then
                heroData.num = self._ownHeros[tonumber(heroData.id)].num
            else
                heroData.num = 0
            end

            local modI = i <= itemsOfLine and (i-1) or ((i-1)%itemsOfLine)
            local posX = 45 + (modI)*distance
            local posY = innerHeight-45-139*( math.floor((i-1)/itemsOfLine) )

            local cardBtn = zc.createIconByData({
                data = {
                    mainType = zc.mainTypeSoldierCard,
                    type = 1, 
                    id = tonumber(heroData.id),
                },
                anchor = cc.p(0.5, 0.5),
                pos = cc.p(posX, posY),
                listener = function()
                    self:showHeroInfo(heroData.id) 
                end,
                showName = false,
            })
            myscrollview:addChild(cardBtn)
            cardBtn:setScale(90/120)
            local countBg = self:createNumbg(cardBtn,  heroData.num > 0 and heroData.num or "")
            local cardName = zc.createLabel({
                text = heroData.name,
                outLine = true,
                fontSize = 16,
                pos = cc.p(posX, posY-55),
            })
            myscrollview:addChild(cardName)
                       
            self._tujianItems[i] = {}
            self._tujianItems[i]["staticId"] = tonumber(heroData.id)
            self._tujianItems[i].numLabel = countBg:getChildByName("countLabel") 
            self._tujianItems[i].countBg = countBg

            self._tujianCardList[i] = {}
            self._tujianCardList[i]._cardBtn = cardBtn
            self._tujianCardList[i]._cardName = cardName
        end
    end
end
-- cc.size(137, 491)
function QunXiongMainLayer:createDuihuanInfo()
    self:createSubTab()
    if self._duihuan then
        self._duihuan:setVisible(true)
    else
        self._duihuan = zc.createSprite()
        self._duihuan:setContentSize( cc.size(813, 465) )
        self._duihuan:setAnchorPoint(1, 0)
        self._duihuan:setPosition(self._subTabBg:getContentSize().width-3, 3)
        self._subTabBg:addChild(self._duihuan)

        local dhBg = self._duihuan
        local dhSize = dhBg:getContentSize()
        local itemsOfLine = 4
        local tableSize = cc.size(dhSize.width-62,dhSize.height-2)
        local tableNode = dhBg
        
        local myTable = zc.ZCTableView:create(tableSize)
        myTable:setPosition(31,2)
        myTable:setInertia(true) --设置惯性
        myTable:setBounceable(true)
        myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) --设置横向纵向
        myTable:setDelegate()
        myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
        
        dhBg:addChild(myTable)
        self._duihuanTable = myTable

        local function cellSizeForTable(table,idx)
            return 200, tableSize.width
        end
        local function numberOfCellsInTableView(table)
            return math.floor((#self._exchangeData-1)/itemsOfLine)+1 --需要的行数
        end
        local function tableCellAtIndex(table,idx)
            local nowIdx = idx + 1
            local cell = table:dequeueCell()
            if cell == nil then
                cell = zc.ZCTableViewCell:new()
                cell:setContentSize(cc.size(tableSize.width, 185))
                self:createDuihuanCell(cell, nowIdx, itemsOfLine)
            end
            self:updateDuihuanCell(cell, nowIdx, itemsOfLine)
            return cell
        end
        myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
        myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
        myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
        myTable:reloadData()
    end
end
function QunXiongMainLayer:createDuihuanCell(cell, nowIdx, itemsNum)
    local cellSize = cell:getContentSize()
    local distance = (cellSize.width-156)/(itemsNum-1)-1.5
    for i = 1, itemsNum do
        local posX = 156/2 + (i-1)*distance
        local posY = cellSize.height/2+8
        local cell_img = zc.createSprite("res/Main/research/qunxiong/exchange_bg.png")
        cell_img:setPosition(posX, posY)
        cell:addChild(cell_img)
        cell["_cell_img"..i] = cell_img

        local head, heroInfo= zc.createIconByData({
            data = {
                mainType = zc.mainTypeSoldierCard,
                type = 1, 
                id = 1,
            }, 
            showDetailPop = false,
            pos = cc.p(cell_img:getContentSize().width/2, 108),
        })
        head:setScale(0.6)
        cell_img:addChild(head)
        cell["_head"..i] = head
        local heroName = zc.createLabel({
            text = "",
            outLine = true,
            fontSize = 18,
            pos = cc.p(head:getPositionX(), 160),
            color = zc.nameColor(1),
        })
        cell_img:addChild(heroName)
        cell["_heroName"..i] = heroName

        local _normal = zc.createSprite("res/Main/common/button/btn_sec_u.png")
        local _select = zc.createSprite("res/Main/common/button/btn_sec_d.png")
        _select:setScale(128/184)
        _normal:setScale(128/184)
        local exchangeBtn = zc.createPushButton({
            normalNode = _normal,
            selectedNode = _select,
            needSwallow = false,
            needEnableWhenMoving = true,
            anchor = cc.p(0.5, 0),
            pos = cc.p(head:getPositionX(), 4),
            endCallback = function() end,
        })
        cell_img:addChild(exchangeBtn)
        cell["_exchangeBtn"..i] = exchangeBtn
        local consume = zc.createSprite(zc.getImgByType(zc.dataTypeHeroSoul))
        consume:setPosition(cc.p(35, exchangeBtn:getContentSize().height/2))
        exchangeBtn:addChild(consume)
        local consumeNum = zc.createLabel({
            text = "",
            outLine = true,
            fontSize = 18,
            ap = cc.p(0, 0.5),
            pos = cc.p(consume:getPositionX()+consume:getContentSize().width/2,  consume:getPositionY()),
        })
        exchangeBtn:addChild(consumeNum)
        exchangeBtn["consume"] = consume
        exchangeBtn["consumeNum"] = consumeNum
    end
end
function QunXiongMainLayer:updateDuihuanCell(cell, nowIdx, itemsNum)
    local cellSize = cell:getContentSize()
    local distance = (cellSize.width-156)/(itemsNum-1)-1.5
    local cell_img = cell._cell_img
    for i = 1, itemsNum do

        local cell_img = cell["_cell_img"..i]
        local head = cell["_head"..i]
        local heroName = cell["_heroName"..i]
        local exchangeBtn = cell["_exchangeBtn"..i]
        local consumeNum = exchangeBtn["consumeNum"]
        cell_img:setVisible(false)

        local dataId = (nowIdx-1)*itemsNum+i
        if self._exchangeData[dataId] then
            cell_img:setVisible(true)
            local heroData = self._exchangeData[dataId]
            --记录数量
            if self._ownHeros[tonumber(heroData.id)] then
                heroData.num =self._ownHeros[tonumber(heroData.id)].num
            else
                heroData.num = 0
            end

            local newParmas = {
                data = {
                    mainType = zc.mainTypeSoldierCard,
                    type = 1, 
                    id = tonumber(heroData.id),
                }, 
                showDetailPop = false,
                pos = cc.p(cell_img:getContentSize().width/2, 108),
                listener = function()
                    self:showHeroInfo(heroData.id)
                end,
            }
            local heroInfo = zc.updateIconByData(head,newParmas)
            if head:getChildByName("countBg") then
                head:getChildByName("countBg"):removeFromParent()
            end
            self:createNumbg(head,  heroData.num > 0 and heroData.num or "")

            heroName:setText(heroInfo.name or "???")
            heroName:setColor(zc.nameColor(heroInfo.star))

            exchangeBtn:setTouchEndedCall(function()
                local comfirm = ZCConfirmDialog:createWithParams({
                    title = zc.lang("prompt"),
                    msg = zc.lang("tips_sure_to_get_card"),
                    rightCallback = function()
                        self:exchangeCard(heroData.id)
                    end
                })
                self:addChild(comfirm, 11)
            end)
            consumeNum:setText(heroData.buy or 1)
        end
    end
end

--激活卡牌
function QunXiongMainLayer:activityCard(_id, _info)
    -- dump(_info)
    local subTag = self._subTag
    zc.sendHttp({
        apiName = "Captain_active",
        params = {id=_id},
        successCallback = function (net_data)
            --功能引导
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_12510 then
                getGuideManager():setFuncGuideOver()
            end

            zc.tipInfo(zc.lang("activate_success") .. "!")
            --更新拥有数据
            if _info then    
                for i = 1, 6 do --heroCardId1
                    if _info["heroCardId"..i] and tonumber(_info["heroCardId"..i]) > 0 then
                        local heroId = tonumber(_info["heroCardId"..i])
                        if self._ownHeros[heroId] then
                            self._ownHeros[heroId].num = tonumber(self._ownHeros[heroId].num)-1
                            if self._ownHeros[heroId].num <= 0 then
                                self._ownHeros[heroId].num = 0
                            end
                        end
                    end
                end  
            end
            --已激活增加
            local openInfo = net_data.combineIds
            for i = 1, #openInfo do
                local id = tonumber(openInfo[i])
                if not self._activitied[id] then
                    self._activitied[id] = "open"
                end
            end
            --记录数据
            self._totalAct[subTag].activitied = self._totalAct[subTag].activitied+1
            
            local yijihuoStr = zc.lang("already_activated") .. "："..self._totalAct[self._subTag].activitied.."/"..self._totalAct[self._subTag].totalGroup
            self._zonglanYijihuo:setText(yijihuoStr)

            if self._subNumLab then
                for i = 1, #self._subNumLab do
                    local numStr =self._totalAct[i].activitied.."/"..self._totalAct[i].totalGroup
                    self._subNumLab[i]:setText(numStr)
                end
            end
            if self._callback and type(self._callback) == "function" then
                self._callback(self._activitied, self._totalAct)
            end

            --刷新数量
            self:refreshAllData()
        end,
    })
end
--兑换卡牌
function QunXiongMainLayer:exchangeCard(_heroId)
    -- print("_heroId ==============================> ", _heroId)
    zc.sendHttp({
        apiName = "Captain_buy",
        params = {id=_heroId},
        successCallback = function (net_data)
            PlayerData:updataData(net_data)
            if tolua.isnull(self) then
                return
            end
            --更新拥有数据
            if self._ownHeros[tonumber(_heroId)] then
                self._ownHeros[tonumber(_heroId)].num = tonumber(net_data.num)
            else
                self._ownHeros[tonumber(_heroId)] = {}
                self._ownHeros[tonumber(_heroId)].mainId = tonumber(net_data.id)
                self._ownHeros[tonumber(_heroId)].staticId = tonumber(_heroId)
                self._ownHeros[tonumber(_heroId)].num = tonumber(net_data.num)
            end
            --刷新数量
            self:refreshAllData()
        end,
    })
end
function QunXiongMainLayer:refreshAllData() --刷新所有数据
    --刷新总览数据
    if self._myTable then
        self:getGroupData(self._subTag)
        self._myTable:reloadDataAndScrollToCurrentCell()
    end

    --刷新图鉴数据
    if self._tujianItems then
        for i = 1, #self._tujianItems do
            local numLabel = self._tujianItems[i].numLabel
            local countBg = self._tujianItems[i].countBg
            local heroId = tonumber(self._tujianItems[i].staticId)
            local textStr
            if self._ownHeros[heroId] and tonumber(self._ownHeros[heroId].num) > 0 then
                textStr = self._ownHeros[heroId].num
            else
                textStr = ""
            end
            numLabel:setText(textStr)
            if textStr ~= "" then
                countBg:setVisible(true)
            else
                countBg:setVisible(false)
            end
        end
    end
    --刷新兑换数据
    if self._duihuanTable then
        self._duihuanTable:reloadDataAndScrollToCurrentCell()
    end
end

function QunXiongMainLayer:onCleanup()
    if self._callback and type(self._callback) == "function" then
        self._callback()
    end
    local _forms = PlayerData:getNowFormationFiles()
    for k, v in pairs( self._record ) do
        -- 如果已上阵，不删除
        local _path, _resId = zc.battle.getHeroArmaturePathByResId( k )
        if not _forms[_resId] then
            ccs.ArmatureDataManager:getInstance():removeArmatureFileInfo( _path )
        end
    end
    helper.collectMemory(true)
end
function QunXiongMainLayer:onEnter( ... )
    if self._fightLab then
        self._fightLab:setText( PlayerData:getResourcesInfo().captainEnergy.."/"..PlayerData:getResourcesInfo().captainEnergyLimit)
    end
    if self._secondIn then
        -- 刷新顶部条
        local userTop = LayerManager.getTopInfoLayer()
        if userTop then
            userTop:dataChange()
        end
        zc.sendHttp({
            apiName = "Captain_captainInfo",
            successCallback = function (net_data)
                if tolua.isnull(self) then
                    return
                end
                self._ownHeros = {} 
                for k,v in pairs(net_data.heroCards) do
                    if tonumber(v.num) > 0 then 
                        local idx = tonumber(v.heroCardId) --用静态id做key
                        self._ownHeros[idx] = {}
                        self._ownHeros[idx].mainId = v.id            --主键id
                        self._ownHeros[idx].staticId = v.heroCardId  --卡牌静态id
                        self._ownHeros[idx].num = v.num              --卡牌数量
                    end
                end
                --刷新数量
                self:refreshAllData()
                self._parmas.captains[self._subTag] = net_data.captains[self._subTag]
                self:initLeftData(self._parmas)
                self:createZLLeftInfo(self._leftBg)
                if self._myTable then
                    self._myTable:scrollToFirstCell()
                end
            end,
        })
    end
    self._secondIn = true
    --功能引导
    self:addGuide()
end
function QunXiongMainLayer:createNumbg(_node, _num)
    local scaleSize = cc.size(30, 30)
    local countBg = zc.getScaleNode("res/Main/research/qunxiong/word_bg.png", scaleSize)
    countBg:setAnchorPoint(cc.p(1, 0))
    countBg:setPosition(cc.p(_node:getContentSize().width - 6, 5))
    countBg:setName("countBg")
    _node:addChild(countBg, 1)
    if not _num then
        _num = ""
    end
    local numLab = zc.createLabel({
        text = tostring(_num),
        outLine = true,
        fontSize = 22,
        pos = cc.p(scaleSize.width/2, scaleSize.height/2),
        color = display.COLOR_WHITE,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    numLab:setName("countLabel")
    countBg:addChild(numLab)
    if _num == "" or tonumber(_num) == 0 then
        countBg:setVisible(false)
    end
    return countBg
end
function QunXiongMainLayer:showHeroInfo(_heroId) --静态id
    if not self._dropStatic then
        self._dropStatic = {}
        local allDropInfo = gameData.getAllDataWithNoClone("drop_award")
        
        local dropStatic = gameData.getAllDataWithNoClone("captain_npcGroup")
        local dropdata = {}
        for i,v in pairs(dropStatic) do
            local dropidTa = string.split(v.drop, ",")
            for j = 1, #dropidTa do
                local dropid = string.split(dropidTa[j], "|")
                local dropItem = allDropInfo[dropid[1]]
                if dropItem and tonumber(dropItem.itemType) == zc.mainTypeSoldierCard then
                    if not self._dropStatic[tonumber(dropItem.itemId)] then
                        self._dropStatic[tonumber(dropItem.itemId)] = v["captainId"]
                    else
                        self._dropStatic[tonumber(dropItem.itemId)] = self._dropStatic[tonumber(dropItem.itemId)]..","..v["captainId"]
                    end
                end 
            end
        end
    end
    -- dump(self._dropStatic, "self._dropStatic =======  ")
    local ownData = {}
    ownData["ownInfo"]  = self._ownHeros[tonumber(_heroId)] or {}
    ownData["heroId"] = _heroId
    ownData["maxOpen"] = table.nums(self._openState)
    ownData["dropdata"] = self._dropStatic
    ownData["activitied"] = self._activitied
    ownData["ownHeros"] = self._ownHeros
    ownData["callback"] = function(data)
        -- dump(data)
        if data and data.type == 1 then
            --出售完刷新数据 (如果能回调这里说明已经是有武将卡了)
            self._ownHeros[tonumber(_heroId)].num = self._ownHeros[tonumber(_heroId)].num-(tonumber(data.num) or 1)
            self:refreshAllData()
        elseif data and data.type == 2 then --前往跳转
            if self._subTab and self._mainTab and data.tag then
                self:changeSubTab(self._subTab[tonumber(data.tag)])
                self:changeTab(self._mainTab[1])
            end
        end
    end
    zc.createSourcePop("QunXiongCardInfo", "src/layer/research/QunXiongCardInfoPop.lua", ownData)
end

--新手引导--功能引导
function QunXiongMainLayer:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12508 then
        getGuideManager():setObjTarget(self._guide_challengeBtn)
        getGuideManager():startGuide()
    elseif _currentGID == GuideKey.KEY_12510 then
        performWithDelay(self, function()
            getGuideManager():setObjTarget(self._guide_activityBtn)
            getGuideManager():startGuide()
        end, 0.01)
    end
end

return QunXiongMainLayer