--[[
    兵器谱
SmithyBookLayer.lua
]]

local SmithyBookLayer = class("SmithyBookLayer", function ()
    return zc.createNormalDialog()
end);
 
function SmithyBookLayer:create(params)--静态创建函数
    return SmithyBookLayer.new(params)
end
function SmithyBookLayer:ctor(params)
    self:initData(params)
    self:initUI()

    zc.addEventListener({
        name = CUSTOM_EVENT.EVENT_REFRESH_FORM_SWEEP ,
        callback = function()
            self:doResetFunction()
        end,
    })
end

function SmithyBookLayer:onEnter()
    self:addGuide()
end
function SmithyBookLayer:onCleanup()
    zc.removeEventListener(CUSTOM_EVENT.EVENT_REFRESH_FORM_SWEEP)
end
function SmithyBookLayer:initData(params)
    self._showAttrTag = 1 -- 1当前属性  2成就属性预览
    self._tagNames = LANGUAGE_get_weapon_type_name()
    table.insert(self._tagNames, 1, zc.lang("all"))
    self._tag = 1--默认是全部
    self._houseInfo = PlayerData:getHouseInfoByHouseId(11)

    --解锁信息  
    local houseEffect = gameData.getDataFromCache("houseEffect_smith" )
    self._unlockInfo = {}
    for i = 1, table.nums(houseEffect) do
        local v = houseEffect[tostring(i)]
        local spectraId = tostring(v["spectraId"])
        local spectraTa = string.split(spectraId, ",")
        for j = 1, #spectraTa do
            if spectraTa[j] and tonumber(spectraTa[j]) > 0 then
                if not self._unlockInfo[tonumber(spectraTa[j])] then
                    self._unlockInfo[tonumber(spectraTa[j])] = i
                end
            end
        end
    end

    --更新兵器信息
    self:resetWeaponInfo()

    --已经激活的成就
    local activitied = params.achievements
    self._activityInfo = {}
    for i = 1, #activitied do
        local achievementId = tonumber(activitied[i]["achievementId"])
        self._activityInfo[achievementId] = activitied[i]
    end
    --更新成就信息
    self:resetAchievement()
end
function SmithyBookLayer:resetAchievement() --重置成就信息
    self._weapon_achievement = {}
    local houseLevel = tonumber(self._houseInfo["level"])
    local nextLevel = 0
    local function getAchievement(_info)
        local canshowInfo = {}
        for i = 1,table.nums(_info) do
            local v = _info[tostring(i)]
            if v and v["spectraId"] then
                local achieveId = tonumber(v["id"])
                local spectraId = tonumber(v["spectraId"])
                local needLevel = self._unlockInfo[spectraId] or 1
                local _hasitem = true
                if houseLevel >= needLevel then
                    v["isOpen"] = true
                    v["openLevel"] = needLevel
                else
                    if nextLevel ~= 0 then
                        if needLevel == nextLevel then
                            v["isOpen"] = false
                            v["openLevel"] = needLevel
                        else
                            _hasitem = false
                        end
                    else
                        nextLevel = tonumber(needLevel)
                        v["isOpen"] = false
                        v["openLevel"] = needLevel
                    end
                end
                if _hasitem then
                    v["level"] = 0
                    if self._activityInfo[achieveId] then --如果已经激活
                        v["activitied"] = true
                        v["activityInfo"] = self._activityInfo[achieveId]
                        v["level"] = self._activityInfo[achieveId]["level"]
                    else
                        v["activitied"] = false
                    end
                    v["achievementId"] = achieveId
                    --设置权重
                    v["sortWeight"] = 1000 - tonumber(v["order"])
                    if v["isOpen"] then
                        if v["activitied"] then
                            v["sortWeight"] = 1000
                            if v["level"] and tonumber(v["level"]) < 5 then
                                v["sortWeight"] = 10000
                                local canLevelup = true
                                for j = 1,5 do
                                    local needId = tonumber(v["weaponId"..j])
                                    if needId > 0 then
                                        local flag = self:isHaveWeapon(needId)
                                        if not flag then
                                            canLevelup = false
                                            break
                                        end
                                    end
                                end
                                if canLevelup then
                                    v["sortWeight"] = 100000
                                end
                            elseif v["level"] and tonumber(v["level"]) >= 5 then
                                v["sortWeight"] = -1
                            end
                        else
                            local canActivity = true
                            for j = 1,5 do
                                local needId = tonumber(v["weaponId"..j])
                                if needId > 0 then
                                    local flag = self:isHaveWeapon(needId)
                                    if not flag then
                                        canActivity = false
                                        break
                                    end
                                end
                            end
                            if canActivity then
                                v["sortWeight"] = 1000000
                            end

                        end
                    else
                        v["sortWeight"] = 1
                    end
                    canshowInfo[#canshowInfo+1] = v
                end
            end
        end
        table.sort(canshowInfo,function(a,b)
            if tonumber(a.sortWeight) ~= tonumber(b.sortWeight) then
                return tonumber(a.sortWeight) > tonumber(b.sortWeight)
            else
                return tonumber(a.order) < tonumber(b.order)
            end
        end)
        return canshowInfo
    end
    local weapon_achievementDB = gameData.getDataFromCache("weapon_achievement")
    self._weapon_achievement = getAchievement(weapon_achievementDB)
end
function SmithyBookLayer:initUI()
    -- 背景图
    local bg = zc.createSprite()
    bg:setContentSize(cc.size(1120, 560))
    bg:setPosition(zc.width/2 +10,zc.height/2 - 10)
    self:addChild(bg, 6)
    self._bg = bg

    local ink_bottom = zc.createSprite("res/Main/role/common/ink_bottom.png")
    ink_bottom:setAnchorPoint(0.5, 0.5)
    ink_bottom:setPosition(80, zc.height/2+168)
    self:addChild(ink_bottom)
    ink_bottom:setRotation(90)

    local heroBody = zc.createSprite("res/Main/hero/body/14.png")
    heroBody:setAnchorPoint(0, 0.5)
    heroBody:setPosition(-40, zc.height/2+60)
    heroBody:setFlipX(true)
    heroBody:setScale(0.8)
    self:addChild(heroBody)

    --下方属性
    local attr_bg = zc.getScaleNode("res/Main/common/attr_bg.png", cc.size(472, 240))
    attr_bg:setAnchorPoint(cc.p(0, 0))
    attr_bg:setPosition(cc.p(0, 0))
    bg:addChild(attr_bg)
    self._attr_bg_s = attr_bg

    local right_bg = zc.createNormalPop({
        srcTag = 2,
        width = 518,
        height = 520+31,
    })
    right_bg:setAnchorPoint(cc.p(0, 0))
    right_bg:setPosition(cc.p(attr_bg:getPositionX()+attr_bg:getContentSize().width+15, 0))
    bg:addChild(right_bg, 10)
    self._rightBg = right_bg

    -- 顶部
    local _topBg = cc.Sprite:create( "res/Main/role/common/top_bg.jpg" )
    _topBg:setAnchorPoint( 0.5, 1 )
    _topBg:setPosition( cc.p(right_bg:getContentSize().width/2,right_bg:getContentSize().height-5 ) )
    right_bg:addChild( _topBg )
    _topBg:setScaleX( 509/_topBg:getContentSize().width )

    local nameBg = zc.getScaleNode("res/Main/role/common/name_bg.png", cc.size(211,32) )
    nameBg:setPosition(cc.p(_topBg:getPositionX(), _topBg:getPositionY()- _topBg:getContentSize().height/2))
    right_bg:addChild(nameBg)
    local titleName = zc.createLabel({
        text = zc.lang("smithy_book"),
        outLine = true,
        fontSize = 22,
        pos = cc.p(nameBg:getContentSize().width/2, nameBg:getContentSize().height/2),
        color = cc.c3b(219,212,167),
    })
    nameBg:addChild(titleName)

    -- --预览按钮 role_desc_btn_u
    local _look_btn = zc.createPushButton({
        normalFile = "res/Main/role/fetter/totalAddition.png",
        needSwallow = false,
        touchScale = 0.9,
        pos = cc.p(-40, right_bg:getContentSize().height - 108),
        endCallback = function()
            if self._showAttrTag == 2 then
                self._showAttrTag = 1
                self:initAchievementAttrAdd()
            elseif self._showAttrTag == 1 then
                self:initAchievementAttrAddByData(self._selectData)
            end
        end,
    })
    right_bg:addChild(_look_btn,1)
    --tabbtn
    self:createTabBtn()
end
function SmithyBookLayer:createTabBtn()

    local initPosY = 509-70/2
    for i=1,#self._tagNames do
        local tabBtn = zc.createPushButton({
            normalFile = "res/Main/common/button/tab_btn_noraml.png",
            needSwallow = false,
            touchScale = 0.9,
            anchor = cc.p(0, 0.5),
            pos = cc.p(self._rightBg:getContentSize().width, initPosY-(i-1)*72),
            endCallback = function() end,
        })
        tabBtn:setTag(i)
        self._rightBg:addChild(tabBtn)

        local labPos = cc.p(42, 36)
        local labAnchor = cc.p(0,0.5)
        if i == 1 then
            labPos = cc.p(123/2-15,36)
            labAnchor = cc.p(0.5, 0.5)
        end

        local normalLab = zc.createLabel({
            text = self._tagNames[i],
            fontSize = 23,
            ap = labAnchor,
            pos = labPos,
            outLine = true,
            color = zc.tabLabNormalColor1,
            color2 = display.COLOR_WHITE,
            pixel = 0.5,
        })
        tabBtn:addChild(normalLab, 2)
        local selectedLab = zc.createLabel({
            text = self._tagNames[i],
            fontSize = 23,
            ap = labAnchor,
            pos = labPos,
            outLine = true,
            color = display.COLOR_WHITE,
            color2 = zc.tabLabselectColor2 ,
            pixel = 1,
        })
        tabBtn:addChild(selectedLab, 2)
        selectedLab:setVisible(false)
        tabBtn._normalLab = normalLab
        tabBtn._selectLab = selectedLab

        if i > 1 then
            local itemimg = zc.getSprite({
                src = zc.getHeroTypeImg(i-1),
                pos = cc.p(5, tabBtn:getContentSize().height/2),
                ap = cc.p(0,0.5),
            })
            tabBtn:addChild(itemimg, 2)
        end

        tabBtn:setTouchEndedCall(function()
            self:changeTab(tabBtn)
        end)
        if self._tag == i then 
            self:changeTab(tabBtn)
        end
    end
end

function SmithyBookLayer:changeTab(_node)
    local function getNormal()
        return zc.createSprite("res/Main/common/button/tab_btn_noraml.png")
    end
    local function getSelect()
        return zc.createSprite("res/Main/common/button/tab_btn_select.png")
    end
    if not self._selectedBtn or self._selectedBtn ~= _node then
        local _tag = _node:getTag()
        if not self._selectedBtn then
            self._selectedBtn = _node
            self._selectedBtn:setStateNormal( getSelect() )
            self._selectedBtn._normalLab:setVisible(false)
            self._selectedBtn._selectLab:setVisible(true)
        else
            self._selectedBtn:setStateNormal( getNormal() )
            self._selectedBtn._normalLab:setVisible(true)
            self._selectedBtn._selectLab:setVisible(false)
            self._selectedBtn = _node
            self._selectedBtn:setStateNormal( getSelect() )
            self._selectedBtn._normalLab:setVisible(false)
            self._selectedBtn._selectLab:setVisible(true)
        end
        self._tag = _tag
        self._slectIndex = 1
        self:updateRightInfo()
    end
end
function SmithyBookLayer:updateRightInfo()
    self:setTabData()
    --初始化tableview
    if not self._bookTableView then
        self:initTableview()
    else
        self._bookTableView:reloadData()
    end
    if next(self._showInfo) then
        self._tipNoItemLab:setVisible(false)
    else
        self._tipNoItemLab:setVisible(true)
    end
end
--当前激活成就属性加成
function SmithyBookLayer:initAchievementAttrAdd()
    if self._showAttrTag == 1 then
        self._attr_bg_s:removeAllChildren()

        local _book_cur_attr_img = zc.createImageView({
            src = "res/Main/smithy/book/totalAttrBg.png",
            pos = cc.p(self._attr_bg_s:getContentSize().width/2, self._attr_bg_s:getContentSize().height-26),
        })
        self._attr_bg_s:addChild(_book_cur_attr_img)

        local lace_left = zc.createSprite("res/Main/common/lace.png")
        lace_left:setAnchorPoint(1, 0.5)
        lace_left:setPosition(0, _book_cur_attr_img:getContentSize().height/2 )
        _book_cur_attr_img:addChild(lace_left)

        local lace_right = zc.createSprite("res/Main/common/lace.png")
        lace_right:setAnchorPoint(0, 0.5)
        lace_right:setPosition(_book_cur_attr_img:getContentSize().width, lace_left:getPositionY() )
        lace_right:setFlipX(true)
        _book_cur_attr_img:addChild(lace_right)

        local _achievementList = {}
        local _typeIds = {}
        local _all_attr_list = {}
        for k,v in pairs(self._weapon_achievement) do
            --判断成就是否激活
            if (v.activitied) then 
                _achievementList[#_achievementList+1] = v
            end
        end
        
        for k,v in pairs(_achievementList) do
            local _data = gameData.getDataFromCache("weapon_achievement_level", {achievementId = v.achievementId, level = v.level})
            for i=1,3 do
                local _typeId = tonumber(v["effectId"..i])
                local _value = tonumber(_data["effectValue"..i])
                if _typeId ~= 0 then 
                    if inArray(_typeId,_typeIds) then
                        for _k,_v in pairs(_all_attr_list) do
                            if tonumber(_v.typeId) == tonumber(_typeId) then
                                _v.value = _v.value + _value
                            end
                        end
                    else
                       _typeIds[#_typeIds+1] = _typeId 
                       local _attr_data = {}
                       _attr_data.typeId = _typeId
                       _attr_data.value = _value
                       _all_attr_list[#_all_attr_list+1] = _attr_data
                    end
                end
            end
        end
        local leftSize = self._attr_bg_s:getContentSize()
        for i=1,#_all_attr_list do
            local posX = i % 2 == 0 and leftSize.width/4*3 or leftSize.width/4
            local posY = 220 - (math.floor((i+1)/2)) * 40
            local effectBg = zc.getScaleNode("res/Main/role/trinket/attrDi.png", cc.size(164, 33))
            effectBg:setAnchorPoint(cc.p(0.5, 0.5))
            effectBg:setPosition( cc.p(posX,posY) )
            self._attr_bg_s:addChild(effectBg)
            local _data = _all_attr_list[i]
            local _effecttext = LANGUAGE_getAttributeTextById( _data.typeId )
            local _effecttext = zc.createRichLabel({
                text = _effecttext.."：",
                fontSize = 22,
            })
            _effecttext:setAnchorPoint(0, 0.5)
            _effecttext:setPosition( cc.p(8, effectBg:getContentSize().height/2) )
            _effecttext:setGradientColor(cc.c4b(244, 159, 8, 255), cc.c4b(255, 255, 124, 255), cc.p(0, -1))
            effectBg:addChild(_effecttext)

            local effectvalue = zc.getAttributeNumById(_data.typeId, _data.value)
            local _valueLabel = zc.createLabel({
                text = effectvalue,
                fontSize = 22,
                ap = cc.p(1, 0.5),
                pos = cc.p(effectBg:getContentSize().width-8,effectBg:getContentSize().height/2),
                outLine = true,
                color = display.COLOR_GREEN
            })
            effectBg:addChild(_valueLabel)
        end
    end
end

--当前成就属性加成显示
function SmithyBookLayer:initAchievementAttrAddByData(_data)
    self._showAttrTag = 2
    self._attr_bg_s:removeAllChildren()
    self._attrScrollView = self:createAttrScrollView()
    self._attr_bg_s:addChild(self._attrScrollView)
    --激活属性显示
    local _book_cur_attr_img = zc.createImageView({
        src = "res/Main/smithy/book/curAttrBg.png",
        pos = cc.p(self._attr_bg_s:getContentSize().width/2, self._attr_bg_s:getContentSize().height-26),
    })
    self._attr_bg_s:addChild(_book_cur_attr_img)

    local lace_left = zc.createSprite("res/Main/common/lace.png")
    lace_left:setAnchorPoint(1, 0.5)
    lace_left:setPosition(0, _book_cur_attr_img:getContentSize().height/2 )
    _book_cur_attr_img:addChild(lace_left)

    local lace_right = zc.createSprite("res/Main/common/lace.png")
    lace_right:setAnchorPoint(0, 0.5)
    lace_right:setPosition(_book_cur_attr_img:getContentSize().width, lace_left:getPositionY() )
    lace_right:setFlipX(true)
    _book_cur_attr_img:addChild(lace_right)

    local _weapon_achievement_levelDB = gameData.getDataFromCache("weapon_achievement_level", {achievementId = _data.achievementId})
    local effectTable = {}
    for i=1,3 do 
        if tonumber(_data["effectId"..i]) ~= 0 then 
            effectTable[#effectTable+1] = _data["effectId"..i]
        end
    end
    local effectLine = (math.floor((#effectTable-1) / 2)+1) * 5 
    self._attrScrollView:setContentSize(cc.size(525,effectLine*42))
    local _posy = effectLine*42 - 17
    for i=1, #_weapon_achievement_levelDB do
        local starbg = zc.getScaleNode("res/Main/role/common/shadow_bg.png", cc.size(70, 33))
        starbg:setAnchorPoint(cc.p(0, 0.5))
        starbg:setPosition(cc.p(21, _posy))
        self._attrScrollView:addChild(starbg)

        local _spriteStar = cc.Sprite:create("res/Main/common/common_hero_star_1.png")
        _spriteStar:setPosition(cc.p(18,starbg:getContentSize().height/2))
        starbg:addChild(_spriteStar)
        local _levelLabel = zc.createLabel({
            text = "X" .. i,
            fontSize = 22,
            ap = cc.p(0, 0.5),
            pos = cc.p(35, _spriteStar:getPositionY() ),
            outLine = true,
        })
        starbg:addChild(_levelLabel)
        local curEffTable = _weapon_achievement_levelDB[i]
        for s=1,#effectTable do 
            local effectBg = zc.getScaleNode("res/Main/role/trinket/attrDi.png", cc.size(164, 33))
            effectBg:setAnchorPoint(cc.p(0, 0.5))
            self._attrScrollView:addChild(effectBg)
            local _effecttext = LANGUAGE_getAttributeTextById( effectTable[s] )
            local _effecttext = zc.createRichLabel({
                text = _effecttext.."：",
                fontSize = 22,
            })
            _effecttext:setAnchorPoint(0, 0.5)
            _effecttext:setPosition( cc.p(8, effectBg:getContentSize().height/2) )
            _effecttext:setGradientColor(cc.c4b(244, 159, 8, 255), cc.c4b(255, 255, 124, 255), cc.p(0, -1))
            effectBg:addChild(_effecttext)
            local effectvalue = zc.getAttributeNumById(effectTable[s], curEffTable["effectValue"..s])
            local _valueLabel = zc.createLabel({
                text = effectvalue,
                fontSize = 22,
                ap = cc.p(1, 0.5),
                pos = cc.p(effectBg:getContentSize().width-8,effectBg:getContentSize().height/2),
                outLine = true,
                color = display.COLOR_GREEN
            })
            effectBg:addChild(_valueLabel)
            if s == 1 then
                effectBg:setPosition(102,_posy)
                if #effectTable == 1 then --如果只有一行，位置下移
                    _posy = _posy - 42
                end
            elseif s == 2 then
                effectBg:setPosition(282,_posy)
                _posy = _posy - 42
            elseif s == 3 then
                effectBg:setPosition(102,_posy)
                _posy = _posy - 42
            elseif s == 4 then
                effectBg:setPosition(282,_posy)
            end
        end
    end
    self._attrScrollView:setContentOffset(self._attrScrollView:minContainerOffset()) 
end
function SmithyBookLayer:findIndex(_info) 
    if self._showInfo then
        for i = 1, #self._showInfo do
            local v = self._showInfo[i]
            if v and v.id and tonumber(v.id) == tonumber(_info.id) then
                local dotype, _isEnougth = self:checkNowState(v)
                if dotype == 1 or dotype == 2 then
                    if _isEnougth then
                        return i
                    else
                        return 1
                    end
                elseif dotype == 3 then
                    return 1
                end
            end
        end
    else
        return 1
    end
end
function SmithyBookLayer:checkNowState(_info)
    local _data = _info or {}
    --判断-激活-升级-满级状态
    local dotype = 0
    local _level = 0
    if not _data["activitied"] then --未激活
        dotype = 1
    else
        if _data["activityInfo"] and tonumber(_data["activityInfo"]["level"]) >= 5 then 
            dotype = 3 --满级
        else
            dotype = 2
        end
        _level = tonumber(_data["level"])
    end
    local _isEnougth = true --材料是否足够
    for i = 1, 5 do
        local needWeaponId = tonumber(_data["weaponId" .. i])
        local _hasWeapon = self:isHaveWeapon(needWeaponId)
        if needWeaponId and needWeaponId > 0 then
            if not _hasWeapon then
                _isEnougth = false
            end
        end
    end
    return dotype, _isEnougth
end
function SmithyBookLayer:setTabData()   
    self._showInfo = {}
    local function getCurList (types) 
        -- print("types --> ", types)
        for i=1,#self._weapon_achievement do
            local v = self._weapon_achievement[i]
            for j = 1, 5 do
                local weaponId = v["weaponId"..j]
                if weaponId and tonumber(weaponId) > 0 then
                    local static = gameData.getDataFromCacheWithPrimaryKey("weapon", weaponId)
                    if static and static["type"] then
                        if tonumber(static["type"]) == types then
                            self._showInfo[#self._showInfo + 1] = v
                            break
                        end
                    end
                end
            end
        end
    end

    if self._tag == 1 then 
        self._showInfo = self._weapon_achievement
    elseif self._tag == 2 then 
        --长柄
        getCurList(1)
    elseif self._tag == 3 then
        --单手
        getCurList(2)
    elseif self._tag == 4 then
        -- 法杖
        getCurList(3)
    elseif self._tag == 5 then
        --剑
        getCurList(4)
    elseif self._tag == 6 then 
        --扇子
        getCurList(5)
    elseif self._tag == 7 then 
        --法球
        getCurList(6)
    end
end
------------------------------------------------------------------------------------图鉴
function SmithyBookLayer:initTableview()
    --kong
    local tipNoItemLab = zc.createSprite("res/Main/common/empty.png")
    tipNoItemLab:setAnchorPoint(0.5, 0.5)
    tipNoItemLab:setPosition(self._rightBg:getContentSize().width-350, self._rightBg:getContentSize().height/2)
    self._rightBg:addChild(tipNoItemLab)
    tipNoItemLab:setVisible(false)
    self._tipNoItemLab = tipNoItemLab
    --tableview
    local _tableSize = cc.size(self._rightBg:getContentSize().width-10, 450)
    local _tableView = zc.ZCTableView:create(_tableSize)
    _tableView:setPosition(9, 10)
    _tableView:setInertia(true)
    _tableView:setBounceable(true)
    _tableView:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL)
    _tableView:setDelegate()
    _tableView:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    self._rightBg:addChild(_tableView)

    local _cellSize = cc.size(500, 140)
    local function numberOfCellsInTableView()
        return #self._showInfo-- --math.floor((#self._showInfo+3)/4)--
    end
    local function cellSizeForTable(table, idx) 
        return _cellSize.height , _cellSize.width--500,110--190, 700--宽 高
    end
    local function tableCellTouched(table,cell)
        local index = cell:getIdx() + 1
        local _data = self._showInfo[index]
        if _data then
            self._slectIndex = index
            self:createSelectEffect(cell["cellimg"])
            self:initAchievementAttrAddByData(_data)
            self._selectData = _data
        end
    end
    local function tableCellAtIndex(table, cellIndex) 
        cellIndex = cellIndex + 1
        local cell = table:dequeueCell()
        if not cell then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(_cellSize)
            self:createCell(cell,cellIndex)
        end
        local cellimg = cell["cellimg"]
        if cellimg and cellimg:getChildByName("selectEffect") then
            cellimg:getChildByName("selectEffect"):removeFromParent()
            self._selectEffect = nil
        end
        self:updateCell(cell,cellIndex)
        return cell 
    end
    _tableView:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    _tableView:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    _tableView:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    _tableView:registerScriptHandler(tableCellTouched,cc.TABLECELL_TOUCHED)

    _tableView:reloadData()
    self._bookTableView = _tableView



end
function SmithyBookLayer:createCell(cell, index)
    local cellSize = cell:getContentSize()

    local cellimg = zc.createSprite("res/Main/smithy/book/cellimg.png")
    cellimg:setAnchorPoint(0.5, 0.5)
    cellimg:setPosition(cellSize.width/2, cellSize.height/2-3)
    cell:addChild(cellimg)

    for i = 1, 5 do
        local _sprite = cc.Sprite:create("res/Main/common/common_hero_star_2.png")
        _sprite:setPosition(cc.p(350+(i-1)*30,109))
        cellimg:addChild(_sprite)
        cell["star"..i] = _sprite
    end
    local name =  zc.createLabel({
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(10, 109),
        outLine = true,
        color = display.COLOR_WHITE
    })
    cellimg:addChild(name)
    local openLevel = zc.createLabel({
        outLine = true,
        fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(name:getPositionX()+name:getContentSize().width, name:getPositionY()),
        color = display.COLOR_RED,
    })
    cellimg:addChild(openLevel)

    for i = 1, 5 do 
        local icon = zc.createIconByData({
            data = {
                mainType = 3,
                type = 1,
                id = 1,
                num = 1,
            }, 
            pos = cc.p(45+(i-1)*80, 50), 
            listener = function() 
            end
        })
        icon:setScale(71/120)
        cellimg:addChild(icon)
        cell["icon"..i] = icon
    end

    local activityBtn = zc.createCommomBtn({
        tag = 2,
        text = zc.lang("activated"),
        pos = cc.p(405, 45),
        touchScale = 0.9,
        needSwallow = false,
    })
    cellimg:addChild(activityBtn)
    local levelUpBtn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("upgrade"),
        pos = cc.p(405, 45),
        touchScale = 0.9,
        needSwallow = false,
    })
    cellimg:addChild(levelUpBtn)

    cell["cellimg"] = cellimg
    cell["name"] = name
    cell["openLevel"] = openLevel
    cell["activityBtn"] = activityBtn
    cell["levelUpBtn"] = levelUpBtn
end
function SmithyBookLayer:updateCell(cell, index)
    local _data = self._showInfo[index]
    local cellimg = cell["cellimg"]

    if _data then
        local name = cell["name"]
        local openLevel = cell["openLevel"]
        local activityBtn = cell["activityBtn"]
        local levelUpBtn = cell["levelUpBtn"]
        --
        name:setString(_data["name"] or "")
        if not _data["isOpen"] then
            openLevel:setVisible(true)
            openLevel:setString("(" .. LANGUAGE_getHouseNameById(11) .._data["openLevel"]..zc.lang("level_unlock") .. ")")
            openLevel:setPositionX(name:getPositionX()+name:getContentSize().width)
        else
            openLevel:setVisible(false)
        end
        
        --判断-激活-升级-满级状态
        local dotype = 0
        local _level = 0
        if not _data["activitied"] then --未激活
            dotype = 1
        else
            if _data["activityInfo"] and tonumber(_data["activityInfo"]["level"]) >= 5 then 
                dotype = 3 --满级
            else
                dotype = 2
            end
            _level = tonumber(_data["level"])
        end
        local _isEnougth = true --材料是否足够
        for i = 1, 5 do
            local icon = cell["icon"..i]
            local needWeaponId = tonumber(_data["weaponId" .. i])
            local _hasWeapon = self:isHaveWeapon(needWeaponId)
            local _showGray = false
            if not _hasWeapon then
                _showGray = true
            end
            if dotype == 3 then
                _showGray = false
            end
            if needWeaponId and needWeaponId > 0 then
                icon:setVisible(true)
                local newParmas = {
                    data = {
                        mainType = zc.mainTypeWeapon,
                        type = 1,
                        id = needWeaponId,
                    },
                    showDetailPop = true,
                    showGray = _showGray,
                    listener = function() 
                        local _data = gameData.getDataFromCacheWithPrimaryKey("synth_weapon", needWeaponId)
                        zc.createWeaponSynthesisPop({
                            itemType = 4,
                            itemId = _data.stuffId,
                            callback = function()
                                self:doResetFunction()
                            end,
                        })
                    end
                }
                zc.updateIconByData(icon,newParmas)
                if not _hasWeapon then
                    _isEnougth = false
                end
            else
                icon:setVisible(false)
            end
        end

        --星星
        for i = 1, 5 do
            local star = cell["star"..i]
            if dotype == 1 then
                star:setVisible(false)
            else
                star:setVisible(true)
                if i <= _level then
                    star:setTexture("res/Main/common/common_hero_star_1.png")
                else
                    star:setTexture("res/Main/common/common_hero_star_2.png")
                end
            end
        end

        if dotype == 1 then
            activityBtn:setVisible(true)
            levelUpBtn:setVisible(false)
            if _data["isOpen"] and _isEnougth then
                activityBtn:setEnable(true)
            else
                activityBtn:setEnable(false)
            end
            activityBtn:setTouchEndedCall(function()
                local function refresh(_refreshData)
                    if self._activityInfo and _refreshData and _refreshData.id then --更新已经激活信息
                        local achieveId = tonumber(_data.achievementId)
                        self._activityInfo[achieveId] = {}
                        self._activityInfo[achieveId].id = _refreshData.id
                        self._activityInfo[achieveId].achievementId = achieveId
                        self._activityInfo[achieveId].level = _refreshData.level
                    end
                    self:doResetFunction()
                end
                local params = {}
                params.data = _data
                params.callback = refresh
                zc.createSourcePop("SmithyBookUse", "src/layer/smithyHouse/SmithyBookUsePop.lua", params)
            end)

        else
            activityBtn:setVisible(false)
            levelUpBtn:setVisible(true)
            if dotype == 3 then
                levelUpBtn:setEnable(false)
            else
                if _isEnougth then
                    levelUpBtn:setEnable(true)
                else
                    levelUpBtn:setEnable(false)
                end
                levelUpBtn:setTouchEndedCall(function()
                    local function refresh(_refreshData)
                        if self._activityInfo and _refreshData and _refreshData.id then --更新已经激活信息
                            local achieveId = tonumber(_data.achievementId)
                            self._activityInfo[achieveId] = {}
                            self._activityInfo[achieveId].id = _refreshData.id
                            self._activityInfo[achieveId].achievementId = achieveId
                            self._activityInfo[achieveId].level = _refreshData.level
                        end
                        self:doResetFunction()
                    end
                    local params = {}
                    params.data = _data
                    params.callback = refresh
                    zc.createSourcePop("SmithyBookUse", "src/layer/smithyHouse/SmithyBookUsePop.lua", params)
                end)
            end
        end



        if self._slectIndex == index then
            if self._selectData and self._selectData["id"] == _data["id"] then

            else
                self:initAchievementAttrAddByData(_data)
                self._selectData = _data
            end
            self:createSelectEffect(cellimg)
        end
    end

end
--后续操作
function SmithyBookLayer:doResetFunction()
    self:resetWeaponInfo()
    self:resetAchievement()
    self:setTabData()
    self._slectIndex = self:findIndex(self._selectData)
    self._bookTableView:reloadData()
    self._bookTableView:scrollToCell(self._slectIndex-1, false)
end
--创建选中效果
function SmithyBookLayer:createSelectEffect(cellimg)
    if not tolua.isnull(self._selectEffect) then
        self._selectEffect:removeFromParent()
    end
    local selectEffect = zc.getScaleNode("res/Main/smithy/book/select.png", cc.size(cellimg:getContentSize().width+5, cellimg:getContentSize().height+5))
    selectEffect:setPosition(cc.p(cellimg:getContentSize().width/2-1, cellimg:getContentSize().height/2+2))
    cellimg:addChild(selectEffect)
    selectEffect:setName("selectEffect")
    self._selectEffect = selectEffect
end
--背包中是否有该兵器
function SmithyBookLayer:isHaveWeapon(_id)
    if self._weaponsById and self._weaponsById[tonumber(_id)] then
        return true , self._weaponsById[tonumber(_id)]
    end
    return false,nil
end

--重置拥有武器信息
function SmithyBookLayer:resetWeaponInfo()
    local myAllWeapons = PlayerData:getWeaponsInfo()
    local totalWeapons = {}
    for i=1,#myAllWeapons do 
        if tonumber(myAllWeapons[i]["isUser"]) == 0 then 
            if myAllWeapons[i]["heroId"] and tonumber(myAllWeapons[i]["heroId"]) == 0 then 
                totalWeapons[#totalWeapons + 1] = myAllWeapons[i]
            end
        end
    end
    self._weaponsById = {} --通过id直接查兵器,这里只列出每一种兵器的一个,升级或者激活后重新赋值
    for i = 1, #totalWeapons do
        local weaponId = tonumber(totalWeapons[i]["weaponId"])
        if not self._weaponsById[weaponId] then
            self._weaponsById[weaponId] = {}
            self._weaponsById[weaponId] = totalWeapons[i]
        end
    end
end


--创建scollView
function SmithyBookLayer:createAttrScrollView()
    local _attrScrollView = cc.ScrollView:create()
    _attrScrollView:setViewSize(cc.size(525, 190))
    _attrScrollView:setContentSize(cc.size(525, 190))
    _attrScrollView:setPosition(cc.p(0,5))
    _attrScrollView:ignoreAnchorPointForPosition(true)
    _attrScrollView:updateInset()
    _attrScrollView:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL) 
    _attrScrollView:setClippingToBounds(true)
    _attrScrollView:setBounceable(true)
    _attrScrollView:setContentOffset(_attrScrollView:minContainerOffset()) 
    return  _attrScrollView

end

function SmithyBookLayer:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_11202 then
        zc.setGuideFuncNextStep(_currentGID)
        self:addGuide()
    elseif inArray(_currentGID, GuideGroup.DUI_HUA) then 
        local function  _callBack()
            getGuideManager():setFuncGuideOver()
        end
        getGuideManager():setHeroFuncCallBack(_callBack)
        getGuideManager():startGuide()
    end
end

return SmithyBookLayer