--[[
    FileName: WeaponCopyListLayer.lua
    Author: wangming
    Date: 2017-02-27
    Purpose: 兵器副本列表
]]
local WeaponCopyListLayer = class( "WeaponCopyListLayer", function ()
    return zc.createNormalDialog({
    	showFlower = false,
	})
end)

function WeaponCopyListLayer:create(parmas)
    return WeaponCopyListLayer.new(parmas)
end

function WeaponCopyListLayer:onEnter()
    self:addGuide()
    if not self._haveInit then
        self._haveInit = true
        return
    end
    self:freshData()
end

function WeaponCopyListLayer:ctor(parmas)
    self._bossInfo = parmas.bossData or {}
    self._bossDb = gameData.getDataFromCacheWithPrimaryKey("bossWeapon", self._bossInfo.id)
    self._maxTollgateId = tonumber(parmas.maxTollgateId) or 0
	self._chapterId = parmas.chapterId
	self._cengId = tonumber(parmas.cengId) or -1
	self._tollgateId = parmas.tollgateId
    self._callback = parmas.callback
    self._cengDbs = gameData.getDataFromCache("weaponTollgateChapter", {type=self._chapterId})
    table.sort(self._cengDbs, function( a, b )
        local _numA = tonumber(a.number) or 0
        local _numB = tonumber(b.number) or 0
        return _numA < _numB
    end)

    self:initUp()
    self:initDown()
    self:freshUI()
end


function WeaponCopyListLayer:initUp()
    -- upBase
    local _upDi = zc.createSprite("res/Main/weaponCopy/upCellDi.png")
    _upDi:setAnchorPoint(0.5, 0)
    _upDi:setPosition(zc.width*0.5, zc.height*0.5 + 95)
    self:addChild(_upDi)

    local _upSize = _upDi:getContentSize()

    local _h = 207
    local _scrollView = zc.createScrollview({
        size = cc.size(516, _h),
        pos = cc.p(0, (_upSize.height - _h)*0.5),
        touchEnable = false
    })
    _upDi:addChild(_scrollView)
    local _upHero = zc.createSprite()
    _upHero:setAnchorPoint(0, 1)
    _upHero:setPosition(0, _h)
    _scrollView:addChild(_upHero)
    self._upHero = _upHero

    local _frame = ccui.Scale9Sprite:create(cc.rect(13, 60, 9, 62), "res/Main/common/frame_s.png")
    _frame:setContentSize(_upSize.width + 10, _upSize.height + 10)
    _frame:setPosition(_upSize.width*0.5, _upSize.height*0.5)
    _upDi:addChild(_frame, 1)
    
    -- num
    local _chapterNumDi = zc.getSprite({
        src = "res/Main/weaponCopy/cengNumDi.png",
        pos = cc.p(_upSize.width*0.5 - 30, _upSize.height*0.5 + 40)
    })
    _upDi:addChild(_chapterNumDi)
    _chapterNumDi:setRotation(-15)

    local _chapterNum = zc.createFntLabel({
        fnt = "res/Main/chapterMain/chapterBigNum.fnt",
        text = 1,
        ap = cc.p(0.5, 0.5),
        pos = cc.p(_chapterNumDi:getContentSize().width*0.5, _chapterNumDi:getContentSize().height*0.5 + 13),
        addwidth = -10,
    })
    _chapterNumDi:addChild(_chapterNum)
    self._chapterNum = _chapterNum

    -- reward
    local _rewardSize = cc.size(330, 90)
    local _rewardDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _rewardSize)
    _rewardDi:setAnchorPoint(0, 0)
    _rewardDi:setPosition(_upSize.width*0.5, 15)
    _upDi:addChild(_rewardDi)

    local _rewardTips = zc.createSprite("res/Main/weaponCopy/dropTips.png")
    _rewardTips:setAnchorPoint(1, 0.5)
    _rewardTips:setPosition(_rewardSize.width + 10, _rewardSize.height + 10)
    _rewardDi:addChild(_rewardTips, 1)

    local _part = 6
    local _tableSize = cc.size(_rewardSize.width - _part, _rewardSize.height)
    local tabTableview = zc.ZCTableView:create(_tableSize)
    tabTableview:setBounceable(true)
    tabTableview:setInertia(true)
    tabTableview:setPosition(_part*0.5, 0)
    tabTableview:setDirection(cc.SCROLLVIEW_DIRECTION_HORIZONTAL)
    tabTableview:setDelegate()
    tabTableview:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)

    local _cellW = 80
    local function cellSizeForTable(table, index) 
        return _tableSize.height, _cellW
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell.icon = zc.createIconByData({
                data = {mainType = 1, type = 1, id = 1},
                pos = cc.p(_cellW*0.5 + 25, _tableSize.height*0.5 + 28)
            })
            cell:addChild(cell.icon)
            cell:setScale(0.6)
        end
        local _info = self._rewardGroup[index + 1]
        zc.updateIconByData(cell.icon, {
            data = {mainType = _info[1], type = _info[2], id = _info[2]},
        })
        cell.icon:setTouchEndedCall(function()
            local _px = cell:getPositionX() + table:getContentOffset().x + _cellW*0.5
            if _px < 0 or _px > _tableSize.width then
                return
            end
            cell.icon:showTip()
        end)

        return cell
    end

    local function numberOfCellsInTableView()
        return #self._rewardGroup
    end

    tabTableview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    tabTableview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    tabTableview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    _rewardDi:addChild(tabTableview)
    self._rewardTab = tabTableview

    -- openBoss 
    local _btnSize = cc.size(120, 120)
    local _btnNode = cc.Node:create()
    _btnNode:setContentSize(_btnSize)
    local _bossBtn = zc.createPushButton({
        normalNode = _btnNode,
        pos = cc.p(_upSize.width - 130, 80),
        endCallback = function()
            local _flag, _chapterId = self:checkBossFlag()
            if _flag == 2 then
                local _currentGID = getGuideManager():getCurrentGID()
                if _currentGID == GuideKey.KEY_13211 then
                    zc.setGuideFuncNextStep(_currentGID, false)
                end
                -- 准备挑战boss
                local _params = {
                    bossData = self._bossInfo,
                    tollgateDb = self._bossDb,
                }
                zc.createSourcePop("WeaponCopyInfoPop", "src/layer/weaponCopy/WeaponCopyInfoPop.lua", _params) 
            elseif _flag == 1 then
                self._cengId = _chapterId
                self:freshUI()
            end
        end
    })
    _bossBtn:setVisible(false)
    _upDi:addChild(_bossBtn, 5)
    self._bossBtn = _bossBtn

    local _spine = zc.getSpine("bosstuxi")
    _spine:setPosition(_btnSize.width*0.5, _btnSize.height*0.5)
    _bossBtn:addChild(_spine)
    _spine:registerSpineEventHandler( function ( event )
        local name  = event.animation
        if name == "boss02" then
            _spine:playAction("boss01", true)
        end
    end, sp.EventType.ANIMATION_COMPLETE)
    _bossBtn.eff = _spine

    local _tipDi = zc.createSprite("res/Main/weaponCopy/tipsDi.png")
    _tipDi:setAnchorPoint(0.5, 0)
    _tipDi:setPosition(_btnSize.width*0.5, 0)
    _bossBtn:addChild(_tipDi) 
    _bossBtn.tipDi = _tipDi

    local _tipLab = zc.createLabel({
        text = "",
        fontSize = 20,
        color = cc.c3b(216, 206, 128),
        pos = cc.p(_tipDi:getContentSize().width*0.5, _tipDi:getContentSize().height*0.5)
    })
    _tipDi:addChild(_tipLab)  
    _bossBtn.tipLab = _tipLab  



    -- left right btn
    local _leftBtn = zc.createPushButton({
        normalNode = zc.createSprite("res/Main/weaponCopy/arrow.png"),
        pos = cc.p(35, _upSize.height*0.5),
        endCallback = function()
            if self._cengId > 1 then
                self._cengId = self._cengId - 1
                self:freshUI()
            end
            self._leftBtn:setVisible(self._cengId ~= 1)
            self._rightBtn:setVisible(self._cengId ~= self._maxCen)
        end
    })
    _upDi:addChild(_leftBtn, 1)
    self._leftBtn = _leftBtn
    local _time, _px = 1.2, 10
    _leftBtn:runAction(cc.RepeatForever:create(cc.Sequence:create(
        cc.MoveBy:create(_time, cc.p(_px, 0)),
        cc.MoveBy:create(_time, cc.p(-_px, 0))
    )))

    local _node = zc.createSprite("res/Main/weaponCopy/arrow.png")
    _node:setScaleX(-1)
    local _rightBtn = zc.createPushButton({
        normalNode = _node,
        pos = cc.p(_upSize.width - _leftBtn:getPositionX(), _leftBtn:getPositionY()),
        endCallback = function()
            if self._cengId < self._maxCen then
                self._cengId = self._cengId + 1
                self:freshUI()
            end
            self._leftBtn:setVisible(self._cengId ~= 1)
            self._rightBtn:setVisible(self._cengId ~= self._maxCen)
        end
    })
    _upDi:addChild(_rightBtn, 1)
    self._rightBtn = _rightBtn
    _rightBtn:runAction(cc.RepeatForever:create(cc.Sequence:create(
        cc.MoveBy:create(_time, cc.p(-_px, 0)),
        cc.MoveBy:create(_time, cc.p(_px, 0))
    )))
end


function WeaponCopyListLayer:initDown()
    -- downBase
    local _downNode = cc.Node:create()
    _downNode:setPosition(zc.width*0.5, zc.height*0.5 - 110)
    self:addChild(_downNode)

    for i=1, 2 do
    	local _rope = zc.createSprite("res/Main/weaponCopy/rope.png")
    	_rope:setPosition(0, 110 - (i - 1)*215)
    	_downNode:addChild(_rope)

        local _flag = i == 1 and -1 or 1
        local _juanzhou = zc.createSprite("res/Main/weaponCopy/juanzhou.png")
        _juanzhou:setPosition(510*_flag, 0)
        _downNode:addChild(_juanzhou, 1)
    end


    -- list
    local _tableSize = cc.size(930, 325)
    local tabTableview = zc.ZCTableView:create(_tableSize)
    tabTableview:setPosition(-_tableSize.width*0.5, -_tableSize.height*0.5)
    tabTableview:setDirection(cc.SCROLLVIEW_DIRECTION_HORIZONTAL)
    tabTableview:setDelegate()
    tabTableview:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)

    local _cellW = 90
    local function cellSizeForTable(table, index) 
        return _tableSize.height, _cellW
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell.di = zc.createPushButton({
            	normalFile = "res/Main/weaponCopy/cellOpen.png",
            	disableFile = "res/Main/weaponCopy/cellUnOpen.png",
                needSwallow = false,
                needEnableWhenMoving = true,
            	pos = cc.p(_cellW*0.5 + 15, _tableSize.height*0.5),
            	endCallback = function()
                    local _currentGID = getGuideManager():getCurrentGID()
                    if _currentGID == GuideKey.KEY_13207 then
                        zc.setGuideFuncNextStep(_currentGID, false)
                    end
                    -- 准备挑战对应个关卡
                    local _params = {
                        tollgateDb = cell._db,
                        maxTollgateId = self._maxTollgateId,
                    }
                    zc.createSourcePop("WeaponCopyInfoPop", "src/layer/weaponCopy/WeaponCopyInfoPop.lua", _params)
            	end
        	})
            cell:addChild(cell.di)

            cell.label = zc.createLabel({
                outLine = true,
                pixel = 2,
                fontSize = 20,
                color = cc.c3b(255, 217, 168),
                pos = cc.p(cell.di:getContentSize().width*0.5, cell.di:getContentSize().height*0.5 + 20),
            })
            cell.di:addChild(cell.label)

            cell.titleLeftSp = zc.getSprite({
                src = "res/Main/common/lace.png",
                ap = cc.p(1, 0.5),
                pos = cc.p(cell.di:getPositionX() - 20, cell.di:getPositionY()),
            })
            cell.titleLeftSp:setRotation(90)
            cell.di:addChild(cell.titleLeftSp)

            cell.titleRightSp = zc.getSprite({
                src = "res/Main/common/lace.png",
                ap = cc.p(1, 0.5),
                pos = cc.p(cell.di:getPositionX() - 20, cell.di:getPositionY()),
            })
            cell.titleRightSp:setRotation(-90)
            cell.di:addChild(cell.titleRightSp)

            cell.bossTag = zc.createSprite("res/Main/weaponCopy/bossTag.png")
            cell.bossTag:setPosition(cell.di:getContentSize().width*0.5, 55)
            cell.di:addChild(cell.bossTag)


            cell.newTag = zc.createSprite("res/Main/weaponCopy/newTag.png")
            cell.newTag:setPosition(cell.di:getContentSize().width*0.5, cell.di:getContentSize().height - 30)
            cell.di:addChild(cell.newTag)
        end

        local _db = self._listDb[index + 1]
        cell._db = _db
        local _flag = self:getStatusFlag(_db)
        cell.di:setEnable(_flag)
        cell.label:setVisible(_flag)
        cell.titleLeftSp:setVisible(_flag)
        cell.titleRightSp:setVisible(_flag)

        local _showType = tonumber(_db.showType) or 0
        if _showType == 1 then
            cell.di:getStateNormal():setTexture("res/Main/weaponCopy/cellOpen.png")
            cell.di:getStateDisable():setTexture("res/Main/weaponCopy/cellUnOpen.png")
        else 
            cell.di:getStateNormal():setTexture("res/Main/weaponCopy/cellOpenBoss.png")
            cell.di:getStateDisable():setTexture("res/Main/weaponCopy/cellUnOpenBoss.png")
            if _showType == 3 then
                zc.setGray(cell.bossTag, not _flag)
            end 
        end
        cell.bossTag:setVisible(_showType == 3)
        

        if _flag then
            cell.label:setString(zc.lang("num_di") .. "\n" .. LANGUAGE_GET_CHINESE_NUM(index + 1) .. "\n" .. zc.lang("num_guan"))
            local _height = cell.label:getContentSize().height
            cell.titleLeftSp:setPositionY(cell.label:getPositionY() + _height*0.5 + 5)
            cell.titleRightSp:setPositionY(cell.label:getPositionY() - _height*0.5 - 5)
        end

        _flag = tonumber(_db.id) == self._newTollId
        cell.newTag:setVisible(_flag)
        if _flag then
            local _time = 1.2
            cell.newTag:runAction(cc.RepeatForever:create(cc.Sequence:create(cc.FadeTo:create(_time, 255*0.3), cc.FadeTo:create(_time, 255))))
        else
            cell.newTag:stopAllActions()
        end

        if not tolua.isnull(cell.guideHand) then
            cell.guideHand:removeFromParent()
            cell.guideHand = nil
        end

        return cell
    end

    local function numberOfCellsInTableView()
        return #self._listDb
    end

    tabTableview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    tabTableview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    tabTableview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    _downNode:addChild(tabTableview)
    self._listTab = tabTableview
end

function WeaponCopyListLayer:getStatusFlag( db )
    local _db = db or {}
    local _id = tonumber(_db.id) or -1
    local _activateId = tonumber(_db.activateId) or -1
    local _flag = false
    if _activateId == 0 then
        _flag = true
    elseif _id > self._maxTollgateId then
        if _activateId <= self._maxTollgateId then
            _flag = true
        end
    else
        _flag = true
    end
    return _flag
end

function WeaponCopyListLayer:freshUI()
    self:freshHead()
    self:freshList()
end

function WeaponCopyListLayer:freshHead( isBossComing )
    self._maxCen = self:getMaxCeng(self._maxTollgateId)
    
    if self._cengId == -1 then
        self._cengId = self._maxCen
    end
    
    if self._maxCen < #self._cengDbs then
        self._maxCen = self._maxCen + 1
    end
    if self._cengId > self._maxCen then
        self._cengId = self._maxCen
    end
    self._leftBtn:setVisible(self._cengId ~= 1)
    self._rightBtn:setVisible(self._cengId ~= self._maxCen)

    self._chapterNum:setString(self._cengId)


    self._rewardGroup = {}
    local _cengDb = self._cengDbs[self._cengId] or {}
    self._upHero:setTexture("res/Main/hero/list/" .. tostring(_cengDb.backgroundShow) .. ".png")
    local _dropShowInfo = string.split(_cengDb.drop or "", ",")
    for k,v in pairs(_dropShowInfo) do
        local _tmp = string.split(v, "|")
        table.insert(self._rewardGroup, _tmp)
    end
    self._rewardTab:reloadData()

    self:checkBossFlag(isBossComing)
    
end

function WeaponCopyListLayer:getMaxCeng( tollId )
    self._newTollId = nil
    local _tollgateDb = gameData.getDataFromCache("weaponTollgate", {activateId = tollId, type = self._chatperId})
    if next(_tollgateDb) ~= nil then
        self._newTollId = _tollgateDb.id
    else
        _tollgateDb = gameData.getDataFromCacheWithPrimaryKey("weaponTollgate", tollId)
    end
    return tonumber(_tollgateDb.chapterId) or 1
end

function WeaponCopyListLayer:checkBossFlag(isBossComing)
    local _flag, _chatperId = 0, 0
    local _nowTime = PlayerData:getTime()
    if tonumber(self._bossInfo.id) ~= 0 and _nowTime < self._bossInfo.lifeTime then
        _flag = 1
        _chatperId = tonumber(self._bossDb.chapterId) or 0
        if _chatperId == self._cengId then
            _flag = 2
        end
    end
    
    self._bossBtn:setVisible(_flag ~= 0)
    self._bossBtn.tipDi:setVisible(_flag == 1)
    if _flag ~= 0 then
        if isBossComing then
            self._bossBtn.eff:playAction("boss02")
        else
            self._bossBtn.eff:playAction(_flag == 1 and "boss03" or "boss01", true)
            if _flag == 1 then
                local _str = zc.lang("num_di") .. LANGUAGE_GET_CHINESE_NUM(_chatperId) .. zc.lang("num_ceng")
                self._bossBtn.tipLab:setString(_str)
            end
        end
    end
    return _flag, _chatperId
end

function WeaponCopyListLayer:freshList()
    self._listDb = gameData.getDataFromCache("weaponTollgate", {type=self._chapterId, chapterId = self._cengId})
    table.sort(self._listDb, function( a, b )
        local _idA = tonumber(a.id)
        local _idB = tonumber(b.id)
        return _idA < _idB
    end)
    self._listTab:reloadData()
end

function WeaponCopyListLayer:freshData()
    local data = PlayerData:getLastSceneData() or {}
    if data.lastScene ~= "WeaponCopy" then
        return
    end
    local _flagHead, _flagList
    local _isNew = tonumber(data.isNew) or 0
    local _isFirst = tonumber(data.isFirst) or 0
    if data.boss and type(data.boss) == "table" then
        local _boss = data.boss[tostring(self._chapterId)]
        if _boss and next(_boss) then
            local _newId = _boss.id
            if _newId ~= self._bossInfo.id or _isNew == 1 then
                _flagHead = true
            end
            self._bossInfo = _boss or {}
            self._bossDb = gameData.getDataFromCacheWithPrimaryKey("bossWeapon", self._bossInfo.id)
        end
    end
    if data.maxTollgateId and type(data.maxTollgateId) == "table" then
        local _maxTollgateId = tonumber(data.maxTollgateId[tostring(self._chapterId)])
        if _maxTollgateId and _maxTollgateId ~= self._maxTollgateId then
            if _isNew ~= 1 then
                local _maxOld = self:getMaxCeng(self._maxTollgateId)
                local _maxNew = self:getMaxCeng(_maxTollgateId)
                if _maxOld ~= _maxNew then
                    self._cengId = -1
                    _flagHead = true
                end
            end
            self._maxTollgateId = _maxTollgateId
            _flagList = true
        end
    end
    local function _doFresh()
        if _flagHead then
            self:freshHead(_isNew == 1)
        end
        if _flagList then
            self:freshList()
        end
        if data.guideFlag then
            self:addHandFlag()
        end
    end
    if self._callback then
        self._callback(data)
    end
    PlayerData:setLastSceneData(nil)
    if _isNew == 1 then
        performWithDelay(self, function()
            local _lay = ZCDialog:create(155)
            LayerManager.addNode(_lay, {isPop = true})
            local _spine = zc.createSpine({
                fileName = "boss_laixi",
                actName = "boss_open",
                loop = false,
            })
            _spine:setPosition(zc.width*0.5, zc.height*0.5)
            _lay:addChild(_spine)
            _spine:registerSpineEventHandler( function ( event )
                local name  = event.animation
                if name == "boss_open" then
                    _spine:playAction("boss_idle")
                elseif name == "boss_idle" then
                    performWithDelay(_lay, function()
                        _doFresh()
                        LayerManager.removeLayout(true)
                        if _isFirst == 1 then
                            getGuideManager():setCurrentGID(GuideKey.KEY_13210)
                            getGuideManager():setHeroFuncCallBack(function()
                                if self._bossBtn and self._bossBtn:isVisible() then
                                    getGuideManager():setObjTarget(self._bossBtn, 0.9)
                                    getGuideManager():startGuide()
                                end
                            end)
                            getGuideManager():startGuide()
                        end
                    end, 0.01)
                end
            end, sp.EventType.ANIMATION_COMPLETE)
        end, 0.01)
    else
        _doFresh()
    end
end

function WeaponCopyListLayer:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_13206 then
        getGuideManager():setHeroFuncCallBack(function()
            local _target = self._listTab:cellAtIndex(0)
            if _target and _target.di then
                getGuideManager():setObjTarget(_target.di, 0.9)
                getGuideManager():startGuide()
            end
        end)
        getGuideManager():startGuide()
    elseif _currentGID == GuideKey.KEY_13215 then
        getGuideManager():setHeroFuncCallBack(function()
            getGuideManager():setFuncGuideOver()
        end)
        getGuideManager():startGuide()
    end
end

function WeaponCopyListLayer:addHandFlag()
    local _index = 1
    local _db = self._listDb[_index + 1]
    local _flag = self:getStatusFlag(_db)
    if not _flag then
        return
    end
    local _target = self._listTab:cellAtIndex(_index)
    if not _target or not _target.di then
        return
    end
    local _guideHand = zc.createSpine({
        fileName = "shou",
        actName = "shou",
    })
    _guideHand:setPosition(cc.pMul(cc.pFromSize(_target.di:getContentSize()), 0.5))
    _target.di:addChild(_guideHand, 10)
    _target.guideHand = _guideHand
    _guideHand:setGlobalZOrder(1)
    performWithDelay(_guideHand, function()
        if not tolua.isnull(_guideHand) then
            _guideHand:removeFromParent()
        end
    end, 4)
end

return WeaponCopyListLayer